diff -ru openssh-3.7.1p2.orig/TODO openssh-3.7.1p2/TODO
--- openssh-3.7.1p2.orig/TODO	2003-06-11 23:56:41.000000000 +1000
+++ openssh-3.7.1p2/TODO	2003-11-12 13:06:03.000000000 +1100
@@ -30,8 +30,6 @@
 
 - More platforms for for setproctitle() emulation (testing needed)
 
-- Handle changing passwords for the non-PAM expired password case
-
 - Improve PAM support (a pam_lastlog module will cause sshd to exit)
   and maybe support alternate forms of authentications like OPIE via
   pam?
diff -ru openssh-3.7.1p2.orig/acconfig.h openssh-3.7.1p2/acconfig.h
--- openssh-3.7.1p2.orig/acconfig.h	2003-09-16 11:52:19.000000000 +1000
+++ openssh-3.7.1p2/acconfig.h	2003-11-12 13:06:03.000000000 +1100
@@ -59,6 +59,9 @@
 /* from environment and PATH */
 #undef LOGIN_PROGRAM_FALLBACK
 
+/* Path to passwd program */
+#undef PASSWD_PROGRAM_PATH
+
 /* Define if your password has a pw_class field */
 #undef HAVE_PW_CLASS_IN_PASSWD
 
diff -ru openssh-3.7.1p2.orig/auth-pam.c openssh-3.7.1p2/auth-pam.c
--- openssh-3.7.1p2.orig/auth-pam.c	2003-09-23 19:24:21.000000000 +1000
+++ openssh-3.7.1p2/auth-pam.c	2003-11-12 13:06:03.000000000 +1100
@@ -52,6 +52,8 @@
 #include "auth-options.h"
 
 extern ServerOptions options;
+extern Buffer loginmsg;
+extern int compat20;
 
 #define __unused
 
@@ -230,6 +232,12 @@
 	sshpam_err = pam_authenticate(sshpam_handle, 0);
 	if (sshpam_err != PAM_SUCCESS)
 		goto auth_fail;
+	if (compat20) {
+		sshpam_err = pam_chauthtok(sshpam_handle,
+		    PAM_CHANGE_EXPIRED_AUTHTOK);
+		if (sshpam_err != PAM_SUCCESS)
+			goto auth_fail;
+	}
 	buffer_put_cstring(&buffer, "OK");
 	ssh_msg_send(ctxt->pam_csock, sshpam_err, &buffer);
 	buffer_free(&buffer);
@@ -325,8 +333,8 @@
          * sshd doesn't set the tty until too late in the auth process and 
 	 * may not even set one (for tty-less connections)
          */
-	debug("PAM: setting PAM_TTY to \"ssh\"");
-	sshpam_err = pam_set_item(sshpam_handle, PAM_TTY, "ssh");
+	debug("PAM: setting PAM_TTY to \"/dev/ssh\"");
+	sshpam_err = pam_set_item(sshpam_handle, PAM_TTY, "/dev/ssh");
 	if (sshpam_err != PAM_SUCCESS) {
 		pam_end(sshpam_handle, sshpam_err);
 		sshpam_handle = NULL;
@@ -419,13 +427,9 @@
 		case PAM_AUTH_ERR:
 			if (**prompts != NULL) {
 				/* drain any accumulated messages */
-#if 0 /* XXX - not compatible with privsep */
-				packet_start(SSH2_MSG_USERAUTH_BANNER);
-				packet_put_cstring(**prompts);
-				packet_put_cstring("");
-				packet_send();
-				packet_write_wait();
-#endif
+				debug("%s: %s", __func__, **prompts);
+				buffer_append(&loginmsg, **prompts,
+				    strlen(**prompts));
 				xfree(**prompts);
 				**prompts = NULL;
 			}
@@ -537,34 +541,13 @@
 	if (sshpam_err != PAM_SUCCESS && sshpam_err != PAM_NEW_AUTHTOK_REQD)
 		return (0);
 
-	if (sshpam_err == PAM_NEW_AUTHTOK_REQD) {
-		sshpam_new_authtok_reqd = 1;
-
-		/* Prevent forwardings until password changed */
-		no_port_forwarding_flag |= 2;
-		no_agent_forwarding_flag |= 2;
-		no_x11_forwarding_flag |= 2;
-	}
+	if (sshpam_err == PAM_NEW_AUTHTOK_REQD)
+		flag_password_change_required();
 
 	return (1);
 }
 
 void
-do_pam_session(void)
-{
-	sshpam_err = pam_set_item(sshpam_handle, PAM_CONV, 
-	    (const void *)&null_conv);
-	if (sshpam_err != PAM_SUCCESS)
-		fatal("PAM: failed to set PAM_CONV: %s",
-		    pam_strerror(sshpam_handle, sshpam_err));
-	sshpam_err = pam_open_session(sshpam_handle, 0);
-	if (sshpam_err != PAM_SUCCESS)
-		fatal("PAM: pam_open_session(): %s",
-		    pam_strerror(sshpam_handle, sshpam_err));
-	sshpam_session_open = 1;
-}
-
-void
 do_pam_set_tty(const char *tty)
 {
 	if (tty != NULL) {
@@ -610,7 +593,7 @@
 }
 
 static int
-pam_chauthtok_conv(int n, const struct pam_message **msg,
+pam_tty_conv(int n, const struct pam_message **msg,
     struct pam_response **resp, void *data)
 {
 	char input[PAM_MAX_MSG_SIZE];
@@ -619,7 +602,7 @@
 
 	*resp = NULL;
 
-	if (n <= 0 || n > PAM_MAX_NUM_MSG)
+	if (n <= 0 || n > PAM_MAX_NUM_MSG || !isatty(STDIN_FILENO))
 		return (PAM_CONV_ERR);
 
 	if ((reply = malloc(n * sizeof(*reply))) == NULL)
@@ -635,14 +618,14 @@
 			reply[i].resp_retcode = PAM_SUCCESS;
 			break;
 		case PAM_PROMPT_ECHO_ON:
-			fputs(PAM_MSG_MEMBER(msg, i, msg), stderr);
+			fprintf(stderr, "%s\n", PAM_MSG_MEMBER(msg, i, msg));
 			fgets(input, sizeof input, stdin);
 			reply[i].resp = xstrdup(input);
 			reply[i].resp_retcode = PAM_SUCCESS;
 			break;
 		case PAM_ERROR_MSG:
 		case PAM_TEXT_INFO:
-			fputs(PAM_MSG_MEMBER(msg, i, msg), stderr);
+			fprintf(stderr, "%s\n", PAM_MSG_MEMBER(msg, i, msg));
 			reply[i].resp_retcode = PAM_SUCCESS;
 			break;
 		default:
@@ -661,6 +644,8 @@
 	return (PAM_CONV_ERR);
 }
 
+static struct pam_conv tty_conv = { pam_tty_conv, NULL };
+
 /*
  * XXX this should be done in the authentication phase, but ssh1 doesn't
  * support that
@@ -668,15 +653,10 @@
 void
 do_pam_chauthtok(void)
 {
-	struct pam_conv pam_conv;
-
-	pam_conv.conv = pam_chauthtok_conv;
-	pam_conv.appdata_ptr = NULL;
-
 	if (use_privsep)
 		fatal("Password expired (unable to change with privsep)");
 	sshpam_err = pam_set_item(sshpam_handle, PAM_CONV,
-	    (const void *)&pam_conv);
+	    (const void *)&tty_conv);
 	if (sshpam_err != PAM_SUCCESS)
 		fatal("PAM: failed to set PAM_CONV: %s",
 		    pam_strerror(sshpam_handle, sshpam_err));
@@ -687,6 +667,21 @@
 		    pam_strerror(sshpam_handle, sshpam_err));
 }
 
+void
+do_pam_session(void)
+{
+	sshpam_err = pam_set_item(sshpam_handle, PAM_CONV, 
+	    (const void *)&tty_conv);
+	if (sshpam_err != PAM_SUCCESS)
+		fatal("PAM: failed to set PAM_CONV: %s",
+		    pam_strerror(sshpam_handle, sshpam_err));
+	sshpam_err = pam_open_session(sshpam_handle, 0);
+	if (sshpam_err != PAM_SUCCESS)
+		fatal("PAM: pam_open_session(): %s",
+		    pam_strerror(sshpam_handle, sshpam_err));
+	sshpam_session_open = 1;
+}
+
 /* 
  * Set a PAM environment string. We need to do this so that the session
  * modules can handle things like Kerberos/GSI credentials that appear
diff -ru openssh-3.7.1p2.orig/auth-passwd.c openssh-3.7.1p2/auth-passwd.c
--- openssh-3.7.1p2.orig/auth-passwd.c	2003-09-18 18:26:48.000000000 +1000
+++ openssh-3.7.1p2/auth-passwd.c	2003-11-12 13:06:03.000000000 +1100
@@ -42,13 +42,17 @@
 #include "log.h"
 #include "servconf.h"
 #include "auth.h"
-#ifdef WITH_AIXAUTHENTICATE
-# include "buffer.h"
-# include "canohost.h"
-extern Buffer loginmsg;
-#endif
+#include "buffer.h"
+#include "canohost.h"
+#include "misc.h"
+#include "channels.h"
+#include "auth-options.h"
+#include "uidswap.h"
 
 extern ServerOptions options;
+extern Buffer loginmsg;
+
+int password_change_required = 0;
 
 /*
  * Tries to authenticate the user using password.  Returns true if
@@ -99,7 +103,6 @@
 
 		if (authenticate(pw->pw_name, password, &reenter,
 		    &authmsg) == 0 && ok) {
-			char *msg;
 			char *host = 
 			    (char *)get_canonical_hostname(options.use_dns);
 
@@ -107,19 +110,7 @@
 			aix_remove_embedded_newlines(authmsg);	
 
 			debug3("AIX/authenticate succeeded for user %s: %.100s",
-				pw->pw_name, authmsg);
-
-	        	/* No pty yet, so just label the line as "ssh" */
-			aix_setauthdb(authctxt->user);
-	        	if (loginsuccess(authctxt->user, host, "ssh", 
-			    &msg) == 0) {
-				if (msg != NULL) {
-					debug("%s: msg %s", __func__, msg);
-					buffer_append(&loginmsg, msg, 
-					    strlen(msg));
-					xfree(msg);
-				}
-			}
+			    pw->pw_name, authmsg);
 		} else {
 			debug3("AIX/authenticate failed for user %s: %.100s",
 			    pw->pw_name, authmsg);
@@ -161,3 +152,79 @@
 # endif
 #endif /* !HAVE_OSF_SIA */
 }
+
+/*
+ * Perform generic password change via tty. Like do_pam_chauthtok(),
+ * it throws a fatal error if the password can't be changed.
+ */
+int
+do_tty_change_password(struct passwd *pw)
+{
+	pid_t pid;
+	int status;
+	mysig_t old_signal;
+
+	old_signal = signal(SIGCHLD, SIG_DFL);
+
+	if ((pid = fork()) == -1)
+		fatal("Couldn't fork: %s", strerror(errno));
+
+	if (pid == 0) {
+		permanently_set_uid(pw);
+		if (geteuid() == 0) 
+			execl(PASSWD_PROGRAM_PATH, "passwd", pw->pw_name,
+			    (char *)NULL);
+		else
+			execl(PASSWD_PROGRAM_PATH, "passwd", (char *)NULL);
+			
+		/* execl shouldn't return */
+		fatal("Couldn't exec %s", PASSWD_PROGRAM_PATH);
+		exit(1);
+	}
+
+	debug3("%s: waiting for pid %d", __func__, (int)pid);
+	if (waitpid(pid, &status, 0) == -1)
+		fatal("Couldn't wait for child: %s", strerror(errno));
+	signal(SIGCHLD, old_signal);
+
+	if (WIFEXITED(status) && WEXITSTATUS(status) == 0) {
+		debug("%s password changed sucessfully", __func__);
+		flag_password_change_successful();
+		return 1;
+	} else {
+		fatal("Failed to change password for %s, passwd returned %d",
+		    pw->pw_name, status);
+		return 0;
+	}
+}
+
+/*
+ * flag that password change is necessary
+ */
+void
+flag_password_change_required(void)
+{
+	debug3("disabling forwarding");
+	password_change_required = 1;
+
+	/* disallow other functionality for now */
+	no_port_forwarding_flag |= 2;
+	no_agent_forwarding_flag |= 2;
+	no_x11_forwarding_flag |= 2;
+}
+
+/*
+ * password change successful
+ * XXX: must be done in parent, but currently there is no way to pass
+ * this request.
+ */
+void
+flag_password_change_successful(void)
+{
+	debug3("resetting forwarding flags");
+
+	password_change_required = 0;
+	no_port_forwarding_flag &= ~2;
+	no_agent_forwarding_flag &= ~2;
+	no_x11_forwarding_flag &= ~2;
+}
diff -ru openssh-3.7.1p2.orig/auth.c openssh-3.7.1p2/auth.c
--- openssh-3.7.1p2.orig/auth.c	2003-09-03 07:32:46.000000000 +1000
+++ openssh-3.7.1p2/auth.c	2003-11-12 13:06:03.000000000 +1100
@@ -51,6 +51,7 @@
 #include "misc.h"
 #include "bufaux.h"
 #include "packet.h"
+#include "sshlogin.h"
 
 /* import */
 extern ServerOptions options;
@@ -59,6 +60,8 @@
 /* Debugging messages */
 Buffer auth_debug;
 int auth_debug_init;
+extern Buffer expiremsg;
+extern Buffer loginmsg;
 
 /*
  * Check if the user is allowed to log in via ssh. If user is listed
@@ -80,43 +83,84 @@
 	struct spwd *spw = NULL;
 #endif
 
+	debug("%s: entering", __func__);
+
 	/* Shouldn't be called if pw is NULL, but better safe than sorry... */
-	if (!pw || !pw->pw_name)
+	if (!pw || !pw->pw_name) {
+		debug3("pw invalid, returning");
 		return 0;
+	}
 
+#define	DAY		(24L * 60 * 60) /* 1 day in seconds */
+#define WEEK		(DAY * 7)	/* 1 week in seconds */
 #if defined(HAVE_SHADOW_H) && !defined(DISABLE_SHADOW)
-	if (!options.use_pam)
+	if (!options.use_pam) {
 		spw = getspnam(pw->pw_name);
+		debug3("Getting shadow info");
+	}
 #ifdef HAS_SHADOW_EXPIRE
-#define	DAY		(24L * 60 * 60) /* 1 day in seconds */
 	if (!options.use_pam && spw != NULL) {
 		time_t today;
+		int daysleft, disabled = 0;
 
 		today = time(NULL) / DAY;
 		debug3("allowed_user: today %d sp_expire %d sp_lstchg %d"
-		    " sp_max %d", (int)today, (int)spw->sp_expire,
-		    (int)spw->sp_lstchg, (int)spw->sp_max);
+		    " sp_max %d sp_warn %d", (int)today, (int)spw->sp_expire,
+		    (int)spw->sp_lstchg, (int)spw->sp_max, (int)spw->sp_warn);
 
 		/*
 		 * We assume account and password expiration occurs the
 		 * day after the day specified.
 		 */
-		if (spw->sp_expire != -1 && today > spw->sp_expire) {
+		daysleft = spw->sp_expire - today;
+		if (spw->sp_expire == -1) {
+			debug3("account expiration disabled");
+		} else if (daysleft < 0) {
 			logit("Account %.100s has expired", pw->pw_name);
 			return 0;
-		}
+		} else if (daysleft <= spw->sp_warn) {
+			char buf[256];
 
-		if (spw->sp_lstchg == 0) {
+			debug3("account will expire in %d days", daysleft);
+			snprintf(buf, sizeof(buf),
+			    "Your account will expire in %d day%s.\n",
+			    daysleft, daysleft == 1 ? "" : "s");
+			buffer_append(&loginmsg, buf, strlen(buf));
+		}
+
+#if defined(__hpux) && !defined(HAVE_SECUREWARE)
+		if (iscomsec() && spw->sp_min == 0 && spw->sp_max == 0 &&
+		    spw->sp_warn == 0)
+			disabled = 1;   /* Trusted Mode: expiry disabled */
+#endif
+
+#define PWCHG_FORCED    "You must change your password now.\n"
+#define PWCHG_EXPIRED   "Your password has expired, you must change it now.\n"
+		daysleft = spw->sp_lstchg + spw->sp_max - today;
+		if (disabled) {
+			debug3("password expiration disabled");
+		} else if (spw->sp_lstchg == 0) {
 			logit("User %.100s password has expired (root forced)",
 			    pw->pw_name);
-			return 0;
-		}
-
-		if (spw->sp_max != -1 &&
-		    today > spw->sp_lstchg + spw->sp_max) {
+			flag_password_change_required();
+			buffer_append(&expiremsg, PWCHG_FORCED,
+			    sizeof(PWCHG_FORCED));
+		} else if (spw->sp_max == -1) {
+			debug3("password expiration disabled");
+		} else if (daysleft < 0) {
 			logit("User %.100s password has expired (password aged)",
 			    pw->pw_name);
-			return 0;
+			flag_password_change_required();
+			buffer_append(&expiremsg, PWCHG_EXPIRED,
+			    sizeof(PWCHG_EXPIRED));
+		} else if (daysleft <= spw->sp_warn) {
+			char buf[256];
+
+			debug3("password will expire in %d days", daysleft);
+			snprintf(buf, sizeof(buf),
+			    "Your password will expire in %d day%s.\n",
+			    daysleft, daysleft == 1 ? "" : "s");
+			buffer_append(&expiremsg, buf, strlen(buf));
 		}
 	}
 #endif /* HAS_SHADOW_EXPIRE */
@@ -147,6 +191,16 @@
 		if (strstr(passwd, LOCKED_PASSWD_SUBSTR))
 			locked = 1;
 #endif
+#if defined(__hpux) && !defined(HAVE_SECUREWARE)
+		if (iscomsec()) {
+			struct pr_field *pr;
+			
+			if ((pr = getprpwnam(pw->pw_name)) != NULL)
+				if (pr->fd_lock)
+					locked = 1;
+		}
+#endif
+
 		if (locked) {
 			logit("User %.100s not allowed because account is locked",
 			    pw->pw_name);
@@ -257,6 +311,64 @@
 				return 0;
 		}
 	}
+
+	/*
+	 * Check AIX password expiry.  Only check when running as root.
+	 * Unpriv'ed users can't access /etc/security/passwd or
+	 * /etc/security/user so passwdexpired will always fail.
+	 */
+	if (geteuid() == 0) {
+		char *msg, *user = pw->pw_name;
+		int result, maxage, result2, maxexpired;
+		struct userpw *upw;
+
+		/*
+		 * Check if password expired too long as in this case,
+		 * passwdexpired still returns 1 but /bin/passwd will fail
+		 */
+		upw = getuserpw(user);
+		result = getuserattr(user, S_MAXEXPIRED, &maxexpired, SEC_INT);
+		result2 = getuserattr(user, S_MAXAGE, &maxage, SEC_INT);
+		if (upw != NULL && result == 0 && result2 == 0) {
+			time_t now = time(NULL);
+
+			debug3("%s lastupdate %lu maxage %d wks maxexpired %d"
+			    "wks time now %d", __func__, 
+			    (unsigned long)upw->upw_lastupdate, maxage,
+			    maxexpired, now);
+
+			if (maxexpired != -1 && maxage != 0 &&
+			    upw->upw_lastupdate + ((maxage+maxexpired) * WEEK) <= now ) {
+				logit("User %.100s password expired too long",
+				    user);
+				return 0;
+			}
+		}
+
+		result = passwdexpired(user, &msg);
+		if (msg && *msg) {
+			buffer_append(&expiremsg, msg, strlen(msg));
+			aix_remove_embedded_newlines(msg);
+		}
+		debug3("AIX/passwdexpired returned %d msg %.100s", result, msg);
+
+		switch (result) {
+		case 0: /* success, password not expired */
+			break;
+		case 1: /* expired, password change required */
+			flag_password_change_required();
+			break;
+		default: /* user can't change(2) or other error (-1) */
+			logit("Password can't be changed for user %s: "
+			    "%.100s", user, msg);
+			if (msg)
+				xfree(msg);
+			return 0;
+		}
+		if (msg)
+			xfree(msg);
+
+	}
 #endif /* WITH_AIXAUTHENTICATE */
 
 	/* We found no reason not to let this user try to log on... */
@@ -271,6 +383,46 @@
 	return authctxt;
 }
 
+/*
+ * Generate last_login message and store for later display.  This must be
+ * called before login_login() is called and lastlog is updated.
+ */
+void
+generate_loginmsg(const char *user, uid_t uid, const char *host)
+{
+#ifdef WITH_AIXAUTHENTICATE
+	char *msg;
+
+	/* We don't have a pty yet, so just label the line as "ssh" */
+	aix_setauthdb(user);
+	if (loginsuccess(user, host, "ssh", &msg) >= 0)
+		buffer_append(&loginmsg, msg, strlen(msg));
+#elif !defined(NO_SSH_LASTLOG)
+	if (options.print_lastlog) {
+		char *time_string, lasthost[MAXHOSTNAMELEN], buf[256];
+		time_t last_login_time;
+
+		last_login_time = get_last_login_time(uid, user, lasthost,
+		   sizeof(lasthost));
+
+		if (last_login_time != 0) {
+		       time_string = ctime(&last_login_time);
+		       if (strchr(time_string, '\n'))
+			       *strchr(time_string, '\n') = 0;
+		       if (strcmp(lasthost, "") == 0)
+			       snprintf(buf, sizeof(buf),
+				   "Last login: %s\r\n",
+				   time_string);
+		       else
+			       snprintf(buf, sizeof(buf),
+				   "Last login: %s from %s\r\n",
+				   time_string, lasthost);
+		       buffer_append(&loginmsg, buf, strlen(buf));
+		}
+       }
+#endif
+}
+
 void
 auth_log(Authctxt *authctxt, int authenticated, char *method, char *info)
 {
@@ -298,6 +450,10 @@
 	    get_remote_port(),
 	    info);
 
+	if (authenticated && geteuid() == 0)
+		generate_loginmsg(authctxt->user, authctxt->pw->pw_uid,
+		    get_canonical_hostname(options.use_dns));
+
 #ifdef CUSTOM_FAILED_LOGIN
 	if (authenticated == 0 && strcmp(method, "password") == 0)
 		record_failed_login(authctxt->user, "ssh");
diff -ru openssh-3.7.1p2.orig/auth.h openssh-3.7.1p2/auth.h
--- openssh-3.7.1p2.orig/auth.h	2003-09-03 12:11:30.000000000 +1000
+++ openssh-3.7.1p2/auth.h	2003-11-12 13:06:03.000000000 +1100
@@ -144,6 +144,9 @@
 
 int	allowed_user(struct passwd *);
 struct passwd * getpwnamallow(const char *user);
+int	do_tty_change_password(struct passwd *pw);
+void	flag_password_change_required(void);
+void	flag_password_change_successful(void);
 
 char	*get_challenge(Authctxt *);
 int	verify_response(Authctxt *, const char *);
diff -ru openssh-3.7.1p2.orig/config.h.in openssh-3.7.1p2/config.h.in
--- openssh-3.7.1p2.orig/config.h.in	2003-09-23 19:55:07.000000000 +1000
+++ openssh-3.7.1p2/config.h.in	2003-11-12 13:06:50.000000000 +1100
@@ -60,6 +60,9 @@
 /* from environment and PATH */
 #undef LOGIN_PROGRAM_FALLBACK
 
+/* Path to passwd program */
+#undef PASSWD_PROGRAM_PATH
+
 /* Define if your password has a pw_class field */
 #undef HAVE_PW_CLASS_IN_PASSWD
 
diff -ru openssh-3.7.1p2.orig/configure openssh-3.7.1p2/configure
--- openssh-3.7.1p2.orig/configure	2003-09-23 19:55:43.000000000 +1000
+++ openssh-3.7.1p2/configure	2003-11-12 13:07:12.000000000 +1100
@@ -2946,11 +2946,59 @@
 	fi
 fi
 
+# Extract the first word of "passwd", so it can be a program name with args.
+set dummy passwd; ac_word=$2
+echo "$as_me:2951: checking for $ac_word" >&5
+echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
+if test "${ac_cv_path_PASSWD_PROGRAM_PATH+set}" = set; then
+  echo $ECHO_N "(cached) $ECHO_C" >&6
+else
+  case $PASSWD_PROGRAM_PATH in
+  [\\/]* | ?:[\\/]*)
+  ac_cv_path_PASSWD_PROGRAM_PATH="$PASSWD_PROGRAM_PATH" # Let the user override the test with a path.
+  ;;
+  *)
+  ac_save_IFS=$IFS; IFS=$ac_path_separator
+ac_dummy="$PATH"
+for ac_dir in $ac_dummy; do
+  IFS=$ac_save_IFS
+  test -z "$ac_dir" && ac_dir=.
+  if $as_executable_p "$ac_dir/$ac_word"; then
+   ac_cv_path_PASSWD_PROGRAM_PATH="$ac_dir/$ac_word"
+   echo "$as_me:2968: found $ac_dir/$ac_word" >&5
+   break
+fi
+done
+
+  ;;
+esac
+fi
+PASSWD_PROGRAM_PATH=$ac_cv_path_PASSWD_PROGRAM_PATH
+
+if test -n "$PASSWD_PROGRAM_PATH"; then
+  echo "$as_me:2979: result: $PASSWD_PROGRAM_PATH" >&5
+echo "${ECHO_T}$PASSWD_PROGRAM_PATH" >&6
+else
+  echo "$as_me:2982: result: no" >&5
+echo "${ECHO_T}no" >&6
+fi
+
+if test ! -z "$PASSWD_PROGRAM_PATH" ; then
+	cat >>confdefs.h <<EOF
+#define PASSWD_PROGRAM_PATH "$PASSWD_PROGRAM_PATH"
+EOF
+
+else
+	{ { echo "$as_me:2992: error: *** passwd command not found - check config.log ***" >&5
+echo "$as_me: error: *** passwd command not found - check config.log ***" >&2;}
+   { (exit 1); exit 1; }; }
+fi
+
 if test -z "$LD" ; then
 	LD=$CC
 fi
 
-echo "$as_me:2953: checking for $CC option to accept ANSI C" >&5
+echo "$as_me:3001: checking for $CC option to accept ANSI C" >&5
 echo $ECHO_N "checking for $CC option to accept ANSI C... $ECHO_C" >&6
 if test "${ac_cv_prog_cc_stdc+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -2958,7 +3006,7 @@
   ac_cv_prog_cc_stdc=no
 ac_save_CC=$CC
 cat >conftest.$ac_ext <<_ACEOF
-#line 2961 "configure"
+#line 3009 "configure"
 #include "confdefs.h"
 #include <stdarg.h>
 #include <stdio.h>
@@ -3007,16 +3055,16 @@
 do
   CC="$ac_save_CC $ac_arg"
   rm -f conftest.$ac_objext
-if { (eval echo "$as_me:3010: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:3058: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:3013: \$? = $ac_status" >&5
+  echo "$as_me:3061: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:3016: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3064: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3019: \$? = $ac_status" >&5
+  echo "$as_me:3067: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_prog_cc_stdc=$ac_arg
 break
@@ -3033,15 +3081,15 @@
 
 case "x$ac_cv_prog_cc_stdc" in
   x|xno)
-    echo "$as_me:3036: result: none needed" >&5
+    echo "$as_me:3084: result: none needed" >&5
 echo "${ECHO_T}none needed" >&6 ;;
   *)
-    echo "$as_me:3039: result: $ac_cv_prog_cc_stdc" >&5
+    echo "$as_me:3087: result: $ac_cv_prog_cc_stdc" >&5
 echo "${ECHO_T}$ac_cv_prog_cc_stdc" >&6
     CC="$CC $ac_cv_prog_cc_stdc" ;;
 esac
 
-echo "$as_me:3044: checking for inline" >&5
+echo "$as_me:3092: checking for inline" >&5
 echo $ECHO_N "checking for inline... $ECHO_C" >&6
 if test "${ac_cv_c_inline+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3049,7 +3097,7 @@
   ac_cv_c_inline=no
 for ac_kw in inline __inline__ __inline; do
   cat >conftest.$ac_ext <<_ACEOF
-#line 3052 "configure"
+#line 3100 "configure"
 #include "confdefs.h"
 #ifndef __cplusplus
 static $ac_kw int static_foo () {return 0; }
@@ -3058,16 +3106,16 @@
 
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:3061: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:3109: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:3064: \$? = $ac_status" >&5
+  echo "$as_me:3112: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:3067: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3115: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3070: \$? = $ac_status" >&5
+  echo "$as_me:3118: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_c_inline=$ac_kw; break
 else
@@ -3078,7 +3126,7 @@
 done
 
 fi
-echo "$as_me:3081: result: $ac_cv_c_inline" >&5
+echo "$as_me:3129: result: $ac_cv_c_inline" >&5
 echo "${ECHO_T}$ac_cv_c_inline" >&6
 case $ac_cv_c_inline in
   inline | yes) ;;
@@ -3102,7 +3150,7 @@
 *-*-aix*)
 	CPPFLAGS="$CPPFLAGS -I/usr/local/include"
 	LDFLAGS="$LDFLAGS -L/usr/local/lib"
-	echo "$as_me:3105: checking how to specify blibpath for linker ($LD)" >&5
+	echo "$as_me:3153: checking how to specify blibpath for linker ($LD)" >&5
 echo $ECHO_N "checking how to specify blibpath for linker ($LD)... $ECHO_C" >&6
 	if (test -z "$blibpath"); then
 		blibpath="/usr/lib:/lib:/usr/local/lib"
@@ -3112,7 +3160,7 @@
 		if (test -z "$blibflags"); then
 			LDFLAGS="$saved_LDFLAGS $tryflags$blibpath"
 			cat >conftest.$ac_ext <<_ACEOF
-#line 3115 "configure"
+#line 3163 "configure"
 #include "confdefs.h"
 
 int
@@ -3124,16 +3172,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:3127: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3175: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3130: \$? = $ac_status" >&5
+  echo "$as_me:3178: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:3133: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3181: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3136: \$? = $ac_status" >&5
+  echo "$as_me:3184: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   blibflags=$tryflags
 else
@@ -3144,23 +3192,23 @@
 		fi
 	done
 	if (test -z "$blibflags"); then
-		echo "$as_me:3147: result: not found" >&5
+		echo "$as_me:3195: result: not found" >&5
 echo "${ECHO_T}not found" >&6
-		{ { echo "$as_me:3149: error: *** must be able to specify blibpath on AIX - check config.log" >&5
+		{ { echo "$as_me:3197: error: *** must be able to specify blibpath on AIX - check config.log" >&5
 echo "$as_me: error: *** must be able to specify blibpath on AIX - check config.log" >&2;}
    { (exit 1); exit 1; }; }
 	else
-		echo "$as_me:3153: result: $blibflags" >&5
+		echo "$as_me:3201: result: $blibflags" >&5
 echo "${ECHO_T}$blibflags" >&6
 	fi
 	LDFLAGS="$saved_LDFLAGS"
-		echo "$as_me:3157: checking for authenticate" >&5
+		echo "$as_me:3205: checking for authenticate" >&5
 echo $ECHO_N "checking for authenticate... $ECHO_C" >&6
 if test "${ac_cv_func_authenticate+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 3163 "configure"
+#line 3211 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char authenticate (); below.  */
@@ -3191,16 +3239,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:3194: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3242: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3197: \$? = $ac_status" >&5
+  echo "$as_me:3245: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:3200: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3248: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3203: \$? = $ac_status" >&5
+  echo "$as_me:3251: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_authenticate=yes
 else
@@ -3210,7 +3258,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:3213: result: $ac_cv_func_authenticate" >&5
+echo "$as_me:3261: result: $ac_cv_func_authenticate" >&5
 echo "${ECHO_T}$ac_cv_func_authenticate" >&6
 if test $ac_cv_func_authenticate = yes; then
   cat >>confdefs.h <<\EOF
@@ -3218,7 +3266,7 @@
 EOF
 
 else
-  echo "$as_me:3221: checking for authenticate in -ls" >&5
+  echo "$as_me:3269: checking for authenticate in -ls" >&5
 echo $ECHO_N "checking for authenticate in -ls... $ECHO_C" >&6
 if test "${ac_cv_lib_s_authenticate+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3226,7 +3274,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-ls  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 3229 "configure"
+#line 3277 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -3245,16 +3293,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:3248: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3296: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3251: \$? = $ac_status" >&5
+  echo "$as_me:3299: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:3254: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3302: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3257: \$? = $ac_status" >&5
+  echo "$as_me:3305: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_s_authenticate=yes
 else
@@ -3265,7 +3313,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:3268: result: $ac_cv_lib_s_authenticate" >&5
+echo "$as_me:3316: result: $ac_cv_lib_s_authenticate" >&5
 echo "${ECHO_T}$ac_cv_lib_s_authenticate" >&6
 if test $ac_cv_lib_s_authenticate = yes; then
    cat >>confdefs.h <<\EOF
@@ -3278,13 +3326,13 @@
 
 fi
 
-		echo "$as_me:3281: checking whether loginfailed is declared" >&5
+		echo "$as_me:3329: checking whether loginfailed is declared" >&5
 echo $ECHO_N "checking whether loginfailed is declared... $ECHO_C" >&6
 if test "${ac_cv_have_decl_loginfailed+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 3287 "configure"
+#line 3335 "configure"
 #include "confdefs.h"
 #include <usersec.h>
 
@@ -3300,16 +3348,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:3303: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:3351: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:3306: \$? = $ac_status" >&5
+  echo "$as_me:3354: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:3309: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3357: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3312: \$? = $ac_status" >&5
+  echo "$as_me:3360: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_have_decl_loginfailed=yes
 else
@@ -3319,13 +3367,13 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:3322: result: $ac_cv_have_decl_loginfailed" >&5
+echo "$as_me:3370: result: $ac_cv_have_decl_loginfailed" >&5
 echo "${ECHO_T}$ac_cv_have_decl_loginfailed" >&6
 if test $ac_cv_have_decl_loginfailed = yes; then
-  echo "$as_me:3325: checking if loginfailed takes 4 arguments" >&5
+  echo "$as_me:3373: checking if loginfailed takes 4 arguments" >&5
 echo $ECHO_N "checking if loginfailed takes 4 arguments... $ECHO_C" >&6
 		  cat >conftest.$ac_ext <<_ACEOF
-#line 3328 "configure"
+#line 3376 "configure"
 #include "confdefs.h"
 #include <usersec.h>
 int
@@ -3337,18 +3385,18 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:3340: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:3388: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:3343: \$? = $ac_status" >&5
+  echo "$as_me:3391: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:3346: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3394: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3349: \$? = $ac_status" >&5
+  echo "$as_me:3397: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-  echo "$as_me:3351: result: yes" >&5
+  echo "$as_me:3399: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 			 cat >>confdefs.h <<\EOF
 #define AIX_LOGINFAILED_4ARG 1
@@ -3357,7 +3405,7 @@
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
-echo "$as_me:3360: result: no" >&5
+echo "$as_me:3408: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
@@ -3367,13 +3415,13 @@
 for ac_func in setauthdb
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:3370: checking for $ac_func" >&5
+echo "$as_me:3418: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 3376 "configure"
+#line 3424 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -3404,16 +3452,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:3407: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3455: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3410: \$? = $ac_status" >&5
+  echo "$as_me:3458: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:3413: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3461: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3416: \$? = $ac_status" >&5
+  echo "$as_me:3464: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -3423,7 +3471,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:3426: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:3474: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -3509,14 +3557,14 @@
 
 	;;
 *-*-darwin*)
-	echo "$as_me:3512: checking if we have working getaddrinfo" >&5
+	echo "$as_me:3560: checking if we have working getaddrinfo" >&5
 echo $ECHO_N "checking if we have working getaddrinfo... $ECHO_C" >&6
 	if test "$cross_compiling" = yes; then
-  echo "$as_me:3515: result: assume it is working" >&5
+  echo "$as_me:3563: result: assume it is working" >&5
 echo "${ECHO_T}assume it is working" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 3519 "configure"
+#line 3567 "configure"
 #include "confdefs.h"
 #include <mach-o/dyld.h>
 main() { if (NSVersionOfRunTimeLibrary("System") >= (60 << 16))
@@ -3526,23 +3574,23 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:3529: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3577: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3532: \$? = $ac_status" >&5
+  echo "$as_me:3580: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:3534: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3582: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3537: \$? = $ac_status" >&5
+  echo "$as_me:3585: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-  echo "$as_me:3539: result: working" >&5
+  echo "$as_me:3587: result: working" >&5
 echo "${ECHO_T}working" >&6
 else
   echo "$as_me: program exited with status $ac_status" >&5
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
-echo "$as_me:3545: result: buggy" >&5
+echo "$as_me:3593: result: buggy" >&5
 echo "${ECHO_T}buggy" >&6
 	cat >>confdefs.h <<\EOF
 #define BROKEN_GETADDRINFO 1
@@ -3604,7 +3652,7 @@
 
 	LIBS="$LIBS -lsec -lsecpw"
 
-echo "$as_me:3607: checking for t_error in -lxnet" >&5
+echo "$as_me:3655: checking for t_error in -lxnet" >&5
 echo $ECHO_N "checking for t_error in -lxnet... $ECHO_C" >&6
 if test "${ac_cv_lib_xnet_t_error+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3612,7 +3660,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lxnet  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 3615 "configure"
+#line 3663 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -3631,16 +3679,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:3634: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3682: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3637: \$? = $ac_status" >&5
+  echo "$as_me:3685: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:3640: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3688: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3643: \$? = $ac_status" >&5
+  echo "$as_me:3691: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_xnet_t_error=yes
 else
@@ -3651,7 +3699,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:3654: result: $ac_cv_lib_xnet_t_error" >&5
+echo "$as_me:3702: result: $ac_cv_lib_xnet_t_error" >&5
 echo "${ECHO_T}$ac_cv_lib_xnet_t_error" >&6
 if test $ac_cv_lib_xnet_t_error = yes; then
   cat >>confdefs.h <<EOF
@@ -3661,7 +3709,7 @@
   LIBS="-lxnet $LIBS"
 
 else
-  { { echo "$as_me:3664: error: *** -lxnet needed on HP-UX - check config.log ***" >&5
+  { { echo "$as_me:3712: error: *** -lxnet needed on HP-UX - check config.log ***" >&5
 echo "$as_me: error: *** -lxnet needed on HP-UX - check config.log ***" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -3704,7 +3752,7 @@
 
 	LIBS="$LIBS -lsec"
 
-echo "$as_me:3707: checking for t_error in -lxnet" >&5
+echo "$as_me:3755: checking for t_error in -lxnet" >&5
 echo $ECHO_N "checking for t_error in -lxnet... $ECHO_C" >&6
 if test "${ac_cv_lib_xnet_t_error+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3712,7 +3760,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lxnet  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 3715 "configure"
+#line 3763 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -3731,16 +3779,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:3734: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3782: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3737: \$? = $ac_status" >&5
+  echo "$as_me:3785: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:3740: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3788: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3743: \$? = $ac_status" >&5
+  echo "$as_me:3791: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_xnet_t_error=yes
 else
@@ -3751,7 +3799,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:3754: result: $ac_cv_lib_xnet_t_error" >&5
+echo "$as_me:3802: result: $ac_cv_lib_xnet_t_error" >&5
 echo "${ECHO_T}$ac_cv_lib_xnet_t_error" >&6
 if test $ac_cv_lib_xnet_t_error = yes; then
   cat >>confdefs.h <<EOF
@@ -3761,7 +3809,7 @@
   LIBS="-lxnet $LIBS"
 
 else
-  { { echo "$as_me:3764: error: *** -lxnet needed on HP-UX - check config.log ***" >&5
+  { { echo "$as_me:3812: error: *** -lxnet needed on HP-UX - check config.log ***" >&5
 echo "$as_me: error: *** -lxnet needed on HP-UX - check config.log ***" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -3804,7 +3852,7 @@
 
 	LIBS="$LIBS -lsec"
 
-echo "$as_me:3807: checking for t_error in -lxnet" >&5
+echo "$as_me:3855: checking for t_error in -lxnet" >&5
 echo $ECHO_N "checking for t_error in -lxnet... $ECHO_C" >&6
 if test "${ac_cv_lib_xnet_t_error+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -3812,7 +3860,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lxnet  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 3815 "configure"
+#line 3863 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -3831,16 +3879,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:3834: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3882: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3837: \$? = $ac_status" >&5
+  echo "$as_me:3885: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:3840: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3888: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3843: \$? = $ac_status" >&5
+  echo "$as_me:3891: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_xnet_t_error=yes
 else
@@ -3851,7 +3899,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:3854: result: $ac_cv_lib_xnet_t_error" >&5
+echo "$as_me:3902: result: $ac_cv_lib_xnet_t_error" >&5
 echo "${ECHO_T}$ac_cv_lib_xnet_t_error" >&6
 if test $ac_cv_lib_xnet_t_error = yes; then
   cat >>confdefs.h <<EOF
@@ -3861,7 +3909,7 @@
   LIBS="-lxnet $LIBS"
 
 else
-  { { echo "$as_me:3864: error: *** -lxnet needed on HP-UX - check config.log ***" >&5
+  { { echo "$as_me:3912: error: *** -lxnet needed on HP-UX - check config.log ***" >&5
 echo "$as_me: error: *** -lxnet needed on HP-UX - check config.log ***" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -3900,13 +3948,13 @@
 #define WITH_IRIX_AUDIT 1
 EOF
 
-	echo "$as_me:3903: checking for jlimit_startjob" >&5
+	echo "$as_me:3951: checking for jlimit_startjob" >&5
 echo $ECHO_N "checking for jlimit_startjob... $ECHO_C" >&6
 if test "${ac_cv_func_jlimit_startjob+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 3909 "configure"
+#line 3957 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char jlimit_startjob (); below.  */
@@ -3937,16 +3985,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:3940: \"$ac_link\"") >&5
+if { (eval echo "$as_me:3988: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:3943: \$? = $ac_status" >&5
+  echo "$as_me:3991: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:3946: \"$ac_try\"") >&5
+  { (eval echo "$as_me:3994: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:3949: \$? = $ac_status" >&5
+  echo "$as_me:3997: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_jlimit_startjob=yes
 else
@@ -3956,7 +4004,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:3959: result: $ac_cv_func_jlimit_startjob" >&5
+echo "$as_me:4007: result: $ac_cv_func_jlimit_startjob" >&5
 echo "${ECHO_T}$ac_cv_func_jlimit_startjob" >&6
 if test $ac_cv_func_jlimit_startjob = yes; then
   cat >>confdefs.h <<\EOF
@@ -4104,11 +4152,11 @@
 	external_path_file=/etc/default/login
 	# hardwire lastlog location (can't detect it on some versions)
 	conf_lastlog_location="/var/adm/lastlog"
-	echo "$as_me:4107: checking for obsolete utmp and wtmp in solaris2.x" >&5
+	echo "$as_me:4155: checking for obsolete utmp and wtmp in solaris2.x" >&5
 echo $ECHO_N "checking for obsolete utmp and wtmp in solaris2.x... $ECHO_C" >&6
 	sol2ver=`echo "$host"| sed -e 's/.*[0-9]\.//'`
 	if test "$sol2ver" -ge 8; then
-		echo "$as_me:4111: result: yes" >&5
+		echo "$as_me:4159: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 		cat >>confdefs.h <<\EOF
 #define DISABLE_UTMP 1
@@ -4119,7 +4167,7 @@
 EOF
 
 	else
-		echo "$as_me:4122: result: no" >&5
+		echo "$as_me:4170: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 	;;
@@ -4129,13 +4177,13 @@
 for ac_func in getpwanam
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:4132: checking for $ac_func" >&5
+echo "$as_me:4180: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4138 "configure"
+#line 4186 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -4166,16 +4214,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:4169: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4217: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4172: \$? = $ac_status" >&5
+  echo "$as_me:4220: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:4175: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4223: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4178: \$? = $ac_status" >&5
+  echo "$as_me:4226: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -4185,7 +4233,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:4188: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:4236: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -4331,13 +4379,13 @@
 for ac_func in getluid setluid
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:4334: checking for $ac_func" >&5
+echo "$as_me:4382: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4340 "configure"
+#line 4388 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -4368,16 +4416,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:4371: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4419: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4374: \$? = $ac_status" >&5
+  echo "$as_me:4422: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:4377: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4425: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4380: \$? = $ac_status" >&5
+  echo "$as_me:4428: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -4387,7 +4435,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:4390: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:4438: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -4443,13 +4491,13 @@
 for ac_func in getluid setluid
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:4446: checking for $ac_func" >&5
+echo "$as_me:4494: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4452 "configure"
+#line 4500 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -4480,16 +4528,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:4483: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4531: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4486: \$? = $ac_status" >&5
+  echo "$as_me:4534: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:4489: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4537: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4492: \$? = $ac_status" >&5
+  echo "$as_me:4540: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -4499,7 +4547,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:4502: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:4550: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -4559,7 +4607,7 @@
 	MANTYPE=cat
 	;;
 *-dec-osf*)
-	echo "$as_me:4562: checking for Digital Unix SIA" >&5
+	echo "$as_me:4610: checking for Digital Unix SIA" >&5
 echo $ECHO_N "checking for Digital Unix SIA... $ECHO_C" >&6
 	no_osfsia=""
 
@@ -4568,7 +4616,7 @@
   withval="$with_osfsia"
 
 			if test "x$withval" = "xno" ; then
-				echo "$as_me:4571: result: disabled" >&5
+				echo "$as_me:4619: result: disabled" >&5
 echo "${ECHO_T}disabled" >&6
 				no_osfsia=1
 			fi
@@ -4576,7 +4624,7 @@
 fi;
 	if test -z "$no_osfsia" ; then
 		if test -f /etc/sia/matrix.conf; then
-			echo "$as_me:4579: result: yes" >&5
+			echo "$as_me:4627: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 			cat >>confdefs.h <<\EOF
 #define HAVE_OSF_SIA 1
@@ -4592,7 +4640,7 @@
 
 			LIBS="$LIBS -lsecurity -ldb -lm -laud"
 		else
-			echo "$as_me:4595: result: no" >&5
+			echo "$as_me:4643: result: no" >&5
 echo "${ECHO_T}no" >&6
 		fi
 	fi
@@ -4688,15 +4736,15 @@
 
 fi;
 
-echo "$as_me:4691: checking compiler and flags for sanity" >&5
+echo "$as_me:4739: checking compiler and flags for sanity" >&5
 echo $ECHO_N "checking compiler and flags for sanity... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
-  { { echo "$as_me:4694: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:4742: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4699 "configure"
+#line 4747 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -4704,26 +4752,26 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:4707: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4755: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4710: \$? = $ac_status" >&5
+  echo "$as_me:4758: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:4712: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4760: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4715: \$? = $ac_status" >&5
+  echo "$as_me:4763: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-  	echo "$as_me:4717: result: yes" >&5
+  	echo "$as_me:4765: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: program exited with status $ac_status" >&5
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:4724: result: no" >&5
+		echo "$as_me:4772: result: no" >&5
 echo "${ECHO_T}no" >&6
-		{ { echo "$as_me:4726: error: *** compiler cannot create working executables, check config.log ***" >&5
+		{ { echo "$as_me:4774: error: *** compiler cannot create working executables, check config.log ***" >&5
 echo "$as_me: error: *** compiler cannot create working executables, check config.log ***" >&2;}
    { (exit 1); exit 1; }; }
 
@@ -4745,23 +4793,23 @@
 	util.h utime.h utmp.h utmpx.h vis.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:4748: checking for $ac_header" >&5
+echo "$as_me:4796: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4754 "configure"
+#line 4802 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:4758: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:4806: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:4764: \$? = $ac_status" >&5
+  echo "$as_me:4812: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -4780,7 +4828,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:4783: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:4831: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -4791,13 +4839,13 @@
 done
 
 # Checks for libraries.
-echo "$as_me:4794: checking for yp_match" >&5
+echo "$as_me:4842: checking for yp_match" >&5
 echo $ECHO_N "checking for yp_match... $ECHO_C" >&6
 if test "${ac_cv_func_yp_match+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4800 "configure"
+#line 4848 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char yp_match (); below.  */
@@ -4828,16 +4876,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:4831: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4879: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4834: \$? = $ac_status" >&5
+  echo "$as_me:4882: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:4837: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4885: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4840: \$? = $ac_status" >&5
+  echo "$as_me:4888: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_yp_match=yes
 else
@@ -4847,13 +4895,13 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:4850: result: $ac_cv_func_yp_match" >&5
+echo "$as_me:4898: result: $ac_cv_func_yp_match" >&5
 echo "${ECHO_T}$ac_cv_func_yp_match" >&6
 if test $ac_cv_func_yp_match = yes; then
   :
 else
 
-echo "$as_me:4856: checking for yp_match in -lnsl" >&5
+echo "$as_me:4904: checking for yp_match in -lnsl" >&5
 echo $ECHO_N "checking for yp_match in -lnsl... $ECHO_C" >&6
 if test "${ac_cv_lib_nsl_yp_match+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4861,7 +4909,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lnsl  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 4864 "configure"
+#line 4912 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -4880,16 +4928,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:4883: \"$ac_link\"") >&5
+if { (eval echo "$as_me:4931: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4886: \$? = $ac_status" >&5
+  echo "$as_me:4934: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:4889: \"$ac_try\"") >&5
+  { (eval echo "$as_me:4937: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4892: \$? = $ac_status" >&5
+  echo "$as_me:4940: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_nsl_yp_match=yes
 else
@@ -4900,7 +4948,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:4903: result: $ac_cv_lib_nsl_yp_match" >&5
+echo "$as_me:4951: result: $ac_cv_lib_nsl_yp_match" >&5
 echo "${ECHO_T}$ac_cv_lib_nsl_yp_match" >&6
 if test $ac_cv_lib_nsl_yp_match = yes; then
   cat >>confdefs.h <<EOF
@@ -4913,13 +4961,13 @@
 
 fi
 
-echo "$as_me:4916: checking for setsockopt" >&5
+echo "$as_me:4964: checking for setsockopt" >&5
 echo $ECHO_N "checking for setsockopt... $ECHO_C" >&6
 if test "${ac_cv_func_setsockopt+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 4922 "configure"
+#line 4970 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char setsockopt (); below.  */
@@ -4950,16 +4998,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:4953: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5001: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:4956: \$? = $ac_status" >&5
+  echo "$as_me:5004: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:4959: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5007: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:4962: \$? = $ac_status" >&5
+  echo "$as_me:5010: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_setsockopt=yes
 else
@@ -4969,13 +5017,13 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:4972: result: $ac_cv_func_setsockopt" >&5
+echo "$as_me:5020: result: $ac_cv_func_setsockopt" >&5
 echo "${ECHO_T}$ac_cv_func_setsockopt" >&6
 if test $ac_cv_func_setsockopt = yes; then
   :
 else
 
-echo "$as_me:4978: checking for setsockopt in -lsocket" >&5
+echo "$as_me:5026: checking for setsockopt in -lsocket" >&5
 echo $ECHO_N "checking for setsockopt in -lsocket... $ECHO_C" >&6
 if test "${ac_cv_lib_socket_setsockopt+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -4983,7 +5031,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lsocket  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 4986 "configure"
+#line 5034 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5002,16 +5050,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5005: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5053: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5008: \$? = $ac_status" >&5
+  echo "$as_me:5056: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5011: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5059: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5014: \$? = $ac_status" >&5
+  echo "$as_me:5062: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_socket_setsockopt=yes
 else
@@ -5022,7 +5070,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5025: result: $ac_cv_lib_socket_setsockopt" >&5
+echo "$as_me:5073: result: $ac_cv_lib_socket_setsockopt" >&5
 echo "${ECHO_T}$ac_cv_lib_socket_setsockopt" >&6
 if test $ac_cv_lib_socket_setsockopt = yes; then
   cat >>confdefs.h <<EOF
@@ -5037,7 +5085,7 @@
 
 if test "x$with_tcp_wrappers" != "xno" ; then
     if test "x$do_sco3_extra_lib_check" = "xyes" ; then
-	echo "$as_me:5040: checking for innetgr in -lrpc" >&5
+	echo "$as_me:5088: checking for innetgr in -lrpc" >&5
 echo $ECHO_N "checking for innetgr in -lrpc... $ECHO_C" >&6
 if test "${ac_cv_lib_rpc_innetgr+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5045,7 +5093,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lrpc -lyp -lrpc $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 5048 "configure"
+#line 5096 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5064,16 +5112,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5067: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5115: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5070: \$? = $ac_status" >&5
+  echo "$as_me:5118: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5073: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5121: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5076: \$? = $ac_status" >&5
+  echo "$as_me:5124: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_rpc_innetgr=yes
 else
@@ -5084,7 +5132,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5087: result: $ac_cv_lib_rpc_innetgr" >&5
+echo "$as_me:5135: result: $ac_cv_lib_rpc_innetgr" >&5
 echo "${ECHO_T}$ac_cv_lib_rpc_innetgr" >&6
 if test $ac_cv_lib_rpc_innetgr = yes; then
   LIBS="-lrpc -lyp -lrpc $LIBS"
@@ -5096,13 +5144,13 @@
 for ac_func in dirname
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:5099: checking for $ac_func" >&5
+echo "$as_me:5147: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5105 "configure"
+#line 5153 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -5133,16 +5181,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5136: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5184: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5139: \$? = $ac_status" >&5
+  echo "$as_me:5187: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5142: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5190: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5145: \$? = $ac_status" >&5
+  echo "$as_me:5193: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -5152,7 +5200,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:5155: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:5203: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -5162,23 +5210,23 @@
 for ac_header in libgen.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:5165: checking for $ac_header" >&5
+echo "$as_me:5213: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5171 "configure"
+#line 5219 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:5175: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:5223: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:5181: \$? = $ac_status" >&5
+  echo "$as_me:5229: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -5197,7 +5245,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:5200: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:5248: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -5209,7 +5257,7 @@
 
 else
 
-	echo "$as_me:5212: checking for dirname in -lgen" >&5
+	echo "$as_me:5260: checking for dirname in -lgen" >&5
 echo $ECHO_N "checking for dirname in -lgen... $ECHO_C" >&6
 if test "${ac_cv_lib_gen_dirname+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5217,7 +5265,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgen  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 5220 "configure"
+#line 5268 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5236,16 +5284,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5239: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5287: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5242: \$? = $ac_status" >&5
+  echo "$as_me:5290: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5245: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5293: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5248: \$? = $ac_status" >&5
+  echo "$as_me:5296: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_gen_dirname=yes
 else
@@ -5256,11 +5304,11 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5259: result: $ac_cv_lib_gen_dirname" >&5
+echo "$as_me:5307: result: $ac_cv_lib_gen_dirname" >&5
 echo "${ECHO_T}$ac_cv_lib_gen_dirname" >&6
 if test $ac_cv_lib_gen_dirname = yes; then
 
-		echo "$as_me:5263: checking for broken dirname" >&5
+		echo "$as_me:5311: checking for broken dirname" >&5
 echo $ECHO_N "checking for broken dirname... $ECHO_C" >&6
 if test "${ac_cv_have_broken_dirname+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5269,12 +5317,12 @@
 			save_LIBS="$LIBS"
 			LIBS="$LIBS -lgen"
 			if test "$cross_compiling" = yes; then
-  { { echo "$as_me:5272: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:5320: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5277 "configure"
+#line 5325 "configure"
 #include "confdefs.h"
 
 #include <libgen.h>
@@ -5294,15 +5342,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:5297: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5345: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5300: \$? = $ac_status" >&5
+  echo "$as_me:5348: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:5302: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5350: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5305: \$? = $ac_status" >&5
+  echo "$as_me:5353: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_broken_dirname="no"
 else
@@ -5317,7 +5365,7 @@
 			LIBS="$save_LIBS"
 
 fi
-echo "$as_me:5320: result: $ac_cv_have_broken_dirname" >&5
+echo "$as_me:5368: result: $ac_cv_have_broken_dirname" >&5
 echo "${ECHO_T}$ac_cv_have_broken_dirname" >&6
 		if test "x$ac_cv_have_broken_dirname" = "xno" ; then
 			LIBS="$LIBS -lgen"
@@ -5328,23 +5376,23 @@
 for ac_header in libgen.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:5331: checking for $ac_header" >&5
+echo "$as_me:5379: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5337 "configure"
+#line 5385 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:5341: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:5389: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:5347: \$? = $ac_status" >&5
+  echo "$as_me:5395: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -5363,7 +5411,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:5366: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:5414: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -5380,13 +5428,13 @@
 fi
 done
 
-echo "$as_me:5383: checking for getspnam" >&5
+echo "$as_me:5431: checking for getspnam" >&5
 echo $ECHO_N "checking for getspnam... $ECHO_C" >&6
 if test "${ac_cv_func_getspnam+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5389 "configure"
+#line 5437 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char getspnam (); below.  */
@@ -5417,16 +5465,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5420: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5468: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5423: \$? = $ac_status" >&5
+  echo "$as_me:5471: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5426: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5474: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5429: \$? = $ac_status" >&5
+  echo "$as_me:5477: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_getspnam=yes
 else
@@ -5436,12 +5484,12 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:5439: result: $ac_cv_func_getspnam" >&5
+echo "$as_me:5487: result: $ac_cv_func_getspnam" >&5
 echo "${ECHO_T}$ac_cv_func_getspnam" >&6
 if test $ac_cv_func_getspnam = yes; then
   :
 else
-  echo "$as_me:5444: checking for getspnam in -lgen" >&5
+  echo "$as_me:5492: checking for getspnam in -lgen" >&5
 echo $ECHO_N "checking for getspnam in -lgen... $ECHO_C" >&6
 if test "${ac_cv_lib_gen_getspnam+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5449,7 +5497,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgen  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 5452 "configure"
+#line 5500 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5468,16 +5516,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5471: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5519: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5474: \$? = $ac_status" >&5
+  echo "$as_me:5522: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5477: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5525: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5480: \$? = $ac_status" >&5
+  echo "$as_me:5528: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_gen_getspnam=yes
 else
@@ -5488,7 +5536,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5491: result: $ac_cv_lib_gen_getspnam" >&5
+echo "$as_me:5539: result: $ac_cv_lib_gen_getspnam" >&5
 echo "${ECHO_T}$ac_cv_lib_gen_getspnam" >&6
 if test $ac_cv_lib_gen_getspnam = yes; then
   LIBS="$LIBS -lgen"
@@ -5496,7 +5544,7 @@
 
 fi
 
-echo "$as_me:5499: checking for library containing basename" >&5
+echo "$as_me:5547: checking for library containing basename" >&5
 echo $ECHO_N "checking for library containing basename... $ECHO_C" >&6
 if test "${ac_cv_search_basename+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5504,7 +5552,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_basename=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 5507 "configure"
+#line 5555 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5523,16 +5571,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5526: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5574: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5529: \$? = $ac_status" >&5
+  echo "$as_me:5577: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5532: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5580: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5535: \$? = $ac_status" >&5
+  echo "$as_me:5583: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_basename="none required"
 else
@@ -5544,7 +5592,7 @@
   for ac_lib in gen; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 5547 "configure"
+#line 5595 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5563,16 +5611,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5566: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5614: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5569: \$? = $ac_status" >&5
+  echo "$as_me:5617: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5572: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5620: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5575: \$? = $ac_status" >&5
+  echo "$as_me:5623: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_basename="-l$ac_lib"
 break
@@ -5585,7 +5633,7 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:5588: result: $ac_cv_search_basename" >&5
+echo "$as_me:5636: result: $ac_cv_search_basename" >&5
 echo "${ECHO_T}$ac_cv_search_basename" >&6
 if test "$ac_cv_search_basename" != no; then
   test "$ac_cv_search_basename" = "none required" || LIBS="$ac_cv_search_basename $LIBS"
@@ -5613,7 +5661,7 @@
   withval="$with_zlib"
 
 		if test "x$withval" = "xno" ; then
-			{ { echo "$as_me:5616: error: *** zlib is required ***" >&5
+			{ { echo "$as_me:5664: error: *** zlib is required ***" >&5
 echo "$as_me: error: *** zlib is required ***" >&2;}
    { (exit 1); exit 1; }; }
 		fi
@@ -5638,7 +5686,7 @@
 
 fi;
 
-echo "$as_me:5641: checking for deflate in -lz" >&5
+echo "$as_me:5689: checking for deflate in -lz" >&5
 echo $ECHO_N "checking for deflate in -lz... $ECHO_C" >&6
 if test "${ac_cv_lib_z_deflate+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5646,7 +5694,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lz  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 5649 "configure"
+#line 5697 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5665,16 +5713,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5668: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5716: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5671: \$? = $ac_status" >&5
+  echo "$as_me:5719: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5674: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5722: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5677: \$? = $ac_status" >&5
+  echo "$as_me:5725: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_z_deflate=yes
 else
@@ -5685,7 +5733,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5688: result: $ac_cv_lib_z_deflate" >&5
+echo "$as_me:5736: result: $ac_cv_lib_z_deflate" >&5
 echo "${ECHO_T}$ac_cv_lib_z_deflate" >&6
 if test $ac_cv_lib_z_deflate = yes; then
   cat >>confdefs.h <<EOF
@@ -5695,18 +5743,18 @@
   LIBS="-lz $LIBS"
 
 else
-  { { echo "$as_me:5698: error: *** zlib missing - please install first or check config.log ***" >&5
+  { { echo "$as_me:5746: error: *** zlib missing - please install first or check config.log ***" >&5
 echo "$as_me: error: *** zlib missing - please install first or check config.log ***" >&2;}
    { (exit 1); exit 1; }; }
 fi
 
-echo "$as_me:5703: checking for strcasecmp" >&5
+echo "$as_me:5751: checking for strcasecmp" >&5
 echo $ECHO_N "checking for strcasecmp... $ECHO_C" >&6
 if test "${ac_cv_func_strcasecmp+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5709 "configure"
+#line 5757 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char strcasecmp (); below.  */
@@ -5737,16 +5785,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5740: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5788: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5743: \$? = $ac_status" >&5
+  echo "$as_me:5791: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5746: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5794: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5749: \$? = $ac_status" >&5
+  echo "$as_me:5797: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_strcasecmp=yes
 else
@@ -5756,12 +5804,12 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:5759: result: $ac_cv_func_strcasecmp" >&5
+echo "$as_me:5807: result: $ac_cv_func_strcasecmp" >&5
 echo "${ECHO_T}$ac_cv_func_strcasecmp" >&6
 if test $ac_cv_func_strcasecmp = yes; then
   :
 else
-   echo "$as_me:5764: checking for strcasecmp in -lresolv" >&5
+   echo "$as_me:5812: checking for strcasecmp in -lresolv" >&5
 echo $ECHO_N "checking for strcasecmp in -lresolv... $ECHO_C" >&6
 if test "${ac_cv_lib_resolv_strcasecmp+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5769,7 +5817,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lresolv  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 5772 "configure"
+#line 5820 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5788,16 +5836,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5791: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5839: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5794: \$? = $ac_status" >&5
+  echo "$as_me:5842: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5797: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5845: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5800: \$? = $ac_status" >&5
+  echo "$as_me:5848: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_resolv_strcasecmp=yes
 else
@@ -5808,7 +5856,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5811: result: $ac_cv_lib_resolv_strcasecmp" >&5
+echo "$as_me:5859: result: $ac_cv_lib_resolv_strcasecmp" >&5
 echo "${ECHO_T}$ac_cv_lib_resolv_strcasecmp" >&6
 if test $ac_cv_lib_resolv_strcasecmp = yes; then
   LIBS="$LIBS -lresolv"
@@ -5816,13 +5864,13 @@
 
 fi
 
-echo "$as_me:5819: checking for utimes" >&5
+echo "$as_me:5867: checking for utimes" >&5
 echo $ECHO_N "checking for utimes... $ECHO_C" >&6
 if test "${ac_cv_func_utimes+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5825 "configure"
+#line 5873 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char utimes (); below.  */
@@ -5853,16 +5901,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5856: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5904: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5859: \$? = $ac_status" >&5
+  echo "$as_me:5907: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5862: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5910: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5865: \$? = $ac_status" >&5
+  echo "$as_me:5913: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_utimes=yes
 else
@@ -5872,12 +5920,12 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:5875: result: $ac_cv_func_utimes" >&5
+echo "$as_me:5923: result: $ac_cv_func_utimes" >&5
 echo "${ECHO_T}$ac_cv_func_utimes" >&6
 if test $ac_cv_func_utimes = yes; then
   :
 else
-   echo "$as_me:5880: checking for utimes in -lc89" >&5
+   echo "$as_me:5928: checking for utimes in -lc89" >&5
 echo $ECHO_N "checking for utimes in -lc89... $ECHO_C" >&6
 if test "${ac_cv_lib_c89_utimes+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5885,7 +5933,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lc89  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 5888 "configure"
+#line 5936 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -5904,16 +5952,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:5907: \"$ac_link\"") >&5
+if { (eval echo "$as_me:5955: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:5910: \$? = $ac_status" >&5
+  echo "$as_me:5958: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:5913: \"$ac_try\"") >&5
+  { (eval echo "$as_me:5961: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:5916: \$? = $ac_status" >&5
+  echo "$as_me:5964: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_c89_utimes=yes
 else
@@ -5924,7 +5972,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:5927: result: $ac_cv_lib_c89_utimes" >&5
+echo "$as_me:5975: result: $ac_cv_lib_c89_utimes" >&5
 echo "${ECHO_T}$ac_cv_lib_c89_utimes" >&6
 if test $ac_cv_lib_c89_utimes = yes; then
   cat >>confdefs.h <<\EOF
@@ -5939,23 +5987,23 @@
 for ac_header in libutil.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:5942: checking for $ac_header" >&5
+echo "$as_me:5990: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 5948 "configure"
+#line 5996 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:5952: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:6000: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:5958: \$? = $ac_status" >&5
+  echo "$as_me:6006: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -5974,7 +6022,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:5977: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:6025: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -5984,7 +6032,7 @@
 fi
 done
 
-echo "$as_me:5987: checking for library containing login" >&5
+echo "$as_me:6035: checking for library containing login" >&5
 echo $ECHO_N "checking for library containing login... $ECHO_C" >&6
 if test "${ac_cv_search_login+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -5992,7 +6040,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_login=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 5995 "configure"
+#line 6043 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6011,16 +6059,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6014: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6062: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6017: \$? = $ac_status" >&5
+  echo "$as_me:6065: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6020: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6068: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6023: \$? = $ac_status" >&5
+  echo "$as_me:6071: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_login="none required"
 else
@@ -6032,7 +6080,7 @@
   for ac_lib in util bsd; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 6035 "configure"
+#line 6083 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6051,16 +6099,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6054: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6102: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6057: \$? = $ac_status" >&5
+  echo "$as_me:6105: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6060: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6108: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6063: \$? = $ac_status" >&5
+  echo "$as_me:6111: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_login="-l$ac_lib"
 break
@@ -6073,7 +6121,7 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:6076: result: $ac_cv_search_login" >&5
+echo "$as_me:6124: result: $ac_cv_search_login" >&5
 echo "${ECHO_T}$ac_cv_search_login" >&6
 if test "$ac_cv_search_login" != no; then
   test "$ac_cv_search_login" = "none required" || LIBS="$ac_cv_search_login $LIBS"
@@ -6086,13 +6134,13 @@
 for ac_func in logout updwtmp logwtmp
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:6089: checking for $ac_func" >&5
+echo "$as_me:6137: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6095 "configure"
+#line 6143 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -6123,16 +6171,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6126: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6174: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6129: \$? = $ac_status" >&5
+  echo "$as_me:6177: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6132: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6180: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6135: \$? = $ac_status" >&5
+  echo "$as_me:6183: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -6142,7 +6190,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:6145: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:6193: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -6155,13 +6203,13 @@
 for ac_func in strftime
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:6158: checking for $ac_func" >&5
+echo "$as_me:6206: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6164 "configure"
+#line 6212 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -6192,16 +6240,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6195: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6243: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6198: \$? = $ac_status" >&5
+  echo "$as_me:6246: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6201: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6249: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6204: \$? = $ac_status" >&5
+  echo "$as_me:6252: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -6211,7 +6259,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:6214: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:6262: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -6220,7 +6268,7 @@
 
 else
   # strftime is in -lintl on SCO UNIX.
-echo "$as_me:6223: checking for strftime in -lintl" >&5
+echo "$as_me:6271: checking for strftime in -lintl" >&5
 echo $ECHO_N "checking for strftime in -lintl... $ECHO_C" >&6
 if test "${ac_cv_lib_intl_strftime+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -6228,7 +6276,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lintl  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 6231 "configure"
+#line 6279 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6247,16 +6295,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6250: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6298: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6253: \$? = $ac_status" >&5
+  echo "$as_me:6301: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6256: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6304: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6259: \$? = $ac_status" >&5
+  echo "$as_me:6307: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_intl_strftime=yes
 else
@@ -6267,7 +6315,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:6270: result: $ac_cv_lib_intl_strftime" >&5
+echo "$as_me:6318: result: $ac_cv_lib_intl_strftime" >&5
 echo "${ECHO_T}$ac_cv_lib_intl_strftime" >&6
 if test $ac_cv_lib_intl_strftime = yes; then
   cat >>confdefs.h <<\EOF
@@ -6281,10 +6329,10 @@
 done
 
 # Check for ALTDIRFUNC glob() extension
-echo "$as_me:6284: checking for GLOB_ALTDIRFUNC support" >&5
+echo "$as_me:6332: checking for GLOB_ALTDIRFUNC support" >&5
 echo $ECHO_N "checking for GLOB_ALTDIRFUNC support... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 6287 "configure"
+#line 6335 "configure"
 #include "confdefs.h"
 
 		#include <glob.h>
@@ -6300,22 +6348,22 @@
 #define GLOB_HAS_ALTDIRFUNC 1
 EOF
 
-		echo "$as_me:6303: result: yes" >&5
+		echo "$as_me:6351: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
 
-		echo "$as_me:6308: result: no" >&5
+		echo "$as_me:6356: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
 rm -f conftest*
 
 # Check for g.gl_matchc glob() extension
-echo "$as_me:6315: checking for gl_matchc field in glob_t" >&5
+echo "$as_me:6363: checking for gl_matchc field in glob_t" >&5
 echo $ECHO_N "checking for gl_matchc field in glob_t... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 6318 "configure"
+#line 6366 "configure"
 #include "confdefs.h"
 
                 #include <glob.h>
@@ -6329,26 +6377,26 @@
 #define GLOB_HAS_GL_MATCHC 1
 EOF
 
-                echo "$as_me:6332: result: yes" >&5
+                echo "$as_me:6380: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
 
-                echo "$as_me:6337: result: no" >&5
+                echo "$as_me:6385: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
 rm -f conftest*
 
-echo "$as_me:6343: checking whether struct dirent allocates space for d_name" >&5
+echo "$as_me:6391: checking whether struct dirent allocates space for d_name" >&5
 echo $ECHO_N "checking whether struct dirent allocates space for d_name... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
-  { { echo "$as_me:6346: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:6394: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6351 "configure"
+#line 6399 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -6357,24 +6405,24 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:6360: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6408: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6363: \$? = $ac_status" >&5
+  echo "$as_me:6411: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:6365: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6413: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6368: \$? = $ac_status" >&5
+  echo "$as_me:6416: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-  echo "$as_me:6370: result: yes" >&5
+  echo "$as_me:6418: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: program exited with status $ac_status" >&5
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:6377: result: no" >&5
+		echo "$as_me:6425: result: no" >&5
 echo "${ECHO_T}no" >&6
 		cat >>confdefs.h <<\EOF
 #define BROKEN_ONE_BYTE_DIRENT_D_NAME 1
@@ -6405,15 +6453,15 @@
 			LIBS="-lskey $LIBS"
 			SKEY_MSG="yes"
 
-			echo "$as_me:6408: checking for s/key support" >&5
+			echo "$as_me:6456: checking for s/key support" >&5
 echo $ECHO_N "checking for s/key support... $ECHO_C" >&6
 			if test "$cross_compiling" = yes; then
-  { { echo "$as_me:6411: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:6459: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6416 "configure"
+#line 6464 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -6422,26 +6470,26 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:6425: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6473: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6428: \$? = $ac_status" >&5
+  echo "$as_me:6476: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:6430: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6478: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6433: \$? = $ac_status" >&5
+  echo "$as_me:6481: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-  echo "$as_me:6435: result: yes" >&5
+  echo "$as_me:6483: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: program exited with status $ac_status" >&5
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-					echo "$as_me:6442: result: no" >&5
+					echo "$as_me:6490: result: no" >&5
 echo "${ECHO_T}no" >&6
-					{ { echo "$as_me:6444: error: ** Incomplete or missing s/key libraries." >&5
+					{ { echo "$as_me:6492: error: ** Incomplete or missing s/key libraries." >&5
 echo "$as_me: error: ** Incomplete or missing s/key libraries." >&2;}
    { (exit 1); exit 1; }; }
 
@@ -6485,10 +6533,10 @@
 			fi
 			LIBWRAP="-lwrap"
 			LIBS="$LIBWRAP $LIBS"
-			echo "$as_me:6488: checking for libwrap" >&5
+			echo "$as_me:6536: checking for libwrap" >&5
 echo $ECHO_N "checking for libwrap... $ECHO_C" >&6
 			cat >conftest.$ac_ext <<_ACEOF
-#line 6491 "configure"
+#line 6539 "configure"
 #include "confdefs.h"
 
 #include <tcpd.h>
@@ -6503,19 +6551,19 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6506: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6554: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6509: \$? = $ac_status" >&5
+  echo "$as_me:6557: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6512: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6560: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6515: \$? = $ac_status" >&5
+  echo "$as_me:6563: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
-					echo "$as_me:6518: result: yes" >&5
+					echo "$as_me:6566: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 					cat >>confdefs.h <<\EOF
 #define LIBWRAP 1
@@ -6527,7 +6575,7 @@
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-					{ { echo "$as_me:6530: error: *** libwrap missing" >&5
+					{ { echo "$as_me:6578: error: *** libwrap missing" >&5
 echo "$as_me: error: *** libwrap missing" >&2;}
    { (exit 1); exit 1; }; }
 
@@ -6554,13 +6602,13 @@
 
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:6557: checking for $ac_func" >&5
+echo "$as_me:6605: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6563 "configure"
+#line 6611 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -6591,16 +6639,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6594: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6642: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6597: \$? = $ac_status" >&5
+  echo "$as_me:6645: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6600: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6648: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6603: \$? = $ac_status" >&5
+  echo "$as_me:6651: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -6610,7 +6658,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:6613: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:6661: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -6625,13 +6673,13 @@
 for ac_func in gai_strerror
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:6628: checking for $ac_func" >&5
+echo "$as_me:6676: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6634 "configure"
+#line 6682 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -6662,16 +6710,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6665: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6713: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6668: \$? = $ac_status" >&5
+  echo "$as_me:6716: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6671: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6719: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6674: \$? = $ac_status" >&5
+  echo "$as_me:6722: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -6681,7 +6729,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:6684: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:6732: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -6693,7 +6741,7 @@
 EOF
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 6696 "configure"
+#line 6744 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -6713,16 +6761,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:6716: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:6764: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:6719: \$? = $ac_status" >&5
+  echo "$as_me:6767: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:6722: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6770: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6725: \$? = $ac_status" >&5
+  echo "$as_me:6773: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 cat >>confdefs.h <<\EOF
@@ -6737,7 +6785,7 @@
 fi
 done
 
-echo "$as_me:6740: checking for library containing nanosleep" >&5
+echo "$as_me:6788: checking for library containing nanosleep" >&5
 echo $ECHO_N "checking for library containing nanosleep... $ECHO_C" >&6
 if test "${ac_cv_search_nanosleep+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -6745,7 +6793,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_nanosleep=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 6748 "configure"
+#line 6796 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6764,16 +6812,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6767: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6815: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6770: \$? = $ac_status" >&5
+  echo "$as_me:6818: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6773: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6821: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6776: \$? = $ac_status" >&5
+  echo "$as_me:6824: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_nanosleep="none required"
 else
@@ -6785,7 +6833,7 @@
   for ac_lib in rt posix4; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 6788 "configure"
+#line 6836 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -6804,16 +6852,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:6807: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6855: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6810: \$? = $ac_status" >&5
+  echo "$as_me:6858: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:6813: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6861: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6816: \$? = $ac_status" >&5
+  echo "$as_me:6864: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_nanosleep="-l$ac_lib"
 break
@@ -6826,7 +6874,7 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:6829: result: $ac_cv_search_nanosleep" >&5
+echo "$as_me:6877: result: $ac_cv_search_nanosleep" >&5
 echo "${ECHO_T}$ac_cv_search_nanosleep" >&6
 if test "$ac_cv_search_nanosleep" != no; then
   test "$ac_cv_search_nanosleep" = "none required" || LIBS="$ac_cv_search_nanosleep $LIBS"
@@ -6836,13 +6884,13 @@
 
 fi
 
-echo "$as_me:6839: checking for ANSI C header files" >&5
+echo "$as_me:6887: checking for ANSI C header files" >&5
 echo $ECHO_N "checking for ANSI C header files... $ECHO_C" >&6
 if test "${ac_cv_header_stdc+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6845 "configure"
+#line 6893 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 #include <stdarg.h>
@@ -6850,13 +6898,13 @@
 #include <float.h>
 
 _ACEOF
-if { (eval echo "$as_me:6853: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:6901: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:6859: \$? = $ac_status" >&5
+  echo "$as_me:6907: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -6878,7 +6926,7 @@
 if test $ac_cv_header_stdc = yes; then
   # SunOS 4.x string.h does not declare mem*, contrary to ANSI.
   cat >conftest.$ac_ext <<_ACEOF
-#line 6881 "configure"
+#line 6929 "configure"
 #include "confdefs.h"
 #include <string.h>
 
@@ -6896,7 +6944,7 @@
 if test $ac_cv_header_stdc = yes; then
   # ISC 2.0.2 stdlib.h does not declare free, contrary to ANSI.
   cat >conftest.$ac_ext <<_ACEOF
-#line 6899 "configure"
+#line 6947 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 
@@ -6917,7 +6965,7 @@
   :
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6920 "configure"
+#line 6968 "configure"
 #include "confdefs.h"
 #include <ctype.h>
 #if ((' ' & 0x0FF) == 0x020)
@@ -6943,15 +6991,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:6946: \"$ac_link\"") >&5
+if { (eval echo "$as_me:6994: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:6949: \$? = $ac_status" >&5
+  echo "$as_me:6997: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:6951: \"$ac_try\"") >&5
+  { (eval echo "$as_me:6999: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:6954: \$? = $ac_status" >&5
+  echo "$as_me:7002: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   :
 else
@@ -6964,7 +7012,7 @@
 fi
 fi
 fi
-echo "$as_me:6967: result: $ac_cv_header_stdc" >&5
+echo "$as_me:7015: result: $ac_cv_header_stdc" >&5
 echo "${ECHO_T}$ac_cv_header_stdc" >&6
 if test $ac_cv_header_stdc = yes; then
 
@@ -6980,28 +7028,28 @@
                   inttypes.h stdint.h unistd.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:6983: checking for $ac_header" >&5
+echo "$as_me:7031: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 6989 "configure"
+#line 7037 "configure"
 #include "confdefs.h"
 $ac_includes_default
 #include <$ac_header>
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:6995: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:7043: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:6998: \$? = $ac_status" >&5
+  echo "$as_me:7046: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:7001: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7049: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7004: \$? = $ac_status" >&5
+  echo "$as_me:7052: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_Header=yes"
 else
@@ -7011,7 +7059,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:7014: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:7062: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7021,13 +7069,13 @@
 fi
 done
 
-echo "$as_me:7024: checking whether strsep is declared" >&5
+echo "$as_me:7072: checking whether strsep is declared" >&5
 echo $ECHO_N "checking whether strsep is declared... $ECHO_C" >&6
 if test "${ac_cv_have_decl_strsep+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7030 "configure"
+#line 7078 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -7042,16 +7090,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:7045: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:7093: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:7048: \$? = $ac_status" >&5
+  echo "$as_me:7096: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:7051: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7099: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7054: \$? = $ac_status" >&5
+  echo "$as_me:7102: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_have_decl_strsep=yes
 else
@@ -7061,20 +7109,20 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:7064: result: $ac_cv_have_decl_strsep" >&5
+echo "$as_me:7112: result: $ac_cv_have_decl_strsep" >&5
 echo "${ECHO_T}$ac_cv_have_decl_strsep" >&6
 if test $ac_cv_have_decl_strsep = yes; then
 
 for ac_func in strsep
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7071: checking for $ac_func" >&5
+echo "$as_me:7119: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7077 "configure"
+#line 7125 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7105,16 +7153,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7108: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7156: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7111: \$? = $ac_status" >&5
+  echo "$as_me:7159: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7114: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7162: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7117: \$? = $ac_status" >&5
+  echo "$as_me:7165: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7124,7 +7172,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7127: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7175: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7136,13 +7184,13 @@
 
 fi
 
-echo "$as_me:7139: checking whether getrusage is declared" >&5
+echo "$as_me:7187: checking whether getrusage is declared" >&5
 echo $ECHO_N "checking whether getrusage is declared... $ECHO_C" >&6
 if test "${ac_cv_have_decl_getrusage+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7145 "configure"
+#line 7193 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -7157,16 +7205,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:7160: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:7208: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:7163: \$? = $ac_status" >&5
+  echo "$as_me:7211: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:7166: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7214: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7169: \$? = $ac_status" >&5
+  echo "$as_me:7217: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_have_decl_getrusage=yes
 else
@@ -7176,20 +7224,20 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:7179: result: $ac_cv_have_decl_getrusage" >&5
+echo "$as_me:7227: result: $ac_cv_have_decl_getrusage" >&5
 echo "${ECHO_T}$ac_cv_have_decl_getrusage" >&6
 if test $ac_cv_have_decl_getrusage = yes; then
 
 for ac_func in getrusage
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7186: checking for $ac_func" >&5
+echo "$as_me:7234: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7192 "configure"
+#line 7240 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7220,16 +7268,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7223: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7271: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7226: \$? = $ac_status" >&5
+  echo "$as_me:7274: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7229: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7277: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7232: \$? = $ac_status" >&5
+  echo "$as_me:7280: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7239,7 +7287,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7242: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7290: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7251,13 +7299,13 @@
 
 fi
 
-echo "$as_me:7254: checking whether tcsendbreak is declared" >&5
+echo "$as_me:7302: checking whether tcsendbreak is declared" >&5
 echo $ECHO_N "checking whether tcsendbreak is declared... $ECHO_C" >&6
 if test "${ac_cv_have_decl_tcsendbreak+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7260 "configure"
+#line 7308 "configure"
 #include "confdefs.h"
 #include <termios.h>
 
@@ -7273,16 +7321,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:7276: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:7324: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:7279: \$? = $ac_status" >&5
+  echo "$as_me:7327: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:7282: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7330: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7285: \$? = $ac_status" >&5
+  echo "$as_me:7333: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_have_decl_tcsendbreak=yes
 else
@@ -7292,7 +7340,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:7295: result: $ac_cv_have_decl_tcsendbreak" >&5
+echo "$as_me:7343: result: $ac_cv_have_decl_tcsendbreak" >&5
 echo "${ECHO_T}$ac_cv_have_decl_tcsendbreak" >&6
 if test $ac_cv_have_decl_tcsendbreak = yes; then
   cat >>confdefs.h <<\EOF
@@ -7304,13 +7352,13 @@
 for ac_func in tcsendbreak
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7307: checking for $ac_func" >&5
+echo "$as_me:7355: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7313 "configure"
+#line 7361 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7341,16 +7389,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7344: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7392: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7347: \$? = $ac_status" >&5
+  echo "$as_me:7395: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7350: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7398: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7353: \$? = $ac_status" >&5
+  echo "$as_me:7401: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7360,7 +7408,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7363: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7411: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7375,13 +7423,13 @@
 for ac_func in gettimeofday time
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7378: checking for $ac_func" >&5
+echo "$as_me:7426: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7384 "configure"
+#line 7432 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7412,16 +7460,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7415: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7463: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7418: \$? = $ac_status" >&5
+  echo "$as_me:7466: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7421: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7469: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7424: \$? = $ac_status" >&5
+  echo "$as_me:7472: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7431,7 +7479,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7434: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7482: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7444,13 +7492,13 @@
 for ac_func in endutent getutent getutid getutline pututline setutent
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7447: checking for $ac_func" >&5
+echo "$as_me:7495: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7453 "configure"
+#line 7501 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7481,16 +7529,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7484: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7532: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7487: \$? = $ac_status" >&5
+  echo "$as_me:7535: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7490: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7538: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7493: \$? = $ac_status" >&5
+  echo "$as_me:7541: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7500,7 +7548,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7503: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7551: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7513,13 +7561,13 @@
 for ac_func in utmpname
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7516: checking for $ac_func" >&5
+echo "$as_me:7564: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7522 "configure"
+#line 7570 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7550,16 +7598,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7553: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7601: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7556: \$? = $ac_status" >&5
+  echo "$as_me:7604: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7559: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7607: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7562: \$? = $ac_status" >&5
+  echo "$as_me:7610: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7569,7 +7617,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7572: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7620: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7582,13 +7630,13 @@
 for ac_func in endutxent getutxent getutxid getutxline pututxline
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7585: checking for $ac_func" >&5
+echo "$as_me:7633: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7591 "configure"
+#line 7639 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7619,16 +7667,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7622: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7670: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7625: \$? = $ac_status" >&5
+  echo "$as_me:7673: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7628: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7676: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7631: \$? = $ac_status" >&5
+  echo "$as_me:7679: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7638,7 +7686,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7641: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7689: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7651,13 +7699,13 @@
 for ac_func in setutxent utmpxname
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:7654: checking for $ac_func" >&5
+echo "$as_me:7702: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7660 "configure"
+#line 7708 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -7688,16 +7736,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7691: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7739: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7694: \$? = $ac_status" >&5
+  echo "$as_me:7742: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7697: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7745: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7700: \$? = $ac_status" >&5
+  echo "$as_me:7748: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -7707,7 +7755,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7710: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:7758: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -7717,13 +7765,13 @@
 fi
 done
 
-echo "$as_me:7720: checking for daemon" >&5
+echo "$as_me:7768: checking for daemon" >&5
 echo $ECHO_N "checking for daemon... $ECHO_C" >&6
 if test "${ac_cv_func_daemon+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7726 "configure"
+#line 7774 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char daemon (); below.  */
@@ -7754,16 +7802,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7757: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7805: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7760: \$? = $ac_status" >&5
+  echo "$as_me:7808: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7763: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7811: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7766: \$? = $ac_status" >&5
+  echo "$as_me:7814: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_daemon=yes
 else
@@ -7773,7 +7821,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7776: result: $ac_cv_func_daemon" >&5
+echo "$as_me:7824: result: $ac_cv_func_daemon" >&5
 echo "${ECHO_T}$ac_cv_func_daemon" >&6
 if test $ac_cv_func_daemon = yes; then
   cat >>confdefs.h <<\EOF
@@ -7781,7 +7829,7 @@
 EOF
 
 else
-  echo "$as_me:7784: checking for daemon in -lbsd" >&5
+  echo "$as_me:7832: checking for daemon in -lbsd" >&5
 echo $ECHO_N "checking for daemon in -lbsd... $ECHO_C" >&6
 if test "${ac_cv_lib_bsd_daemon+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -7789,7 +7837,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lbsd  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 7792 "configure"
+#line 7840 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -7808,16 +7856,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7811: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7859: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7814: \$? = $ac_status" >&5
+  echo "$as_me:7862: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7817: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7865: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7820: \$? = $ac_status" >&5
+  echo "$as_me:7868: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_bsd_daemon=yes
 else
@@ -7828,7 +7876,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:7831: result: $ac_cv_lib_bsd_daemon" >&5
+echo "$as_me:7879: result: $ac_cv_lib_bsd_daemon" >&5
 echo "${ECHO_T}$ac_cv_lib_bsd_daemon" >&6
 if test $ac_cv_lib_bsd_daemon = yes; then
   LIBS="$LIBS -lbsd"; cat >>confdefs.h <<\EOF
@@ -7839,13 +7887,13 @@
 
 fi
 
-echo "$as_me:7842: checking for getpagesize" >&5
+echo "$as_me:7890: checking for getpagesize" >&5
 echo $ECHO_N "checking for getpagesize... $ECHO_C" >&6
 if test "${ac_cv_func_getpagesize+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7848 "configure"
+#line 7896 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char getpagesize (); below.  */
@@ -7876,16 +7924,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7879: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7927: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7882: \$? = $ac_status" >&5
+  echo "$as_me:7930: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7885: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7933: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7888: \$? = $ac_status" >&5
+  echo "$as_me:7936: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_getpagesize=yes
 else
@@ -7895,7 +7943,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:7898: result: $ac_cv_func_getpagesize" >&5
+echo "$as_me:7946: result: $ac_cv_func_getpagesize" >&5
 echo "${ECHO_T}$ac_cv_func_getpagesize" >&6
 if test $ac_cv_func_getpagesize = yes; then
   cat >>confdefs.h <<\EOF
@@ -7903,7 +7951,7 @@
 EOF
 
 else
-  echo "$as_me:7906: checking for getpagesize in -lucb" >&5
+  echo "$as_me:7954: checking for getpagesize in -lucb" >&5
 echo $ECHO_N "checking for getpagesize in -lucb... $ECHO_C" >&6
 if test "${ac_cv_lib_ucb_getpagesize+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -7911,7 +7959,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lucb  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 7914 "configure"
+#line 7962 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -7930,16 +7978,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:7933: \"$ac_link\"") >&5
+if { (eval echo "$as_me:7981: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7936: \$? = $ac_status" >&5
+  echo "$as_me:7984: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:7939: \"$ac_try\"") >&5
+  { (eval echo "$as_me:7987: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7942: \$? = $ac_status" >&5
+  echo "$as_me:7990: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_ucb_getpagesize=yes
 else
@@ -7950,7 +7998,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:7953: result: $ac_cv_lib_ucb_getpagesize" >&5
+echo "$as_me:8001: result: $ac_cv_lib_ucb_getpagesize" >&5
 echo "${ECHO_T}$ac_cv_lib_ucb_getpagesize" >&6
 if test $ac_cv_lib_ucb_getpagesize = yes; then
   LIBS="$LIBS -lucb"; cat >>confdefs.h <<\EOF
@@ -7963,15 +8011,15 @@
 
 # Check for broken snprintf
 if test "x$ac_cv_func_snprintf" = "xyes" ; then
-	echo "$as_me:7966: checking whether snprintf correctly terminates long strings" >&5
+	echo "$as_me:8014: checking whether snprintf correctly terminates long strings" >&5
 echo $ECHO_N "checking whether snprintf correctly terminates long strings... $ECHO_C" >&6
 	if test "$cross_compiling" = yes; then
-  { { echo "$as_me:7969: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:8017: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 7974 "configure"
+#line 8022 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -7979,30 +8027,30 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:7982: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8030: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:7985: \$? = $ac_status" >&5
+  echo "$as_me:8033: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:7987: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8035: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:7990: \$? = $ac_status" >&5
+  echo "$as_me:8038: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-  echo "$as_me:7992: result: yes" >&5
+  echo "$as_me:8040: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: program exited with status $ac_status" >&5
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-			echo "$as_me:7999: result: no" >&5
+			echo "$as_me:8047: result: no" >&5
 echo "${ECHO_T}no" >&6
 			cat >>confdefs.h <<\EOF
 #define BROKEN_SNPRINTF 1
 EOF
 
-			{ echo "$as_me:8005: WARNING: ****** Your snprintf() function is broken, complain to your vendor" >&5
+			{ echo "$as_me:8053: WARNING: ****** Your snprintf() function is broken, complain to your vendor" >&5
 echo "$as_me: WARNING: ****** Your snprintf() function is broken, complain to your vendor" >&2;}
 
 fi
@@ -8011,11 +8059,11 @@
 fi
 
 if test "x$ac_cv_func_mkdtemp" = "xyes" ; then
-echo "$as_me:8014: checking for (overly) strict mkstemp" >&5
+echo "$as_me:8062: checking for (overly) strict mkstemp" >&5
 echo $ECHO_N "checking for (overly) strict mkstemp... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
 
-		echo "$as_me:8018: result: yes" >&5
+		echo "$as_me:8066: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 		cat >>confdefs.h <<\EOF
 #define HAVE_STRICT_MKSTEMP 1
@@ -8023,7 +8071,7 @@
 
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8026 "configure"
+#line 8074 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -8035,18 +8083,18 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:8038: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8086: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8041: \$? = $ac_status" >&5
+  echo "$as_me:8089: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:8043: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8091: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8046: \$? = $ac_status" >&5
+  echo "$as_me:8094: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
-		echo "$as_me:8049: result: no" >&5
+		echo "$as_me:8097: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 else
@@ -8054,7 +8102,7 @@
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:8057: result: yes" >&5
+		echo "$as_me:8105: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 		cat >>confdefs.h <<\EOF
 #define HAVE_STRICT_MKSTEMP 1
@@ -8066,15 +8114,15 @@
 fi
 
 if test ! -z "$check_for_openpty_ctty_bug"; then
-	echo "$as_me:8069: checking if openpty correctly handles controlling tty" >&5
+	echo "$as_me:8117: checking if openpty correctly handles controlling tty" >&5
 echo $ECHO_N "checking if openpty correctly handles controlling tty... $ECHO_C" >&6
 	if test "$cross_compiling" = yes; then
-  { { echo "$as_me:8072: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:8120: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8077 "configure"
+#line 8125 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -8111,18 +8159,18 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:8114: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8162: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8117: \$? = $ac_status" >&5
+  echo "$as_me:8165: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:8119: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8167: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8122: \$? = $ac_status" >&5
+  echo "$as_me:8170: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
-			echo "$as_me:8125: result: yes" >&5
+			echo "$as_me:8173: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
@@ -8130,7 +8178,7 @@
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-			echo "$as_me:8133: result: no" >&5
+			echo "$as_me:8181: result: no" >&5
 echo "${ECHO_T}no" >&6
 			cat >>confdefs.h <<\EOF
 #define SSHD_ACQUIRES_CTTY 1
@@ -8141,14 +8189,14 @@
 fi
 fi
 
-echo "$as_me:8144: checking whether getpgrp takes no argument" >&5
+echo "$as_me:8192: checking whether getpgrp takes no argument" >&5
 echo $ECHO_N "checking whether getpgrp takes no argument... $ECHO_C" >&6
 if test "${ac_cv_func_getpgrp_void+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   # Use it with a single arg.
 cat >conftest.$ac_ext <<_ACEOF
-#line 8151 "configure"
+#line 8199 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -8160,16 +8208,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8163: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:8211: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8166: \$? = $ac_status" >&5
+  echo "$as_me:8214: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8169: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8217: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8172: \$? = $ac_status" >&5
+  echo "$as_me:8220: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_func_getpgrp_1=yes
 else
@@ -8180,7 +8228,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 # Use it with no arg.
 cat >conftest.$ac_ext <<_ACEOF
-#line 8183 "configure"
+#line 8231 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -8192,16 +8240,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8195: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:8243: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8198: \$? = $ac_status" >&5
+  echo "$as_me:8246: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8201: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8249: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8204: \$? = $ac_status" >&5
+  echo "$as_me:8252: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_func_getpgrp_0=yes
 else
@@ -8215,12 +8263,12 @@
   yes:no) ac_cv_func_getpgrp_void=yes;;
   no:yes) ac_cv_func_getpgrp_void=false;;
   *) if test "$cross_compiling" = yes; then
-  { { echo "$as_me:8218: error: cannot check getpgrp if cross compiling" >&5
+  { { echo "$as_me:8266: error: cannot check getpgrp if cross compiling" >&5
 echo "$as_me: error: cannot check getpgrp if cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8223 "configure"
+#line 8271 "configure"
 #include "confdefs.h"
 $ac_includes_default
 
@@ -8274,15 +8322,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:8277: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8325: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8280: \$? = $ac_status" >&5
+  echo "$as_me:8328: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:8282: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8330: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8285: \$? = $ac_status" >&5
+  echo "$as_me:8333: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_func_getpgrp_void=yes
 else
@@ -8296,7 +8344,7 @@
 esac # $ac_func_getpgrp_0:$ac_func_getpgrp_1
 
 fi
-echo "$as_me:8299: result: $ac_cv_func_getpgrp_void" >&5
+echo "$as_me:8347: result: $ac_cv_func_getpgrp_void" >&5
 echo "${ECHO_T}$ac_cv_func_getpgrp_void" >&6
 if test $ac_cv_func_getpgrp_void = yes; then
 
@@ -8315,12 +8363,12 @@
 
 		if test "x$withval" != "xno" ; then
 			if test "x$ac_cv_header_security_pam_appl_h" != "xyes" ; then
-				{ { echo "$as_me:8318: error: PAM headers not found" >&5
+				{ { echo "$as_me:8366: error: PAM headers not found" >&5
 echo "$as_me: error: PAM headers not found" >&2;}
    { (exit 1); exit 1; }; }
 			fi
 
-echo "$as_me:8323: checking for dlopen in -ldl" >&5
+echo "$as_me:8371: checking for dlopen in -ldl" >&5
 echo $ECHO_N "checking for dlopen in -ldl... $ECHO_C" >&6
 if test "${ac_cv_lib_dl_dlopen+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -8328,7 +8376,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-ldl  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 8331 "configure"
+#line 8379 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -8347,16 +8395,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8350: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8398: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8353: \$? = $ac_status" >&5
+  echo "$as_me:8401: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8356: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8404: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8359: \$? = $ac_status" >&5
+  echo "$as_me:8407: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_dl_dlopen=yes
 else
@@ -8367,7 +8415,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:8370: result: $ac_cv_lib_dl_dlopen" >&5
+echo "$as_me:8418: result: $ac_cv_lib_dl_dlopen" >&5
 echo "${ECHO_T}$ac_cv_lib_dl_dlopen" >&6
 if test $ac_cv_lib_dl_dlopen = yes; then
   cat >>confdefs.h <<EOF
@@ -8378,7 +8426,7 @@
 
 fi
 
-echo "$as_me:8381: checking for pam_set_item in -lpam" >&5
+echo "$as_me:8429: checking for pam_set_item in -lpam" >&5
 echo $ECHO_N "checking for pam_set_item in -lpam... $ECHO_C" >&6
 if test "${ac_cv_lib_pam_pam_set_item+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -8386,7 +8434,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lpam  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 8389 "configure"
+#line 8437 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -8405,16 +8453,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8408: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8456: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8411: \$? = $ac_status" >&5
+  echo "$as_me:8459: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8414: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8462: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8417: \$? = $ac_status" >&5
+  echo "$as_me:8465: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_pam_pam_set_item=yes
 else
@@ -8425,7 +8473,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:8428: result: $ac_cv_lib_pam_pam_set_item" >&5
+echo "$as_me:8476: result: $ac_cv_lib_pam_pam_set_item" >&5
 echo "${ECHO_T}$ac_cv_lib_pam_pam_set_item" >&6
 if test $ac_cv_lib_pam_pam_set_item = yes; then
   cat >>confdefs.h <<EOF
@@ -8435,7 +8483,7 @@
   LIBS="-lpam $LIBS"
 
 else
-  { { echo "$as_me:8438: error: *** libpam missing" >&5
+  { { echo "$as_me:8486: error: *** libpam missing" >&5
 echo "$as_me: error: *** libpam missing" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -8443,13 +8491,13 @@
 for ac_func in pam_getenvlist
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:8446: checking for $ac_func" >&5
+echo "$as_me:8494: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8452 "configure"
+#line 8500 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -8480,16 +8528,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8483: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8531: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8486: \$? = $ac_status" >&5
+  echo "$as_me:8534: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8489: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8537: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8492: \$? = $ac_status" >&5
+  echo "$as_me:8540: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -8499,7 +8547,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:8502: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:8550: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -8512,13 +8560,13 @@
 for ac_func in pam_putenv
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:8515: checking for $ac_func" >&5
+echo "$as_me:8563: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8521 "configure"
+#line 8569 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -8549,16 +8597,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8552: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8600: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8555: \$? = $ac_status" >&5
+  echo "$as_me:8603: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8558: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8606: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8561: \$? = $ac_status" >&5
+  echo "$as_me:8609: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -8568,7 +8616,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:8571: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:8619: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -8578,7 +8626,6 @@
 fi
 done
 
-			disable_shadow=yes
 			PAM_MSG="yes"
 
 			cat >>confdefs.h <<\EOF
@@ -8598,10 +8645,10 @@
 # Check for older PAM
 if test "x$PAM_MSG" = "xyes" ; then
 	# Check PAM strerror arguments (old PAM)
-	echo "$as_me:8601: checking whether pam_strerror takes only one argument" >&5
+	echo "$as_me:8648: checking whether pam_strerror takes only one argument" >&5
 echo $ECHO_N "checking whether pam_strerror takes only one argument... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 8604 "configure"
+#line 8651 "configure"
 #include "confdefs.h"
 
 #include <stdlib.h>
@@ -8616,18 +8663,18 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:8619: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:8666: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:8622: \$? = $ac_status" >&5
+  echo "$as_me:8669: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:8625: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8672: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8628: \$? = $ac_status" >&5
+  echo "$as_me:8675: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-  echo "$as_me:8630: result: no" >&5
+  echo "$as_me:8677: result: no" >&5
 echo "${ECHO_T}no" >&6
 else
   echo "$as_me: failed program was:" >&5
@@ -8637,7 +8684,7 @@
 #define HAVE_OLD_PAM 1
 EOF
 
-			echo "$as_me:8640: result: yes" >&5
+			echo "$as_me:8687: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 			PAM_MSG="yes (old library)"
 
@@ -8649,7 +8696,7 @@
 # because the system crypt() is more featureful.
 if test "x$check_for_libcrypt_before" = "x1"; then
 
-echo "$as_me:8652: checking for crypt in -lcrypt" >&5
+echo "$as_me:8699: checking for crypt in -lcrypt" >&5
 echo $ECHO_N "checking for crypt in -lcrypt... $ECHO_C" >&6
 if test "${ac_cv_lib_crypt_crypt+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -8657,7 +8704,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lcrypt  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 8660 "configure"
+#line 8707 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -8676,16 +8723,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8679: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8726: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8682: \$? = $ac_status" >&5
+  echo "$as_me:8729: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8685: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8732: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8688: \$? = $ac_status" >&5
+  echo "$as_me:8735: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_crypt_crypt=yes
 else
@@ -8696,7 +8743,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:8699: result: $ac_cv_lib_crypt_crypt" >&5
+echo "$as_me:8746: result: $ac_cv_lib_crypt_crypt" >&5
 echo "${ECHO_T}$ac_cv_lib_crypt_crypt" >&6
 if test $ac_cv_lib_crypt_crypt = yes; then
   cat >>confdefs.h <<EOF
@@ -8741,7 +8788,7 @@
 fi;
 LIBS="$LIBS -lcrypto"
 cat >conftest.$ac_ext <<_ACEOF
-#line 8744 "configure"
+#line 8791 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -8760,16 +8807,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8763: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8810: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8766: \$? = $ac_status" >&5
+  echo "$as_me:8813: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8769: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8816: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8772: \$? = $ac_status" >&5
+  echo "$as_me:8819: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cat >>confdefs.h <<\EOF
 #define HAVE_OPENSSL 1
@@ -8786,7 +8833,7 @@
 		fi
 		CPPFLAGS="-I/usr/local/ssl/include ${saved_CPPFLAGS}"
 		cat >conftest.$ac_ext <<_ACEOF
-#line 8789 "configure"
+#line 8836 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -8805,16 +8852,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:8808: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8855: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8811: \$? = $ac_status" >&5
+  echo "$as_me:8858: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:8814: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8861: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8817: \$? = $ac_status" >&5
+  echo "$as_me:8864: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cat >>confdefs.h <<\EOF
 #define HAVE_OPENSSL 1
@@ -8824,7 +8871,7 @@
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-				{ { echo "$as_me:8827: error: *** Can't find recent OpenSSL libcrypto (see config.log for details) ***" >&5
+				{ { echo "$as_me:8874: error: *** Can't find recent OpenSSL libcrypto (see config.log for details) ***" >&5
 echo "$as_me: error: *** Can't find recent OpenSSL libcrypto (see config.log for details) ***" >&2;}
    { (exit 1); exit 1; }; }
 
@@ -8835,15 +8882,15 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 # Determine OpenSSL header version
-echo "$as_me:8838: checking OpenSSL header version" >&5
+echo "$as_me:8885: checking OpenSSL header version" >&5
 echo $ECHO_N "checking OpenSSL header version... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
-  { { echo "$as_me:8841: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:8888: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8846 "configure"
+#line 8893 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -8866,19 +8913,19 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:8869: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8916: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8872: \$? = $ac_status" >&5
+  echo "$as_me:8919: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:8874: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8921: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8877: \$? = $ac_status" >&5
+  echo "$as_me:8924: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 		ssl_header_ver=`cat conftest.sslincver`
-		echo "$as_me:8881: result: $ssl_header_ver" >&5
+		echo "$as_me:8928: result: $ssl_header_ver" >&5
 echo "${ECHO_T}$ssl_header_ver" >&6
 
 else
@@ -8886,9 +8933,9 @@
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:8889: result: not found" >&5
+		echo "$as_me:8936: result: not found" >&5
 echo "${ECHO_T}not found" >&6
-		{ { echo "$as_me:8891: error: OpenSSL version header not found." >&5
+		{ { echo "$as_me:8938: error: OpenSSL version header not found." >&5
 echo "$as_me: error: OpenSSL version header not found." >&2;}
    { (exit 1); exit 1; }; }
 
@@ -8897,15 +8944,15 @@
 fi
 
 # Determine OpenSSL library version
-echo "$as_me:8900: checking OpenSSL library version" >&5
+echo "$as_me:8947: checking OpenSSL library version" >&5
 echo $ECHO_N "checking OpenSSL library version... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
-  { { echo "$as_me:8903: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:8950: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8908 "configure"
+#line 8955 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -8929,19 +8976,19 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:8932: \"$ac_link\"") >&5
+if { (eval echo "$as_me:8979: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8935: \$? = $ac_status" >&5
+  echo "$as_me:8982: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:8937: \"$ac_try\"") >&5
+  { (eval echo "$as_me:8984: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8940: \$? = $ac_status" >&5
+  echo "$as_me:8987: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 		ssl_library_ver=`cat conftest.ssllibver`
-		echo "$as_me:8944: result: $ssl_library_ver" >&5
+		echo "$as_me:8991: result: $ssl_library_ver" >&5
 echo "${ECHO_T}$ssl_library_ver" >&6
 
 else
@@ -8949,9 +8996,9 @@
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:8952: result: not found" >&5
+		echo "$as_me:8999: result: not found" >&5
 echo "${ECHO_T}not found" >&6
-		{ { echo "$as_me:8954: error: OpenSSL library not found." >&5
+		{ { echo "$as_me:9001: error: OpenSSL library not found." >&5
 echo "$as_me: error: OpenSSL library not found." >&2;}
    { (exit 1); exit 1; }; }
 
@@ -8960,15 +9007,15 @@
 fi
 
 # Sanity check OpenSSL headers
-echo "$as_me:8963: checking whether OpenSSL's headers match the library" >&5
+echo "$as_me:9010: checking whether OpenSSL's headers match the library" >&5
 echo $ECHO_N "checking whether OpenSSL's headers match the library... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
-  { { echo "$as_me:8966: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:9013: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 8971 "configure"
+#line 9018 "configure"
 #include "confdefs.h"
 
 #include <string.h>
@@ -8977,18 +9024,18 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:8980: \"$ac_link\"") >&5
+if { (eval echo "$as_me:9027: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:8983: \$? = $ac_status" >&5
+  echo "$as_me:9030: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:8985: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9032: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:8988: \$? = $ac_status" >&5
+  echo "$as_me:9035: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
-		echo "$as_me:8991: result: yes" >&5
+		echo "$as_me:9038: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
@@ -8996,9 +9043,9 @@
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:8999: result: no" >&5
+		echo "$as_me:9046: result: no" >&5
 echo "${ECHO_T}no" >&6
-		{ { echo "$as_me:9001: error: Your OpenSSL headers do not match your library.
+		{ { echo "$as_me:9048: error: Your OpenSSL headers do not match your library.
 Check config.log for details.
 Also see contrib/findssl.sh for help identifying header/library mismatches." >&5
 echo "$as_me: error: Your OpenSSL headers do not match your library.
@@ -9013,7 +9060,7 @@
 # Some Linux systems (Slackware) need crypt() from libcrypt, *not* the
 # version in OpenSSL. Skip this for PAM
 if test "x$check_for_libcrypt_later" = "x1"; then
-	echo "$as_me:9016: checking for crypt in -lcrypt" >&5
+	echo "$as_me:9063: checking for crypt in -lcrypt" >&5
 echo $ECHO_N "checking for crypt in -lcrypt... $ECHO_C" >&6
 if test "${ac_cv_lib_crypt_crypt+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9021,7 +9068,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lcrypt  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 9024 "configure"
+#line 9071 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -9040,16 +9087,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:9043: \"$ac_link\"") >&5
+if { (eval echo "$as_me:9090: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:9046: \$? = $ac_status" >&5
+  echo "$as_me:9093: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:9049: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9096: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9052: \$? = $ac_status" >&5
+  echo "$as_me:9099: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_crypt_crypt=yes
 else
@@ -9060,7 +9107,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:9063: result: $ac_cv_lib_crypt_crypt" >&5
+echo "$as_me:9110: result: $ac_cv_lib_crypt_crypt" >&5
 echo "${ECHO_T}$ac_cv_lib_crypt_crypt" >&6
 if test $ac_cv_lib_crypt_crypt = yes; then
   LIBS="$LIBS -lcrypt"
@@ -9071,15 +9118,15 @@
 ### Configure cryptographic random number support
 
 # Check wheter OpenSSL seeds itself
-echo "$as_me:9074: checking whether OpenSSL's PRNG is internally seeded" >&5
+echo "$as_me:9121: checking whether OpenSSL's PRNG is internally seeded" >&5
 echo $ECHO_N "checking whether OpenSSL's PRNG is internally seeded... $ECHO_C" >&6
 if test "$cross_compiling" = yes; then
-  { { echo "$as_me:9077: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:9124: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 9082 "configure"
+#line 9129 "configure"
 #include "confdefs.h"
 
 #include <string.h>
@@ -9088,19 +9135,19 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:9091: \"$ac_link\"") >&5
+if { (eval echo "$as_me:9138: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:9094: \$? = $ac_status" >&5
+  echo "$as_me:9141: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:9096: \"$ac_try\"") >&5
+  { (eval echo "$as_me:9143: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:9099: \$? = $ac_status" >&5
+  echo "$as_me:9146: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 		OPENSSL_SEEDS_ITSELF=yes
-		echo "$as_me:9103: result: yes" >&5
+		echo "$as_me:9150: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
@@ -9108,7 +9155,7 @@
 echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:9111: result: no" >&5
+		echo "$as_me:9158: result: no" >&5
 echo "${ECHO_T}no" >&6
 		# Default to use of the rand helper if OpenSSL doesn't
 		# seed itself
@@ -9128,7 +9175,7 @@
 			# Force use of OpenSSL's internal RNG, even if
 			# the previous test showed it to be unseeded.
 			if test -z "$OPENSSL_SEEDS_ITSELF" ; then
-				{ echo "$as_me:9131: WARNING: *** Forcing use of OpenSSL's non-self-seeding PRNG" >&5
+				{ echo "$as_me:9178: WARNING: *** Forcing use of OpenSSL's non-self-seeding PRNG" >&5
 echo "$as_me: WARNING: *** Forcing use of OpenSSL's non-self-seeding PRNG" >&2;}
 				OPENSSL_SEEDS_ITSELF=yes
 				USE_RAND_HELPER=""
@@ -9169,7 +9216,7 @@
 		[0-9]*)
 			;;
 		*)
-			{ { echo "$as_me:9172: error: You must specify a numeric port number for --with-prngd-port" >&5
+			{ { echo "$as_me:9219: error: You must specify a numeric port number for --with-prngd-port" >&5
 echo "$as_me: error: You must specify a numeric port number for --with-prngd-port" >&2;}
    { (exit 1); exit 1; }; }
 			;;
@@ -9200,7 +9247,7 @@
 		/*)
 			;;
 		*)
-			{ { echo "$as_me:9203: error: You must specify an absolute path to the entropy socket" >&5
+			{ { echo "$as_me:9250: error: You must specify an absolute path to the entropy socket" >&5
 echo "$as_me: error: You must specify an absolute path to the entropy socket" >&2;}
    { (exit 1); exit 1; }; }
 			;;
@@ -9208,12 +9255,12 @@
 
 		if test ! -z "$withval" ; then
 			if test ! -z "$PRNGD_PORT" ; then
-				{ { echo "$as_me:9211: error: You may not specify both a PRNGD/EGD port and socket" >&5
+				{ { echo "$as_me:9258: error: You may not specify both a PRNGD/EGD port and socket" >&5
 echo "$as_me: error: You may not specify both a PRNGD/EGD port and socket" >&2;}
    { (exit 1); exit 1; }; }
 			fi
 			if test ! -r "$withval" ; then
-				{ echo "$as_me:9216: WARNING: Entropy socket is not readable" >&5
+				{ echo "$as_me:9263: WARNING: Entropy socket is not readable" >&5
 echo "$as_me: WARNING: Entropy socket is not readable" >&2;}
 			fi
 			PRNGD_SOCKET="$withval"
@@ -9227,7 +9274,7 @@
 
 		# Check for existing socket only if we don't have a random device already
 		if test "$USE_RAND_HELPER" = yes ; then
-			echo "$as_me:9230: checking for PRNGD/EGD socket" >&5
+			echo "$as_me:9277: checking for PRNGD/EGD socket" >&5
 echo $ECHO_N "checking for PRNGD/EGD socket... $ECHO_C" >&6
 			# Insert other locations here
 			for sock in /var/run/egd-pool /dev/egd-pool /etc/entropy; do
@@ -9241,10 +9288,10 @@
 				fi
 			done
 			if test ! -z "$PRNGD_SOCKET" ; then
-				echo "$as_me:9244: result: $PRNGD_SOCKET" >&5
+				echo "$as_me:9291: result: $PRNGD_SOCKET" >&5
 echo "${ECHO_T}$PRNGD_SOCKET" >&6
 			else
-				echo "$as_me:9247: result: not found" >&5
+				echo "$as_me:9294: result: not found" >&5
 echo "${ECHO_T}not found" >&6
 			fi
 		fi
@@ -9300,7 +9347,7 @@
 
 	# Extract the first word of "ls", so it can be a program name with args.
 set dummy ls; ac_word=$2
-echo "$as_me:9303: checking for $ac_word" >&5
+echo "$as_me:9350: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_LS+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9317,7 +9364,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_LS="$ac_dir/$ac_word"
-   echo "$as_me:9320: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9367: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9328,10 +9375,10 @@
 PROG_LS=$ac_cv_path_PROG_LS
 
 if test -n "$PROG_LS"; then
-  echo "$as_me:9331: result: $PROG_LS" >&5
+  echo "$as_me:9378: result: $PROG_LS" >&5
 echo "${ECHO_T}$PROG_LS" >&6
 else
-  echo "$as_me:9334: result: no" >&5
+  echo "$as_me:9381: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9341,7 +9388,7 @@
 
 	# Extract the first word of "netstat", so it can be a program name with args.
 set dummy netstat; ac_word=$2
-echo "$as_me:9344: checking for $ac_word" >&5
+echo "$as_me:9391: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_NETSTAT+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9358,7 +9405,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_NETSTAT="$ac_dir/$ac_word"
-   echo "$as_me:9361: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9408: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9369,10 +9416,10 @@
 PROG_NETSTAT=$ac_cv_path_PROG_NETSTAT
 
 if test -n "$PROG_NETSTAT"; then
-  echo "$as_me:9372: result: $PROG_NETSTAT" >&5
+  echo "$as_me:9419: result: $PROG_NETSTAT" >&5
 echo "${ECHO_T}$PROG_NETSTAT" >&6
 else
-  echo "$as_me:9375: result: no" >&5
+  echo "$as_me:9422: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9382,7 +9429,7 @@
 
 	# Extract the first word of "arp", so it can be a program name with args.
 set dummy arp; ac_word=$2
-echo "$as_me:9385: checking for $ac_word" >&5
+echo "$as_me:9432: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_ARP+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9399,7 +9446,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_ARP="$ac_dir/$ac_word"
-   echo "$as_me:9402: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9449: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9410,10 +9457,10 @@
 PROG_ARP=$ac_cv_path_PROG_ARP
 
 if test -n "$PROG_ARP"; then
-  echo "$as_me:9413: result: $PROG_ARP" >&5
+  echo "$as_me:9460: result: $PROG_ARP" >&5
 echo "${ECHO_T}$PROG_ARP" >&6
 else
-  echo "$as_me:9416: result: no" >&5
+  echo "$as_me:9463: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9423,7 +9470,7 @@
 
 	# Extract the first word of "ifconfig", so it can be a program name with args.
 set dummy ifconfig; ac_word=$2
-echo "$as_me:9426: checking for $ac_word" >&5
+echo "$as_me:9473: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_IFCONFIG+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9440,7 +9487,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_IFCONFIG="$ac_dir/$ac_word"
-   echo "$as_me:9443: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9490: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9451,10 +9498,10 @@
 PROG_IFCONFIG=$ac_cv_path_PROG_IFCONFIG
 
 if test -n "$PROG_IFCONFIG"; then
-  echo "$as_me:9454: result: $PROG_IFCONFIG" >&5
+  echo "$as_me:9501: result: $PROG_IFCONFIG" >&5
 echo "${ECHO_T}$PROG_IFCONFIG" >&6
 else
-  echo "$as_me:9457: result: no" >&5
+  echo "$as_me:9504: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9464,7 +9511,7 @@
 
 	# Extract the first word of "jstat", so it can be a program name with args.
 set dummy jstat; ac_word=$2
-echo "$as_me:9467: checking for $ac_word" >&5
+echo "$as_me:9514: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_JSTAT+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9481,7 +9528,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_JSTAT="$ac_dir/$ac_word"
-   echo "$as_me:9484: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9531: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9492,10 +9539,10 @@
 PROG_JSTAT=$ac_cv_path_PROG_JSTAT
 
 if test -n "$PROG_JSTAT"; then
-  echo "$as_me:9495: result: $PROG_JSTAT" >&5
+  echo "$as_me:9542: result: $PROG_JSTAT" >&5
 echo "${ECHO_T}$PROG_JSTAT" >&6
 else
-  echo "$as_me:9498: result: no" >&5
+  echo "$as_me:9545: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9505,7 +9552,7 @@
 
 	# Extract the first word of "ps", so it can be a program name with args.
 set dummy ps; ac_word=$2
-echo "$as_me:9508: checking for $ac_word" >&5
+echo "$as_me:9555: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_PS+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9522,7 +9569,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_PS="$ac_dir/$ac_word"
-   echo "$as_me:9525: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9572: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9533,10 +9580,10 @@
 PROG_PS=$ac_cv_path_PROG_PS
 
 if test -n "$PROG_PS"; then
-  echo "$as_me:9536: result: $PROG_PS" >&5
+  echo "$as_me:9583: result: $PROG_PS" >&5
 echo "${ECHO_T}$PROG_PS" >&6
 else
-  echo "$as_me:9539: result: no" >&5
+  echo "$as_me:9586: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9546,7 +9593,7 @@
 
 	# Extract the first word of "sar", so it can be a program name with args.
 set dummy sar; ac_word=$2
-echo "$as_me:9549: checking for $ac_word" >&5
+echo "$as_me:9596: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_SAR+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9563,7 +9610,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_SAR="$ac_dir/$ac_word"
-   echo "$as_me:9566: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9613: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9574,10 +9621,10 @@
 PROG_SAR=$ac_cv_path_PROG_SAR
 
 if test -n "$PROG_SAR"; then
-  echo "$as_me:9577: result: $PROG_SAR" >&5
+  echo "$as_me:9624: result: $PROG_SAR" >&5
 echo "${ECHO_T}$PROG_SAR" >&6
 else
-  echo "$as_me:9580: result: no" >&5
+  echo "$as_me:9627: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9587,7 +9634,7 @@
 
 	# Extract the first word of "w", so it can be a program name with args.
 set dummy w; ac_word=$2
-echo "$as_me:9590: checking for $ac_word" >&5
+echo "$as_me:9637: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_W+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9604,7 +9651,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_W="$ac_dir/$ac_word"
-   echo "$as_me:9607: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9654: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9615,10 +9662,10 @@
 PROG_W=$ac_cv_path_PROG_W
 
 if test -n "$PROG_W"; then
-  echo "$as_me:9618: result: $PROG_W" >&5
+  echo "$as_me:9665: result: $PROG_W" >&5
 echo "${ECHO_T}$PROG_W" >&6
 else
-  echo "$as_me:9621: result: no" >&5
+  echo "$as_me:9668: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9628,7 +9675,7 @@
 
 	# Extract the first word of "who", so it can be a program name with args.
 set dummy who; ac_word=$2
-echo "$as_me:9631: checking for $ac_word" >&5
+echo "$as_me:9678: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_WHO+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9645,7 +9692,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_WHO="$ac_dir/$ac_word"
-   echo "$as_me:9648: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9695: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9656,10 +9703,10 @@
 PROG_WHO=$ac_cv_path_PROG_WHO
 
 if test -n "$PROG_WHO"; then
-  echo "$as_me:9659: result: $PROG_WHO" >&5
+  echo "$as_me:9706: result: $PROG_WHO" >&5
 echo "${ECHO_T}$PROG_WHO" >&6
 else
-  echo "$as_me:9662: result: no" >&5
+  echo "$as_me:9709: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9669,7 +9716,7 @@
 
 	# Extract the first word of "last", so it can be a program name with args.
 set dummy last; ac_word=$2
-echo "$as_me:9672: checking for $ac_word" >&5
+echo "$as_me:9719: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_LAST+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9686,7 +9733,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_LAST="$ac_dir/$ac_word"
-   echo "$as_me:9689: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9736: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9697,10 +9744,10 @@
 PROG_LAST=$ac_cv_path_PROG_LAST
 
 if test -n "$PROG_LAST"; then
-  echo "$as_me:9700: result: $PROG_LAST" >&5
+  echo "$as_me:9747: result: $PROG_LAST" >&5
 echo "${ECHO_T}$PROG_LAST" >&6
 else
-  echo "$as_me:9703: result: no" >&5
+  echo "$as_me:9750: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9710,7 +9757,7 @@
 
 	# Extract the first word of "lastlog", so it can be a program name with args.
 set dummy lastlog; ac_word=$2
-echo "$as_me:9713: checking for $ac_word" >&5
+echo "$as_me:9760: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_LASTLOG+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9727,7 +9774,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_LASTLOG="$ac_dir/$ac_word"
-   echo "$as_me:9730: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9777: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9738,10 +9785,10 @@
 PROG_LASTLOG=$ac_cv_path_PROG_LASTLOG
 
 if test -n "$PROG_LASTLOG"; then
-  echo "$as_me:9741: result: $PROG_LASTLOG" >&5
+  echo "$as_me:9788: result: $PROG_LASTLOG" >&5
 echo "${ECHO_T}$PROG_LASTLOG" >&6
 else
-  echo "$as_me:9744: result: no" >&5
+  echo "$as_me:9791: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9751,7 +9798,7 @@
 
 	# Extract the first word of "df", so it can be a program name with args.
 set dummy df; ac_word=$2
-echo "$as_me:9754: checking for $ac_word" >&5
+echo "$as_me:9801: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_DF+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9768,7 +9815,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_DF="$ac_dir/$ac_word"
-   echo "$as_me:9771: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9818: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9779,10 +9826,10 @@
 PROG_DF=$ac_cv_path_PROG_DF
 
 if test -n "$PROG_DF"; then
-  echo "$as_me:9782: result: $PROG_DF" >&5
+  echo "$as_me:9829: result: $PROG_DF" >&5
 echo "${ECHO_T}$PROG_DF" >&6
 else
-  echo "$as_me:9785: result: no" >&5
+  echo "$as_me:9832: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9792,7 +9839,7 @@
 
 	# Extract the first word of "vmstat", so it can be a program name with args.
 set dummy vmstat; ac_word=$2
-echo "$as_me:9795: checking for $ac_word" >&5
+echo "$as_me:9842: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_VMSTAT+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9809,7 +9856,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_VMSTAT="$ac_dir/$ac_word"
-   echo "$as_me:9812: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9859: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9820,10 +9867,10 @@
 PROG_VMSTAT=$ac_cv_path_PROG_VMSTAT
 
 if test -n "$PROG_VMSTAT"; then
-  echo "$as_me:9823: result: $PROG_VMSTAT" >&5
+  echo "$as_me:9870: result: $PROG_VMSTAT" >&5
 echo "${ECHO_T}$PROG_VMSTAT" >&6
 else
-  echo "$as_me:9826: result: no" >&5
+  echo "$as_me:9873: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9833,7 +9880,7 @@
 
 	# Extract the first word of "uptime", so it can be a program name with args.
 set dummy uptime; ac_word=$2
-echo "$as_me:9836: checking for $ac_word" >&5
+echo "$as_me:9883: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_UPTIME+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9850,7 +9897,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_UPTIME="$ac_dir/$ac_word"
-   echo "$as_me:9853: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9900: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9861,10 +9908,10 @@
 PROG_UPTIME=$ac_cv_path_PROG_UPTIME
 
 if test -n "$PROG_UPTIME"; then
-  echo "$as_me:9864: result: $PROG_UPTIME" >&5
+  echo "$as_me:9911: result: $PROG_UPTIME" >&5
 echo "${ECHO_T}$PROG_UPTIME" >&6
 else
-  echo "$as_me:9867: result: no" >&5
+  echo "$as_me:9914: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9874,7 +9921,7 @@
 
 	# Extract the first word of "ipcs", so it can be a program name with args.
 set dummy ipcs; ac_word=$2
-echo "$as_me:9877: checking for $ac_word" >&5
+echo "$as_me:9924: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_IPCS+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9891,7 +9938,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_IPCS="$ac_dir/$ac_word"
-   echo "$as_me:9894: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9941: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9902,10 +9949,10 @@
 PROG_IPCS=$ac_cv_path_PROG_IPCS
 
 if test -n "$PROG_IPCS"; then
-  echo "$as_me:9905: result: $PROG_IPCS" >&5
+  echo "$as_me:9952: result: $PROG_IPCS" >&5
 echo "${ECHO_T}$PROG_IPCS" >&6
 else
-  echo "$as_me:9908: result: no" >&5
+  echo "$as_me:9955: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9915,7 +9962,7 @@
 
 	# Extract the first word of "tail", so it can be a program name with args.
 set dummy tail; ac_word=$2
-echo "$as_me:9918: checking for $ac_word" >&5
+echo "$as_me:9965: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_PROG_TAIL+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -9932,7 +9979,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_PROG_TAIL="$ac_dir/$ac_word"
-   echo "$as_me:9935: found $ac_dir/$ac_word" >&5
+   echo "$as_me:9982: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -9943,10 +9990,10 @@
 PROG_TAIL=$ac_cv_path_PROG_TAIL
 
 if test -n "$PROG_TAIL"; then
-  echo "$as_me:9946: result: $PROG_TAIL" >&5
+  echo "$as_me:9993: result: $PROG_TAIL" >&5
 echo "${ECHO_T}$PROG_TAIL" >&6
 else
-  echo "$as_me:9949: result: no" >&5
+  echo "$as_me:9996: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -9977,13 +10024,13 @@
 fi
 
 # Checks for data types
-echo "$as_me:9980: checking for char" >&5
+echo "$as_me:10027: checking for char" >&5
 echo $ECHO_N "checking for char... $ECHO_C" >&6
 if test "${ac_cv_type_char+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 9986 "configure"
+#line 10033 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -9998,16 +10045,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10001: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10048: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10004: \$? = $ac_status" >&5
+  echo "$as_me:10051: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10007: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10054: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10010: \$? = $ac_status" >&5
+  echo "$as_me:10057: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_char=yes
 else
@@ -10017,10 +10064,10 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:10020: result: $ac_cv_type_char" >&5
+echo "$as_me:10067: result: $ac_cv_type_char" >&5
 echo "${ECHO_T}$ac_cv_type_char" >&6
 
-echo "$as_me:10023: checking size of char" >&5
+echo "$as_me:10070: checking size of char" >&5
 echo $ECHO_N "checking size of char... $ECHO_C" >&6
 if test "${ac_cv_sizeof_char+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10029,7 +10076,7 @@
   if test "$cross_compiling" = yes; then
   # Depending upon the size, compute the lo and hi bounds.
 cat >conftest.$ac_ext <<_ACEOF
-#line 10032 "configure"
+#line 10079 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10041,21 +10088,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10044: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10091: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10047: \$? = $ac_status" >&5
+  echo "$as_me:10094: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10050: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10097: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10053: \$? = $ac_status" >&5
+  echo "$as_me:10100: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=0 ac_mid=0
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10058 "configure"
+#line 10105 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10067,16 +10114,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10070: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10117: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10073: \$? = $ac_status" >&5
+  echo "$as_me:10120: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10076: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10123: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10079: \$? = $ac_status" >&5
+  echo "$as_me:10126: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid; break
 else
@@ -10092,7 +10139,7 @@
 ac_hi=-1 ac_mid=-1
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10095 "configure"
+#line 10142 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10104,16 +10151,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10107: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10154: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10110: \$? = $ac_status" >&5
+  echo "$as_me:10157: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10113: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10160: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10116: \$? = $ac_status" >&5
+  echo "$as_me:10163: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=$ac_mid; break
 else
@@ -10129,7 +10176,7 @@
 while test "x$ac_lo" != "x$ac_hi"; do
   ac_mid=`expr '(' $ac_hi - $ac_lo ')' / 2 + $ac_lo`
   cat >conftest.$ac_ext <<_ACEOF
-#line 10132 "configure"
+#line 10179 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10141,16 +10188,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10144: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10191: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10147: \$? = $ac_status" >&5
+  echo "$as_me:10194: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10150: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10197: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10153: \$? = $ac_status" >&5
+  echo "$as_me:10200: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid
 else
@@ -10163,12 +10210,12 @@
 ac_cv_sizeof_char=$ac_lo
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:10166: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:10213: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10171 "configure"
+#line 10218 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10184,15 +10231,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:10187: \"$ac_link\"") >&5
+if { (eval echo "$as_me:10234: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10190: \$? = $ac_status" >&5
+  echo "$as_me:10237: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:10192: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10239: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10195: \$? = $ac_status" >&5
+  echo "$as_me:10242: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sizeof_char=`cat conftest.val`
 else
@@ -10208,19 +10255,19 @@
   ac_cv_sizeof_char=0
 fi
 fi
-echo "$as_me:10211: result: $ac_cv_sizeof_char" >&5
+echo "$as_me:10258: result: $ac_cv_sizeof_char" >&5
 echo "${ECHO_T}$ac_cv_sizeof_char" >&6
 cat >>confdefs.h <<EOF
 #define SIZEOF_CHAR $ac_cv_sizeof_char
 EOF
 
-echo "$as_me:10217: checking for short int" >&5
+echo "$as_me:10264: checking for short int" >&5
 echo $ECHO_N "checking for short int... $ECHO_C" >&6
 if test "${ac_cv_type_short_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10223 "configure"
+#line 10270 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10235,16 +10282,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10238: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10285: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10241: \$? = $ac_status" >&5
+  echo "$as_me:10288: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10244: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10291: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10247: \$? = $ac_status" >&5
+  echo "$as_me:10294: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_short_int=yes
 else
@@ -10254,10 +10301,10 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:10257: result: $ac_cv_type_short_int" >&5
+echo "$as_me:10304: result: $ac_cv_type_short_int" >&5
 echo "${ECHO_T}$ac_cv_type_short_int" >&6
 
-echo "$as_me:10260: checking size of short int" >&5
+echo "$as_me:10307: checking size of short int" >&5
 echo $ECHO_N "checking size of short int... $ECHO_C" >&6
 if test "${ac_cv_sizeof_short_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10266,7 +10313,7 @@
   if test "$cross_compiling" = yes; then
   # Depending upon the size, compute the lo and hi bounds.
 cat >conftest.$ac_ext <<_ACEOF
-#line 10269 "configure"
+#line 10316 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10278,21 +10325,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10281: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10328: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10284: \$? = $ac_status" >&5
+  echo "$as_me:10331: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10287: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10334: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10290: \$? = $ac_status" >&5
+  echo "$as_me:10337: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=0 ac_mid=0
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10295 "configure"
+#line 10342 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10304,16 +10351,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10307: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10354: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10310: \$? = $ac_status" >&5
+  echo "$as_me:10357: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10313: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10360: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10316: \$? = $ac_status" >&5
+  echo "$as_me:10363: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid; break
 else
@@ -10329,7 +10376,7 @@
 ac_hi=-1 ac_mid=-1
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10332 "configure"
+#line 10379 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10341,16 +10388,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10344: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10391: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10347: \$? = $ac_status" >&5
+  echo "$as_me:10394: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10350: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10397: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10353: \$? = $ac_status" >&5
+  echo "$as_me:10400: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=$ac_mid; break
 else
@@ -10366,7 +10413,7 @@
 while test "x$ac_lo" != "x$ac_hi"; do
   ac_mid=`expr '(' $ac_hi - $ac_lo ')' / 2 + $ac_lo`
   cat >conftest.$ac_ext <<_ACEOF
-#line 10369 "configure"
+#line 10416 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10378,16 +10425,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10381: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10428: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10384: \$? = $ac_status" >&5
+  echo "$as_me:10431: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10387: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10434: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10390: \$? = $ac_status" >&5
+  echo "$as_me:10437: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid
 else
@@ -10400,12 +10447,12 @@
 ac_cv_sizeof_short_int=$ac_lo
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:10403: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:10450: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10408 "configure"
+#line 10455 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10421,15 +10468,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:10424: \"$ac_link\"") >&5
+if { (eval echo "$as_me:10471: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10427: \$? = $ac_status" >&5
+  echo "$as_me:10474: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:10429: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10476: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10432: \$? = $ac_status" >&5
+  echo "$as_me:10479: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sizeof_short_int=`cat conftest.val`
 else
@@ -10445,19 +10492,19 @@
   ac_cv_sizeof_short_int=0
 fi
 fi
-echo "$as_me:10448: result: $ac_cv_sizeof_short_int" >&5
+echo "$as_me:10495: result: $ac_cv_sizeof_short_int" >&5
 echo "${ECHO_T}$ac_cv_sizeof_short_int" >&6
 cat >>confdefs.h <<EOF
 #define SIZEOF_SHORT_INT $ac_cv_sizeof_short_int
 EOF
 
-echo "$as_me:10454: checking for int" >&5
+echo "$as_me:10501: checking for int" >&5
 echo $ECHO_N "checking for int... $ECHO_C" >&6
 if test "${ac_cv_type_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10460 "configure"
+#line 10507 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10472,16 +10519,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10475: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10522: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10478: \$? = $ac_status" >&5
+  echo "$as_me:10525: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10481: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10528: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10484: \$? = $ac_status" >&5
+  echo "$as_me:10531: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_int=yes
 else
@@ -10491,10 +10538,10 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:10494: result: $ac_cv_type_int" >&5
+echo "$as_me:10541: result: $ac_cv_type_int" >&5
 echo "${ECHO_T}$ac_cv_type_int" >&6
 
-echo "$as_me:10497: checking size of int" >&5
+echo "$as_me:10544: checking size of int" >&5
 echo $ECHO_N "checking size of int... $ECHO_C" >&6
 if test "${ac_cv_sizeof_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10503,7 +10550,7 @@
   if test "$cross_compiling" = yes; then
   # Depending upon the size, compute the lo and hi bounds.
 cat >conftest.$ac_ext <<_ACEOF
-#line 10506 "configure"
+#line 10553 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10515,21 +10562,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10518: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10565: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10521: \$? = $ac_status" >&5
+  echo "$as_me:10568: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10524: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10571: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10527: \$? = $ac_status" >&5
+  echo "$as_me:10574: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=0 ac_mid=0
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10532 "configure"
+#line 10579 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10541,16 +10588,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10544: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10591: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10547: \$? = $ac_status" >&5
+  echo "$as_me:10594: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10550: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10597: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10553: \$? = $ac_status" >&5
+  echo "$as_me:10600: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid; break
 else
@@ -10566,7 +10613,7 @@
 ac_hi=-1 ac_mid=-1
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10569 "configure"
+#line 10616 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10578,16 +10625,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10581: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10628: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10584: \$? = $ac_status" >&5
+  echo "$as_me:10631: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10587: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10634: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10590: \$? = $ac_status" >&5
+  echo "$as_me:10637: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=$ac_mid; break
 else
@@ -10603,7 +10650,7 @@
 while test "x$ac_lo" != "x$ac_hi"; do
   ac_mid=`expr '(' $ac_hi - $ac_lo ')' / 2 + $ac_lo`
   cat >conftest.$ac_ext <<_ACEOF
-#line 10606 "configure"
+#line 10653 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10615,16 +10662,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10618: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10665: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10621: \$? = $ac_status" >&5
+  echo "$as_me:10668: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10624: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10671: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10627: \$? = $ac_status" >&5
+  echo "$as_me:10674: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid
 else
@@ -10637,12 +10684,12 @@
 ac_cv_sizeof_int=$ac_lo
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:10640: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:10687: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10645 "configure"
+#line 10692 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10658,15 +10705,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:10661: \"$ac_link\"") >&5
+if { (eval echo "$as_me:10708: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10664: \$? = $ac_status" >&5
+  echo "$as_me:10711: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:10666: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10713: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10669: \$? = $ac_status" >&5
+  echo "$as_me:10716: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sizeof_int=`cat conftest.val`
 else
@@ -10682,19 +10729,19 @@
   ac_cv_sizeof_int=0
 fi
 fi
-echo "$as_me:10685: result: $ac_cv_sizeof_int" >&5
+echo "$as_me:10732: result: $ac_cv_sizeof_int" >&5
 echo "${ECHO_T}$ac_cv_sizeof_int" >&6
 cat >>confdefs.h <<EOF
 #define SIZEOF_INT $ac_cv_sizeof_int
 EOF
 
-echo "$as_me:10691: checking for long int" >&5
+echo "$as_me:10738: checking for long int" >&5
 echo $ECHO_N "checking for long int... $ECHO_C" >&6
 if test "${ac_cv_type_long_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10697 "configure"
+#line 10744 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10709,16 +10756,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10712: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10759: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10715: \$? = $ac_status" >&5
+  echo "$as_me:10762: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10718: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10765: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10721: \$? = $ac_status" >&5
+  echo "$as_me:10768: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_long_int=yes
 else
@@ -10728,10 +10775,10 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:10731: result: $ac_cv_type_long_int" >&5
+echo "$as_me:10778: result: $ac_cv_type_long_int" >&5
 echo "${ECHO_T}$ac_cv_type_long_int" >&6
 
-echo "$as_me:10734: checking size of long int" >&5
+echo "$as_me:10781: checking size of long int" >&5
 echo $ECHO_N "checking size of long int... $ECHO_C" >&6
 if test "${ac_cv_sizeof_long_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10740,7 +10787,7 @@
   if test "$cross_compiling" = yes; then
   # Depending upon the size, compute the lo and hi bounds.
 cat >conftest.$ac_ext <<_ACEOF
-#line 10743 "configure"
+#line 10790 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10752,21 +10799,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10755: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10802: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10758: \$? = $ac_status" >&5
+  echo "$as_me:10805: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10761: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10808: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10764: \$? = $ac_status" >&5
+  echo "$as_me:10811: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=0 ac_mid=0
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10769 "configure"
+#line 10816 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10778,16 +10825,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10781: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10828: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10784: \$? = $ac_status" >&5
+  echo "$as_me:10831: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10787: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10834: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10790: \$? = $ac_status" >&5
+  echo "$as_me:10837: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid; break
 else
@@ -10803,7 +10850,7 @@
 ac_hi=-1 ac_mid=-1
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 10806 "configure"
+#line 10853 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10815,16 +10862,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10818: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10865: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10821: \$? = $ac_status" >&5
+  echo "$as_me:10868: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10824: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10871: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10827: \$? = $ac_status" >&5
+  echo "$as_me:10874: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=$ac_mid; break
 else
@@ -10840,7 +10887,7 @@
 while test "x$ac_lo" != "x$ac_hi"; do
   ac_mid=`expr '(' $ac_hi - $ac_lo ')' / 2 + $ac_lo`
   cat >conftest.$ac_ext <<_ACEOF
-#line 10843 "configure"
+#line 10890 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10852,16 +10899,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10855: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10902: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10858: \$? = $ac_status" >&5
+  echo "$as_me:10905: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10861: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10908: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10864: \$? = $ac_status" >&5
+  echo "$as_me:10911: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid
 else
@@ -10874,12 +10921,12 @@
 ac_cv_sizeof_long_int=$ac_lo
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:10877: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:10924: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10882 "configure"
+#line 10929 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10895,15 +10942,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:10898: \"$ac_link\"") >&5
+if { (eval echo "$as_me:10945: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:10901: \$? = $ac_status" >&5
+  echo "$as_me:10948: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:10903: \"$ac_try\"") >&5
+  { (eval echo "$as_me:10950: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10906: \$? = $ac_status" >&5
+  echo "$as_me:10953: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sizeof_long_int=`cat conftest.val`
 else
@@ -10919,19 +10966,19 @@
   ac_cv_sizeof_long_int=0
 fi
 fi
-echo "$as_me:10922: result: $ac_cv_sizeof_long_int" >&5
+echo "$as_me:10969: result: $ac_cv_sizeof_long_int" >&5
 echo "${ECHO_T}$ac_cv_sizeof_long_int" >&6
 cat >>confdefs.h <<EOF
 #define SIZEOF_LONG_INT $ac_cv_sizeof_long_int
 EOF
 
-echo "$as_me:10928: checking for long long int" >&5
+echo "$as_me:10975: checking for long long int" >&5
 echo $ECHO_N "checking for long long int... $ECHO_C" >&6
 if test "${ac_cv_type_long_long_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 10934 "configure"
+#line 10981 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10946,16 +10993,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10949: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:10996: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10952: \$? = $ac_status" >&5
+  echo "$as_me:10999: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10955: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11002: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:10958: \$? = $ac_status" >&5
+  echo "$as_me:11005: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_long_long_int=yes
 else
@@ -10965,10 +11012,10 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:10968: result: $ac_cv_type_long_long_int" >&5
+echo "$as_me:11015: result: $ac_cv_type_long_long_int" >&5
 echo "${ECHO_T}$ac_cv_type_long_long_int" >&6
 
-echo "$as_me:10971: checking size of long long int" >&5
+echo "$as_me:11018: checking size of long long int" >&5
 echo $ECHO_N "checking size of long long int... $ECHO_C" >&6
 if test "${ac_cv_sizeof_long_long_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10977,7 +11024,7 @@
   if test "$cross_compiling" = yes; then
   # Depending upon the size, compute the lo and hi bounds.
 cat >conftest.$ac_ext <<_ACEOF
-#line 10980 "configure"
+#line 11027 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -10989,21 +11036,21 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:10992: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11039: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:10995: \$? = $ac_status" >&5
+  echo "$as_me:11042: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:10998: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11045: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11001: \$? = $ac_status" >&5
+  echo "$as_me:11048: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=0 ac_mid=0
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 11006 "configure"
+#line 11053 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -11015,16 +11062,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11018: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11065: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11021: \$? = $ac_status" >&5
+  echo "$as_me:11068: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11024: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11071: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11027: \$? = $ac_status" >&5
+  echo "$as_me:11074: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid; break
 else
@@ -11040,7 +11087,7 @@
 ac_hi=-1 ac_mid=-1
   while :; do
     cat >conftest.$ac_ext <<_ACEOF
-#line 11043 "configure"
+#line 11090 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -11052,16 +11099,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11055: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11102: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11058: \$? = $ac_status" >&5
+  echo "$as_me:11105: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11061: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11108: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11064: \$? = $ac_status" >&5
+  echo "$as_me:11111: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_lo=$ac_mid; break
 else
@@ -11077,7 +11124,7 @@
 while test "x$ac_lo" != "x$ac_hi"; do
   ac_mid=`expr '(' $ac_hi - $ac_lo ')' / 2 + $ac_lo`
   cat >conftest.$ac_ext <<_ACEOF
-#line 11080 "configure"
+#line 11127 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -11089,16 +11136,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11092: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11139: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11095: \$? = $ac_status" >&5
+  echo "$as_me:11142: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11098: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11145: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11101: \$? = $ac_status" >&5
+  echo "$as_me:11148: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_hi=$ac_mid
 else
@@ -11111,12 +11158,12 @@
 ac_cv_sizeof_long_long_int=$ac_lo
 else
   if test "$cross_compiling" = yes; then
-  { { echo "$as_me:11114: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:11161: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 11119 "configure"
+#line 11166 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -11132,15 +11179,15 @@
 }
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:11135: \"$ac_link\"") >&5
+if { (eval echo "$as_me:11182: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:11138: \$? = $ac_status" >&5
+  echo "$as_me:11185: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:11140: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11187: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11143: \$? = $ac_status" >&5
+  echo "$as_me:11190: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_sizeof_long_long_int=`cat conftest.val`
 else
@@ -11156,7 +11203,7 @@
   ac_cv_sizeof_long_long_int=0
 fi
 fi
-echo "$as_me:11159: result: $ac_cv_sizeof_long_long_int" >&5
+echo "$as_me:11206: result: $ac_cv_sizeof_long_long_int" >&5
 echo "${ECHO_T}$ac_cv_sizeof_long_long_int" >&6
 cat >>confdefs.h <<EOF
 #define SIZEOF_LONG_LONG_INT $ac_cv_sizeof_long_long_int
@@ -11168,14 +11215,14 @@
 fi
 
 # More checks for data types
-echo "$as_me:11171: checking for u_int type" >&5
+echo "$as_me:11218: checking for u_int type" >&5
 echo $ECHO_N "checking for u_int type... $ECHO_C" >&6
 if test "${ac_cv_have_u_int+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11178 "configure"
+#line 11225 "configure"
 #include "confdefs.h"
  #include <sys/types.h>
 int
@@ -11187,16 +11234,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11190: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11237: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11193: \$? = $ac_status" >&5
+  echo "$as_me:11240: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11196: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11243: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11199: \$? = $ac_status" >&5
+  echo "$as_me:11246: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_u_int="yes"
 else
@@ -11208,7 +11255,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11211: result: $ac_cv_have_u_int" >&5
+echo "$as_me:11258: result: $ac_cv_have_u_int" >&5
 echo "${ECHO_T}$ac_cv_have_u_int" >&6
 if test "x$ac_cv_have_u_int" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11218,14 +11265,14 @@
 	have_u_int=1
 fi
 
-echo "$as_me:11221: checking for intXX_t types" >&5
+echo "$as_me:11268: checking for intXX_t types" >&5
 echo $ECHO_N "checking for intXX_t types... $ECHO_C" >&6
 if test "${ac_cv_have_intxx_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11228 "configure"
+#line 11275 "configure"
 #include "confdefs.h"
  #include <sys/types.h>
 int
@@ -11237,16 +11284,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11240: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11287: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11243: \$? = $ac_status" >&5
+  echo "$as_me:11290: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11246: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11293: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11249: \$? = $ac_status" >&5
+  echo "$as_me:11296: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_intxx_t="yes"
 else
@@ -11258,7 +11305,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11261: result: $ac_cv_have_intxx_t" >&5
+echo "$as_me:11308: result: $ac_cv_have_intxx_t" >&5
 echo "${ECHO_T}$ac_cv_have_intxx_t" >&6
 if test "x$ac_cv_have_intxx_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11271,10 +11318,10 @@
 if (test -z "$have_intxx_t" && \
            test "x$ac_cv_header_stdint_h" = "xyes")
 then
-    echo "$as_me:11274: checking for intXX_t types in stdint.h" >&5
+    echo "$as_me:11321: checking for intXX_t types in stdint.h" >&5
 echo $ECHO_N "checking for intXX_t types in stdint.h... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11277 "configure"
+#line 11324 "configure"
 #include "confdefs.h"
  #include <stdint.h>
 int
@@ -11286,43 +11333,43 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11289: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11336: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11292: \$? = $ac_status" >&5
+  echo "$as_me:11339: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11295: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11342: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11298: \$? = $ac_status" >&5
+  echo "$as_me:11345: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cat >>confdefs.h <<\EOF
 #define HAVE_INTXX_T 1
 EOF
 
-			echo "$as_me:11305: result: yes" >&5
+			echo "$as_me:11352: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:11311: result: no" >&5
+ echo "$as_me:11358: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
 
-echo "$as_me:11318: checking for int64_t type" >&5
+echo "$as_me:11365: checking for int64_t type" >&5
 echo $ECHO_N "checking for int64_t type... $ECHO_C" >&6
 if test "${ac_cv_have_int64_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11325 "configure"
+#line 11372 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -11343,16 +11390,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11346: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11393: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11349: \$? = $ac_status" >&5
+  echo "$as_me:11396: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11352: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11399: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11355: \$? = $ac_status" >&5
+  echo "$as_me:11402: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_int64_t="yes"
 else
@@ -11364,7 +11411,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11367: result: $ac_cv_have_int64_t" >&5
+echo "$as_me:11414: result: $ac_cv_have_int64_t" >&5
 echo "${ECHO_T}$ac_cv_have_int64_t" >&6
 if test "x$ac_cv_have_int64_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11373,14 +11420,14 @@
 
 fi
 
-echo "$as_me:11376: checking for u_intXX_t types" >&5
+echo "$as_me:11423: checking for u_intXX_t types" >&5
 echo $ECHO_N "checking for u_intXX_t types... $ECHO_C" >&6
 if test "${ac_cv_have_u_intxx_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11383 "configure"
+#line 11430 "configure"
 #include "confdefs.h"
  #include <sys/types.h>
 int
@@ -11392,16 +11439,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11395: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11442: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11398: \$? = $ac_status" >&5
+  echo "$as_me:11445: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11401: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11448: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11404: \$? = $ac_status" >&5
+  echo "$as_me:11451: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_u_intxx_t="yes"
 else
@@ -11413,7 +11460,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11416: result: $ac_cv_have_u_intxx_t" >&5
+echo "$as_me:11463: result: $ac_cv_have_u_intxx_t" >&5
 echo "${ECHO_T}$ac_cv_have_u_intxx_t" >&6
 if test "x$ac_cv_have_u_intxx_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11424,10 +11471,10 @@
 fi
 
 if test -z "$have_u_intxx_t" ; then
-    echo "$as_me:11427: checking for u_intXX_t types in sys/socket.h" >&5
+    echo "$as_me:11474: checking for u_intXX_t types in sys/socket.h" >&5
 echo $ECHO_N "checking for u_intXX_t types in sys/socket.h... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11430 "configure"
+#line 11477 "configure"
 #include "confdefs.h"
  #include <sys/socket.h>
 int
@@ -11439,43 +11486,43 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11442: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11489: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11445: \$? = $ac_status" >&5
+  echo "$as_me:11492: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11448: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11495: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11451: \$? = $ac_status" >&5
+  echo "$as_me:11498: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cat >>confdefs.h <<\EOF
 #define HAVE_U_INTXX_T 1
 EOF
 
-			echo "$as_me:11458: result: yes" >&5
+			echo "$as_me:11505: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:11464: result: no" >&5
+ echo "$as_me:11511: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
 
-echo "$as_me:11471: checking for u_int64_t types" >&5
+echo "$as_me:11518: checking for u_int64_t types" >&5
 echo $ECHO_N "checking for u_int64_t types... $ECHO_C" >&6
 if test "${ac_cv_have_u_int64_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11478 "configure"
+#line 11525 "configure"
 #include "confdefs.h"
  #include <sys/types.h>
 int
@@ -11487,16 +11534,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11490: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11537: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11493: \$? = $ac_status" >&5
+  echo "$as_me:11540: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11496: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11543: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11499: \$? = $ac_status" >&5
+  echo "$as_me:11546: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_u_int64_t="yes"
 else
@@ -11508,7 +11555,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11511: result: $ac_cv_have_u_int64_t" >&5
+echo "$as_me:11558: result: $ac_cv_have_u_int64_t" >&5
 echo "${ECHO_T}$ac_cv_have_u_int64_t" >&6
 if test "x$ac_cv_have_u_int64_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11519,10 +11566,10 @@
 fi
 
 if test -z "$have_u_int64_t" ; then
-    echo "$as_me:11522: checking for u_int64_t type in sys/bitypes.h" >&5
+    echo "$as_me:11569: checking for u_int64_t type in sys/bitypes.h" >&5
 echo $ECHO_N "checking for u_int64_t type in sys/bitypes.h... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11525 "configure"
+#line 11572 "configure"
 #include "confdefs.h"
  #include <sys/bitypes.h>
 int
@@ -11534,29 +11581,29 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11537: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11584: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11540: \$? = $ac_status" >&5
+  echo "$as_me:11587: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11543: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11590: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11546: \$? = $ac_status" >&5
+  echo "$as_me:11593: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cat >>confdefs.h <<\EOF
 #define HAVE_U_INT64_T 1
 EOF
 
-			echo "$as_me:11553: result: yes" >&5
+			echo "$as_me:11600: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:11559: result: no" >&5
+ echo "$as_me:11606: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
@@ -11564,14 +11611,14 @@
 fi
 
 if test -z "$have_u_intxx_t" ; then
-	echo "$as_me:11567: checking for uintXX_t types" >&5
+	echo "$as_me:11614: checking for uintXX_t types" >&5
 echo $ECHO_N "checking for uintXX_t types... $ECHO_C" >&6
 if test "${ac_cv_have_uintxx_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 11574 "configure"
+#line 11621 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -11585,16 +11632,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11588: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11635: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11591: \$? = $ac_status" >&5
+  echo "$as_me:11638: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11594: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11641: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11597: \$? = $ac_status" >&5
+  echo "$as_me:11644: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_uintxx_t="yes"
 else
@@ -11606,7 +11653,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11609: result: $ac_cv_have_uintxx_t" >&5
+echo "$as_me:11656: result: $ac_cv_have_uintxx_t" >&5
 echo "${ECHO_T}$ac_cv_have_uintxx_t" >&6
 	if test "x$ac_cv_have_uintxx_t" = "xyes" ; then
 		cat >>confdefs.h <<\EOF
@@ -11617,10 +11664,10 @@
 fi
 
 if test -z "$have_uintxx_t" ; then
-    echo "$as_me:11620: checking for uintXX_t types in stdint.h" >&5
+    echo "$as_me:11667: checking for uintXX_t types in stdint.h" >&5
 echo $ECHO_N "checking for uintXX_t types in stdint.h... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11623 "configure"
+#line 11670 "configure"
 #include "confdefs.h"
  #include <stdint.h>
 int
@@ -11632,29 +11679,29 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11635: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11682: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11638: \$? = $ac_status" >&5
+  echo "$as_me:11685: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11641: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11688: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11644: \$? = $ac_status" >&5
+  echo "$as_me:11691: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cat >>confdefs.h <<\EOF
 #define HAVE_UINTXX_T 1
 EOF
 
-			echo "$as_me:11651: result: yes" >&5
+			echo "$as_me:11698: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:11657: result: no" >&5
+ echo "$as_me:11704: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
@@ -11664,10 +11711,10 @@
 if (test -z "$have_u_intxx_t" || test -z "$have_intxx_t" && \
            test "x$ac_cv_header_sys_bitypes_h" = "xyes")
 then
-	echo "$as_me:11667: checking for intXX_t and u_intXX_t types in sys/bitypes.h" >&5
+	echo "$as_me:11714: checking for intXX_t and u_intXX_t types in sys/bitypes.h" >&5
 echo $ECHO_N "checking for intXX_t and u_intXX_t types in sys/bitypes.h... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11670 "configure"
+#line 11717 "configure"
 #include "confdefs.h"
 
 #include <sys/bitypes.h>
@@ -11685,16 +11732,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11688: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11735: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11691: \$? = $ac_status" >&5
+  echo "$as_me:11738: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11694: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11741: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11697: \$? = $ac_status" >&5
+  echo "$as_me:11744: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 			cat >>confdefs.h <<\EOF
@@ -11705,27 +11752,27 @@
 #define HAVE_INTXX_T 1
 EOF
 
-			echo "$as_me:11708: result: yes" >&5
+			echo "$as_me:11755: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
-echo "$as_me:11714: result: no" >&5
+echo "$as_me:11761: result: no" >&5
 echo "${ECHO_T}no" >&6
 
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
 
-echo "$as_me:11721: checking for u_char" >&5
+echo "$as_me:11768: checking for u_char" >&5
 echo $ECHO_N "checking for u_char... $ECHO_C" >&6
 if test "${ac_cv_have_u_char+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11728 "configure"
+#line 11775 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -11739,16 +11786,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11742: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11789: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11745: \$? = $ac_status" >&5
+  echo "$as_me:11792: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11748: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11795: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11751: \$? = $ac_status" >&5
+  echo "$as_me:11798: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_u_char="yes"
 else
@@ -11760,7 +11807,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11763: result: $ac_cv_have_u_char" >&5
+echo "$as_me:11810: result: $ac_cv_have_u_char" >&5
 echo "${ECHO_T}$ac_cv_have_u_char" >&6
 if test "x$ac_cv_have_u_char" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11769,13 +11816,13 @@
 
 fi
 
-   echo "$as_me:11772: checking for socklen_t" >&5
+   echo "$as_me:11819: checking for socklen_t" >&5
 echo $ECHO_N "checking for socklen_t... $ECHO_C" >&6
 if test "${ac_cv_type_socklen_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 11778 "configure"
+#line 11825 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -11792,16 +11839,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11795: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11842: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11798: \$? = $ac_status" >&5
+  echo "$as_me:11845: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11801: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11848: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11804: \$? = $ac_status" >&5
+  echo "$as_me:11851: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_socklen_t=yes
 else
@@ -11811,13 +11858,13 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:11814: result: $ac_cv_type_socklen_t" >&5
+echo "$as_me:11861: result: $ac_cv_type_socklen_t" >&5
 echo "${ECHO_T}$ac_cv_type_socklen_t" >&6
 if test $ac_cv_type_socklen_t = yes; then
   :
 else
 
-      echo "$as_me:11820: checking for socklen_t equivalent" >&5
+      echo "$as_me:11867: checking for socklen_t equivalent" >&5
 echo $ECHO_N "checking for socklen_t equivalent... $ECHO_C" >&6
       if test "${curl_cv_socklen_t_equiv+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -11829,7 +11876,7 @@
 	 for arg2 in "struct sockaddr" void; do
 	    for t in int size_t unsigned long "unsigned long"; do
 	       cat >conftest.$ac_ext <<_ACEOF
-#line 11832 "configure"
+#line 11879 "configure"
 #include "confdefs.h"
 
 		  #include <sys/types.h>
@@ -11849,16 +11896,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11852: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11899: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11855: \$? = $ac_status" >&5
+  echo "$as_me:11902: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11858: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11905: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11861: \$? = $ac_status" >&5
+  echo "$as_me:11908: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
 
 		  curl_cv_socklen_t_equiv="$t"
@@ -11873,14 +11920,14 @@
 	 done
 
 	 if test "x$curl_cv_socklen_t_equiv" = x; then
-	    { { echo "$as_me:11876: error: Cannot find a type to use in place of socklen_t" >&5
+	    { { echo "$as_me:11923: error: Cannot find a type to use in place of socklen_t" >&5
 echo "$as_me: error: Cannot find a type to use in place of socklen_t" >&2;}
    { (exit 1); exit 1; }; }
 	 fi
 
 fi
 
-      echo "$as_me:11883: result: $curl_cv_socklen_t_equiv" >&5
+      echo "$as_me:11930: result: $curl_cv_socklen_t_equiv" >&5
 echo "${ECHO_T}$curl_cv_socklen_t_equiv" >&6
 
 cat >>confdefs.h <<EOF
@@ -11889,13 +11936,13 @@
 
 fi
 
-echo "$as_me:11892: checking for sig_atomic_t" >&5
+echo "$as_me:11939: checking for sig_atomic_t" >&5
 echo $ECHO_N "checking for sig_atomic_t... $ECHO_C" >&6
 if test "${ac_cv_type_sig_atomic_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 11898 "configure"
+#line 11945 "configure"
 #include "confdefs.h"
 #include <signal.h>
 
@@ -11911,16 +11958,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11914: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:11961: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11917: \$? = $ac_status" >&5
+  echo "$as_me:11964: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11920: \"$ac_try\"") >&5
+  { (eval echo "$as_me:11967: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11923: \$? = $ac_status" >&5
+  echo "$as_me:11970: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_sig_atomic_t=yes
 else
@@ -11930,7 +11977,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:11933: result: $ac_cv_type_sig_atomic_t" >&5
+echo "$as_me:11980: result: $ac_cv_type_sig_atomic_t" >&5
 echo "${ECHO_T}$ac_cv_type_sig_atomic_t" >&6
 if test $ac_cv_type_sig_atomic_t = yes; then
 
@@ -11940,14 +11987,14 @@
 
 fi
 
-echo "$as_me:11943: checking for size_t" >&5
+echo "$as_me:11990: checking for size_t" >&5
 echo $ECHO_N "checking for size_t... $ECHO_C" >&6
 if test "${ac_cv_have_size_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 11950 "configure"
+#line 11997 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -11961,16 +12008,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:11964: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12011: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:11967: \$? = $ac_status" >&5
+  echo "$as_me:12014: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:11970: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12017: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:11973: \$? = $ac_status" >&5
+  echo "$as_me:12020: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_size_t="yes"
 else
@@ -11982,7 +12029,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:11985: result: $ac_cv_have_size_t" >&5
+echo "$as_me:12032: result: $ac_cv_have_size_t" >&5
 echo "${ECHO_T}$ac_cv_have_size_t" >&6
 if test "x$ac_cv_have_size_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -11991,14 +12038,14 @@
 
 fi
 
-echo "$as_me:11994: checking for ssize_t" >&5
+echo "$as_me:12041: checking for ssize_t" >&5
 echo $ECHO_N "checking for ssize_t... $ECHO_C" >&6
 if test "${ac_cv_have_ssize_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12001 "configure"
+#line 12048 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12012,16 +12059,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12015: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12062: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12018: \$? = $ac_status" >&5
+  echo "$as_me:12065: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12021: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12068: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12024: \$? = $ac_status" >&5
+  echo "$as_me:12071: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_ssize_t="yes"
 else
@@ -12033,7 +12080,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12036: result: $ac_cv_have_ssize_t" >&5
+echo "$as_me:12083: result: $ac_cv_have_ssize_t" >&5
 echo "${ECHO_T}$ac_cv_have_ssize_t" >&6
 if test "x$ac_cv_have_ssize_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12042,14 +12089,14 @@
 
 fi
 
-echo "$as_me:12045: checking for clock_t" >&5
+echo "$as_me:12092: checking for clock_t" >&5
 echo $ECHO_N "checking for clock_t... $ECHO_C" >&6
 if test "${ac_cv_have_clock_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12052 "configure"
+#line 12099 "configure"
 #include "confdefs.h"
 
 #include <time.h>
@@ -12063,16 +12110,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12066: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12113: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12069: \$? = $ac_status" >&5
+  echo "$as_me:12116: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12072: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12119: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12075: \$? = $ac_status" >&5
+  echo "$as_me:12122: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_clock_t="yes"
 else
@@ -12084,7 +12131,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12087: result: $ac_cv_have_clock_t" >&5
+echo "$as_me:12134: result: $ac_cv_have_clock_t" >&5
 echo "${ECHO_T}$ac_cv_have_clock_t" >&6
 if test "x$ac_cv_have_clock_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12093,14 +12140,14 @@
 
 fi
 
-echo "$as_me:12096: checking for sa_family_t" >&5
+echo "$as_me:12143: checking for sa_family_t" >&5
 echo $ECHO_N "checking for sa_family_t... $ECHO_C" >&6
 if test "${ac_cv_have_sa_family_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12103 "configure"
+#line 12150 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12115,23 +12162,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12118: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12165: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12121: \$? = $ac_status" >&5
+  echo "$as_me:12168: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12124: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12171: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12127: \$? = $ac_status" >&5
+  echo "$as_me:12174: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_sa_family_t="yes"
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
  cat >conftest.$ac_ext <<_ACEOF
-#line 12134 "configure"
+#line 12181 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12147,16 +12194,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12150: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12197: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12153: \$? = $ac_status" >&5
+  echo "$as_me:12200: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12156: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12203: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12159: \$? = $ac_status" >&5
+  echo "$as_me:12206: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_sa_family_t="yes"
 else
@@ -12171,7 +12218,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12174: result: $ac_cv_have_sa_family_t" >&5
+echo "$as_me:12221: result: $ac_cv_have_sa_family_t" >&5
 echo "${ECHO_T}$ac_cv_have_sa_family_t" >&6
 if test "x$ac_cv_have_sa_family_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12180,14 +12227,14 @@
 
 fi
 
-echo "$as_me:12183: checking for pid_t" >&5
+echo "$as_me:12230: checking for pid_t" >&5
 echo $ECHO_N "checking for pid_t... $ECHO_C" >&6
 if test "${ac_cv_have_pid_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12190 "configure"
+#line 12237 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12201,16 +12248,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12204: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12251: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12207: \$? = $ac_status" >&5
+  echo "$as_me:12254: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12210: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12257: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12213: \$? = $ac_status" >&5
+  echo "$as_me:12260: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_pid_t="yes"
 else
@@ -12222,7 +12269,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12225: result: $ac_cv_have_pid_t" >&5
+echo "$as_me:12272: result: $ac_cv_have_pid_t" >&5
 echo "${ECHO_T}$ac_cv_have_pid_t" >&6
 if test "x$ac_cv_have_pid_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12231,14 +12278,14 @@
 
 fi
 
-echo "$as_me:12234: checking for mode_t" >&5
+echo "$as_me:12281: checking for mode_t" >&5
 echo $ECHO_N "checking for mode_t... $ECHO_C" >&6
 if test "${ac_cv_have_mode_t+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12241 "configure"
+#line 12288 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12252,16 +12299,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12255: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12302: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12258: \$? = $ac_status" >&5
+  echo "$as_me:12305: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12261: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12308: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12264: \$? = $ac_status" >&5
+  echo "$as_me:12311: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_mode_t="yes"
 else
@@ -12273,7 +12320,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12276: result: $ac_cv_have_mode_t" >&5
+echo "$as_me:12323: result: $ac_cv_have_mode_t" >&5
 echo "${ECHO_T}$ac_cv_have_mode_t" >&6
 if test "x$ac_cv_have_mode_t" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12282,14 +12329,14 @@
 
 fi
 
-echo "$as_me:12285: checking for struct sockaddr_storage" >&5
+echo "$as_me:12332: checking for struct sockaddr_storage" >&5
 echo $ECHO_N "checking for struct sockaddr_storage... $ECHO_C" >&6
 if test "${ac_cv_have_struct_sockaddr_storage+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12292 "configure"
+#line 12339 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12304,16 +12351,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12307: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12354: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12310: \$? = $ac_status" >&5
+  echo "$as_me:12357: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12313: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12360: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12316: \$? = $ac_status" >&5
+  echo "$as_me:12363: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_struct_sockaddr_storage="yes"
 else
@@ -12325,7 +12372,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12328: result: $ac_cv_have_struct_sockaddr_storage" >&5
+echo "$as_me:12375: result: $ac_cv_have_struct_sockaddr_storage" >&5
 echo "${ECHO_T}$ac_cv_have_struct_sockaddr_storage" >&6
 if test "x$ac_cv_have_struct_sockaddr_storage" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12334,14 +12381,14 @@
 
 fi
 
-echo "$as_me:12337: checking for struct sockaddr_in6" >&5
+echo "$as_me:12384: checking for struct sockaddr_in6" >&5
 echo $ECHO_N "checking for struct sockaddr_in6... $ECHO_C" >&6
 if test "${ac_cv_have_struct_sockaddr_in6+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12344 "configure"
+#line 12391 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12356,16 +12403,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12359: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12406: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12362: \$? = $ac_status" >&5
+  echo "$as_me:12409: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12365: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12412: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12368: \$? = $ac_status" >&5
+  echo "$as_me:12415: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_struct_sockaddr_in6="yes"
 else
@@ -12377,7 +12424,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12380: result: $ac_cv_have_struct_sockaddr_in6" >&5
+echo "$as_me:12427: result: $ac_cv_have_struct_sockaddr_in6" >&5
 echo "${ECHO_T}$ac_cv_have_struct_sockaddr_in6" >&6
 if test "x$ac_cv_have_struct_sockaddr_in6" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12386,14 +12433,14 @@
 
 fi
 
-echo "$as_me:12389: checking for struct in6_addr" >&5
+echo "$as_me:12436: checking for struct in6_addr" >&5
 echo $ECHO_N "checking for struct in6_addr... $ECHO_C" >&6
 if test "${ac_cv_have_struct_in6_addr+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12396 "configure"
+#line 12443 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12408,16 +12455,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12411: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12458: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12414: \$? = $ac_status" >&5
+  echo "$as_me:12461: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12417: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12464: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12420: \$? = $ac_status" >&5
+  echo "$as_me:12467: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_struct_in6_addr="yes"
 else
@@ -12429,7 +12476,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12432: result: $ac_cv_have_struct_in6_addr" >&5
+echo "$as_me:12479: result: $ac_cv_have_struct_in6_addr" >&5
 echo "${ECHO_T}$ac_cv_have_struct_in6_addr" >&6
 if test "x$ac_cv_have_struct_in6_addr" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12438,14 +12485,14 @@
 
 fi
 
-echo "$as_me:12441: checking for struct addrinfo" >&5
+echo "$as_me:12488: checking for struct addrinfo" >&5
 echo $ECHO_N "checking for struct addrinfo... $ECHO_C" >&6
 if test "${ac_cv_have_struct_addrinfo+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12448 "configure"
+#line 12495 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -12461,16 +12508,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12464: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12511: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12467: \$? = $ac_status" >&5
+  echo "$as_me:12514: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12470: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12517: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12473: \$? = $ac_status" >&5
+  echo "$as_me:12520: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_struct_addrinfo="yes"
 else
@@ -12482,7 +12529,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12485: result: $ac_cv_have_struct_addrinfo" >&5
+echo "$as_me:12532: result: $ac_cv_have_struct_addrinfo" >&5
 echo "${ECHO_T}$ac_cv_have_struct_addrinfo" >&6
 if test "x$ac_cv_have_struct_addrinfo" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12491,14 +12538,14 @@
 
 fi
 
-echo "$as_me:12494: checking for struct timeval" >&5
+echo "$as_me:12541: checking for struct timeval" >&5
 echo $ECHO_N "checking for struct timeval... $ECHO_C" >&6
 if test "${ac_cv_have_struct_timeval+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 12501 "configure"
+#line 12548 "configure"
 #include "confdefs.h"
  #include <sys/time.h>
 int
@@ -12510,16 +12557,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12513: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12560: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12516: \$? = $ac_status" >&5
+  echo "$as_me:12563: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12519: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12566: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12522: \$? = $ac_status" >&5
+  echo "$as_me:12569: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_struct_timeval="yes"
 else
@@ -12531,7 +12578,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:12534: result: $ac_cv_have_struct_timeval" >&5
+echo "$as_me:12581: result: $ac_cv_have_struct_timeval" >&5
 echo "${ECHO_T}$ac_cv_have_struct_timeval" >&6
 if test "x$ac_cv_have_struct_timeval" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -12541,13 +12588,13 @@
 	have_struct_timeval=1
 fi
 
-echo "$as_me:12544: checking for struct timespec" >&5
+echo "$as_me:12591: checking for struct timespec" >&5
 echo $ECHO_N "checking for struct timespec... $ECHO_C" >&6
 if test "${ac_cv_type_struct_timespec+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 12550 "configure"
+#line 12597 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -12562,16 +12609,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:12565: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:12612: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:12568: \$? = $ac_status" >&5
+  echo "$as_me:12615: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:12571: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12618: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12574: \$? = $ac_status" >&5
+  echo "$as_me:12621: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_type_struct_timespec=yes
 else
@@ -12581,7 +12628,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:12584: result: $ac_cv_type_struct_timespec" >&5
+echo "$as_me:12631: result: $ac_cv_type_struct_timespec" >&5
 echo "${ECHO_T}$ac_cv_type_struct_timespec" >&6
 if test $ac_cv_type_struct_timespec = yes; then
 
@@ -12601,12 +12648,12 @@
 	exit 1;
 else
 	if test "$cross_compiling" = yes; then
-  { { echo "$as_me:12604: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:12651: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 12609 "configure"
+#line 12656 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -12634,15 +12681,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:12637: \"$ac_link\"") >&5
+if { (eval echo "$as_me:12684: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:12640: \$? = $ac_status" >&5
+  echo "$as_me:12687: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:12642: \"$ac_try\"") >&5
+  { (eval echo "$as_me:12689: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:12645: \$? = $ac_status" >&5
+  echo "$as_me:12692: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    true
 else
@@ -12661,14 +12708,14 @@
 # look for field 'ut_host' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_host
-	echo "$as_me:12664: checking for ut_host field in utmp.h" >&5
+	echo "$as_me:12711: checking for ut_host field in utmp.h" >&5
 echo $ECHO_N "checking for ut_host field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12671 "configure"
+#line 12718 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -12685,7 +12732,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12688: result: $ossh_result" >&5
+		echo "$as_me:12735: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12694,21 +12741,21 @@
 
 		fi
 	else
-		echo "$as_me:12697: result: no" >&5
+		echo "$as_me:12744: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_host' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_host
-	echo "$as_me:12704: checking for ut_host field in utmpx.h" >&5
+	echo "$as_me:12751: checking for ut_host field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_host field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12711 "configure"
+#line 12758 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -12725,7 +12772,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12728: result: $ossh_result" >&5
+		echo "$as_me:12775: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12734,21 +12781,21 @@
 
 		fi
 	else
-		echo "$as_me:12737: result: no" >&5
+		echo "$as_me:12784: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'syslen' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"syslen
-	echo "$as_me:12744: checking for syslen field in utmpx.h" >&5
+	echo "$as_me:12791: checking for syslen field in utmpx.h" >&5
 echo $ECHO_N "checking for syslen field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12751 "configure"
+#line 12798 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -12765,7 +12812,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12768: result: $ossh_result" >&5
+		echo "$as_me:12815: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12774,21 +12821,21 @@
 
 		fi
 	else
-		echo "$as_me:12777: result: no" >&5
+		echo "$as_me:12824: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_pid' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_pid
-	echo "$as_me:12784: checking for ut_pid field in utmp.h" >&5
+	echo "$as_me:12831: checking for ut_pid field in utmp.h" >&5
 echo $ECHO_N "checking for ut_pid field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12791 "configure"
+#line 12838 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -12805,7 +12852,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12808: result: $ossh_result" >&5
+		echo "$as_me:12855: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12814,21 +12861,21 @@
 
 		fi
 	else
-		echo "$as_me:12817: result: no" >&5
+		echo "$as_me:12864: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_type' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_type
-	echo "$as_me:12824: checking for ut_type field in utmp.h" >&5
+	echo "$as_me:12871: checking for ut_type field in utmp.h" >&5
 echo $ECHO_N "checking for ut_type field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12831 "configure"
+#line 12878 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -12845,7 +12892,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12848: result: $ossh_result" >&5
+		echo "$as_me:12895: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12854,21 +12901,21 @@
 
 		fi
 	else
-		echo "$as_me:12857: result: no" >&5
+		echo "$as_me:12904: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_type' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_type
-	echo "$as_me:12864: checking for ut_type field in utmpx.h" >&5
+	echo "$as_me:12911: checking for ut_type field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_type field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12871 "configure"
+#line 12918 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -12885,7 +12932,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12888: result: $ossh_result" >&5
+		echo "$as_me:12935: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12894,21 +12941,21 @@
 
 		fi
 	else
-		echo "$as_me:12897: result: no" >&5
+		echo "$as_me:12944: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_tv' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_tv
-	echo "$as_me:12904: checking for ut_tv field in utmp.h" >&5
+	echo "$as_me:12951: checking for ut_tv field in utmp.h" >&5
 echo $ECHO_N "checking for ut_tv field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12911 "configure"
+#line 12958 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -12925,7 +12972,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12928: result: $ossh_result" >&5
+		echo "$as_me:12975: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12934,21 +12981,21 @@
 
 		fi
 	else
-		echo "$as_me:12937: result: no" >&5
+		echo "$as_me:12984: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_id' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_id
-	echo "$as_me:12944: checking for ut_id field in utmp.h" >&5
+	echo "$as_me:12991: checking for ut_id field in utmp.h" >&5
 echo $ECHO_N "checking for ut_id field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12951 "configure"
+#line 12998 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -12965,7 +13012,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:12968: result: $ossh_result" >&5
+		echo "$as_me:13015: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -12974,21 +13021,21 @@
 
 		fi
 	else
-		echo "$as_me:12977: result: no" >&5
+		echo "$as_me:13024: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_id' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_id
-	echo "$as_me:12984: checking for ut_id field in utmpx.h" >&5
+	echo "$as_me:13031: checking for ut_id field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_id field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 12991 "configure"
+#line 13038 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -13005,7 +13052,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13008: result: $ossh_result" >&5
+		echo "$as_me:13055: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13014,21 +13061,21 @@
 
 		fi
 	else
-		echo "$as_me:13017: result: no" >&5
+		echo "$as_me:13064: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_addr' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_addr
-	echo "$as_me:13024: checking for ut_addr field in utmp.h" >&5
+	echo "$as_me:13071: checking for ut_addr field in utmp.h" >&5
 echo $ECHO_N "checking for ut_addr field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13031 "configure"
+#line 13078 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -13045,7 +13092,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13048: result: $ossh_result" >&5
+		echo "$as_me:13095: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13054,21 +13101,21 @@
 
 		fi
 	else
-		echo "$as_me:13057: result: no" >&5
+		echo "$as_me:13104: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_addr' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_addr
-	echo "$as_me:13064: checking for ut_addr field in utmpx.h" >&5
+	echo "$as_me:13111: checking for ut_addr field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_addr field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13071 "configure"
+#line 13118 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -13085,7 +13132,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13088: result: $ossh_result" >&5
+		echo "$as_me:13135: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13094,21 +13141,21 @@
 
 		fi
 	else
-		echo "$as_me:13097: result: no" >&5
+		echo "$as_me:13144: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_addr_v6' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_addr_v6
-	echo "$as_me:13104: checking for ut_addr_v6 field in utmp.h" >&5
+	echo "$as_me:13151: checking for ut_addr_v6 field in utmp.h" >&5
 echo $ECHO_N "checking for ut_addr_v6 field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13111 "configure"
+#line 13158 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -13125,7 +13172,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13128: result: $ossh_result" >&5
+		echo "$as_me:13175: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13134,21 +13181,21 @@
 
 		fi
 	else
-		echo "$as_me:13137: result: no" >&5
+		echo "$as_me:13184: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_addr_v6' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_addr_v6
-	echo "$as_me:13144: checking for ut_addr_v6 field in utmpx.h" >&5
+	echo "$as_me:13191: checking for ut_addr_v6 field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_addr_v6 field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13151 "configure"
+#line 13198 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -13165,7 +13212,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13168: result: $ossh_result" >&5
+		echo "$as_me:13215: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13174,21 +13221,21 @@
 
 		fi
 	else
-		echo "$as_me:13177: result: no" >&5
+		echo "$as_me:13224: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_exit' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_exit
-	echo "$as_me:13184: checking for ut_exit field in utmp.h" >&5
+	echo "$as_me:13231: checking for ut_exit field in utmp.h" >&5
 echo $ECHO_N "checking for ut_exit field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13191 "configure"
+#line 13238 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -13205,7 +13252,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13208: result: $ossh_result" >&5
+		echo "$as_me:13255: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13214,21 +13261,21 @@
 
 		fi
 	else
-		echo "$as_me:13217: result: no" >&5
+		echo "$as_me:13264: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_time' in header 'utmp.h'
 		ossh_safe=`echo "utmp.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_time
-	echo "$as_me:13224: checking for ut_time field in utmp.h" >&5
+	echo "$as_me:13271: checking for ut_time field in utmp.h" >&5
 echo $ECHO_N "checking for ut_time field in utmp.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13231 "configure"
+#line 13278 "configure"
 #include "confdefs.h"
 #include <utmp.h>
 
@@ -13245,7 +13292,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13248: result: $ossh_result" >&5
+		echo "$as_me:13295: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13254,21 +13301,21 @@
 
 		fi
 	else
-		echo "$as_me:13257: result: no" >&5
+		echo "$as_me:13304: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_time' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_time
-	echo "$as_me:13264: checking for ut_time field in utmpx.h" >&5
+	echo "$as_me:13311: checking for ut_time field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_time field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13271 "configure"
+#line 13318 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -13285,7 +13332,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13288: result: $ossh_result" >&5
+		echo "$as_me:13335: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13294,21 +13341,21 @@
 
 		fi
 	else
-		echo "$as_me:13297: result: no" >&5
+		echo "$as_me:13344: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
 # look for field 'ut_tv' in header 'utmpx.h'
 		ossh_safe=`echo "utmpx.h" | sed 'y%./+-%__p_%'`
 		ossh_varname="ossh_cv_$ossh_safe""_has_"ut_tv
-	echo "$as_me:13304: checking for ut_tv field in utmpx.h" >&5
+	echo "$as_me:13351: checking for ut_tv field in utmpx.h" >&5
 echo $ECHO_N "checking for ut_tv field in utmpx.h... $ECHO_C" >&6
 	if eval "test \"\${$ossh_varname+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 		cat >conftest.$ac_ext <<_ACEOF
-#line 13311 "configure"
+#line 13358 "configure"
 #include "confdefs.h"
 #include <utmpx.h>
 
@@ -13325,7 +13372,7 @@
 
 	ossh_result=`eval 'echo $'"$ossh_varname"`
 	if test -n "`echo $ossh_varname`"; then
-		echo "$as_me:13328: result: $ossh_result" >&5
+		echo "$as_me:13375: result: $ossh_result" >&5
 echo "${ECHO_T}$ossh_result" >&6
 		if test "x$ossh_result" = "xyes"; then
 			cat >>confdefs.h <<\EOF
@@ -13334,17 +13381,17 @@
 
 		fi
 	else
-		echo "$as_me:13337: result: no" >&5
+		echo "$as_me:13384: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 
-echo "$as_me:13341: checking for struct stat.st_blksize" >&5
+echo "$as_me:13388: checking for struct stat.st_blksize" >&5
 echo $ECHO_N "checking for struct stat.st_blksize... $ECHO_C" >&6
 if test "${ac_cv_member_struct_stat_st_blksize+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 13347 "configure"
+#line 13394 "configure"
 #include "confdefs.h"
 $ac_includes_default
 int
@@ -13358,16 +13405,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13361: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:13408: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13364: \$? = $ac_status" >&5
+  echo "$as_me:13411: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13367: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13414: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13370: \$? = $ac_status" >&5
+  echo "$as_me:13417: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_member_struct_stat_st_blksize=yes
 else
@@ -13377,7 +13424,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:13380: result: $ac_cv_member_struct_stat_st_blksize" >&5
+echo "$as_me:13427: result: $ac_cv_member_struct_stat_st_blksize" >&5
 echo "${ECHO_T}$ac_cv_member_struct_stat_st_blksize" >&6
 if test $ac_cv_member_struct_stat_st_blksize = yes; then
 
@@ -13387,14 +13434,14 @@
 
 fi
 
-echo "$as_me:13390: checking for ss_family field in struct sockaddr_storage" >&5
+echo "$as_me:13437: checking for ss_family field in struct sockaddr_storage" >&5
 echo $ECHO_N "checking for ss_family field in struct sockaddr_storage... $ECHO_C" >&6
 if test "${ac_cv_have_ss_family_in_struct_ss+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13397 "configure"
+#line 13444 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -13409,16 +13456,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13412: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:13459: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13415: \$? = $ac_status" >&5
+  echo "$as_me:13462: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13418: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13465: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13421: \$? = $ac_status" >&5
+  echo "$as_me:13468: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_ss_family_in_struct_ss="yes"
 else
@@ -13429,7 +13476,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:13432: result: $ac_cv_have_ss_family_in_struct_ss" >&5
+echo "$as_me:13479: result: $ac_cv_have_ss_family_in_struct_ss" >&5
 echo "${ECHO_T}$ac_cv_have_ss_family_in_struct_ss" >&6
 if test "x$ac_cv_have_ss_family_in_struct_ss" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13438,14 +13485,14 @@
 
 fi
 
-echo "$as_me:13441: checking for __ss_family field in struct sockaddr_storage" >&5
+echo "$as_me:13488: checking for __ss_family field in struct sockaddr_storage" >&5
 echo $ECHO_N "checking for __ss_family field in struct sockaddr_storage... $ECHO_C" >&6
 if test "${ac_cv_have___ss_family_in_struct_ss+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13448 "configure"
+#line 13495 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -13460,16 +13507,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13463: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:13510: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13466: \$? = $ac_status" >&5
+  echo "$as_me:13513: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13469: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13516: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13472: \$? = $ac_status" >&5
+  echo "$as_me:13519: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have___ss_family_in_struct_ss="yes"
 else
@@ -13481,7 +13528,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:13484: result: $ac_cv_have___ss_family_in_struct_ss" >&5
+echo "$as_me:13531: result: $ac_cv_have___ss_family_in_struct_ss" >&5
 echo "${ECHO_T}$ac_cv_have___ss_family_in_struct_ss" >&6
 if test "x$ac_cv_have___ss_family_in_struct_ss" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13490,14 +13537,14 @@
 
 fi
 
-echo "$as_me:13493: checking for pw_class field in struct passwd" >&5
+echo "$as_me:13540: checking for pw_class field in struct passwd" >&5
 echo $ECHO_N "checking for pw_class field in struct passwd... $ECHO_C" >&6
 if test "${ac_cv_have_pw_class_in_struct_passwd+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13500 "configure"
+#line 13547 "configure"
 #include "confdefs.h"
 
 #include <pwd.h>
@@ -13511,16 +13558,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13514: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:13561: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13517: \$? = $ac_status" >&5
+  echo "$as_me:13564: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13520: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13567: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13523: \$? = $ac_status" >&5
+  echo "$as_me:13570: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_pw_class_in_struct_passwd="yes"
 else
@@ -13532,7 +13579,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:13535: result: $ac_cv_have_pw_class_in_struct_passwd" >&5
+echo "$as_me:13582: result: $ac_cv_have_pw_class_in_struct_passwd" >&5
 echo "${ECHO_T}$ac_cv_have_pw_class_in_struct_passwd" >&6
 if test "x$ac_cv_have_pw_class_in_struct_passwd" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13541,14 +13588,14 @@
 
 fi
 
-echo "$as_me:13544: checking for pw_expire field in struct passwd" >&5
+echo "$as_me:13591: checking for pw_expire field in struct passwd" >&5
 echo $ECHO_N "checking for pw_expire field in struct passwd... $ECHO_C" >&6
 if test "${ac_cv_have_pw_expire_in_struct_passwd+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13551 "configure"
+#line 13598 "configure"
 #include "confdefs.h"
 
 #include <pwd.h>
@@ -13562,16 +13609,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13565: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:13612: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13568: \$? = $ac_status" >&5
+  echo "$as_me:13615: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13571: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13618: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13574: \$? = $ac_status" >&5
+  echo "$as_me:13621: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_pw_expire_in_struct_passwd="yes"
 else
@@ -13583,7 +13630,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:13586: result: $ac_cv_have_pw_expire_in_struct_passwd" >&5
+echo "$as_me:13633: result: $ac_cv_have_pw_expire_in_struct_passwd" >&5
 echo "${ECHO_T}$ac_cv_have_pw_expire_in_struct_passwd" >&6
 if test "x$ac_cv_have_pw_expire_in_struct_passwd" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13592,14 +13639,14 @@
 
 fi
 
-echo "$as_me:13595: checking for pw_change field in struct passwd" >&5
+echo "$as_me:13642: checking for pw_change field in struct passwd" >&5
 echo $ECHO_N "checking for pw_change field in struct passwd... $ECHO_C" >&6
 if test "${ac_cv_have_pw_change_in_struct_passwd+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13602 "configure"
+#line 13649 "configure"
 #include "confdefs.h"
 
 #include <pwd.h>
@@ -13613,16 +13660,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:13616: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:13663: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:13619: \$? = $ac_status" >&5
+  echo "$as_me:13666: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:13622: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13669: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13625: \$? = $ac_status" >&5
+  echo "$as_me:13672: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_pw_change_in_struct_passwd="yes"
 else
@@ -13634,7 +13681,7 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 fi
-echo "$as_me:13637: result: $ac_cv_have_pw_change_in_struct_passwd" >&5
+echo "$as_me:13684: result: $ac_cv_have_pw_change_in_struct_passwd" >&5
 echo "${ECHO_T}$ac_cv_have_pw_change_in_struct_passwd" >&6
 if test "x$ac_cv_have_pw_change_in_struct_passwd" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13643,19 +13690,19 @@
 
 fi
 
-echo "$as_me:13646: checking for msg_accrights field in struct msghdr" >&5
+echo "$as_me:13693: checking for msg_accrights field in struct msghdr" >&5
 echo $ECHO_N "checking for msg_accrights field in struct msghdr... $ECHO_C" >&6
 if test "${ac_cv_have_accrights_in_msghdr+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	if test "$cross_compiling" = yes; then
-  { { echo "$as_me:13653: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:13700: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 13658 "configure"
+#line 13705 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -13672,15 +13719,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:13675: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13722: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13678: \$? = $ac_status" >&5
+  echo "$as_me:13725: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:13680: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13727: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13683: \$? = $ac_status" >&5
+  echo "$as_me:13730: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_accrights_in_msghdr="yes"
 else
@@ -13694,7 +13741,7 @@
 fi
 
 fi
-echo "$as_me:13697: result: $ac_cv_have_accrights_in_msghdr" >&5
+echo "$as_me:13744: result: $ac_cv_have_accrights_in_msghdr" >&5
 echo "${ECHO_T}$ac_cv_have_accrights_in_msghdr" >&6
 if test "x$ac_cv_have_accrights_in_msghdr" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13703,19 +13750,19 @@
 
 fi
 
-echo "$as_me:13706: checking for msg_control field in struct msghdr" >&5
+echo "$as_me:13753: checking for msg_control field in struct msghdr" >&5
 echo $ECHO_N "checking for msg_control field in struct msghdr... $ECHO_C" >&6
 if test "${ac_cv_have_control_in_msghdr+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	if test "$cross_compiling" = yes; then
-  { { echo "$as_me:13713: error: cannot run test program while cross compiling" >&5
+  { { echo "$as_me:13760: error: cannot run test program while cross compiling" >&5
 echo "$as_me: error: cannot run test program while cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 13718 "configure"
+#line 13765 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -13732,15 +13779,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:13735: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13782: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13738: \$? = $ac_status" >&5
+  echo "$as_me:13785: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:13740: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13787: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13743: \$? = $ac_status" >&5
+  echo "$as_me:13790: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_control_in_msghdr="yes"
 else
@@ -13754,7 +13801,7 @@
 fi
 
 fi
-echo "$as_me:13757: result: $ac_cv_have_control_in_msghdr" >&5
+echo "$as_me:13804: result: $ac_cv_have_control_in_msghdr" >&5
 echo "${ECHO_T}$ac_cv_have_control_in_msghdr" >&6
 if test "x$ac_cv_have_control_in_msghdr" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13763,14 +13810,14 @@
 
 fi
 
-echo "$as_me:13766: checking if libc defines __progname" >&5
+echo "$as_me:13813: checking if libc defines __progname" >&5
 echo $ECHO_N "checking if libc defines __progname... $ECHO_C" >&6
 if test "${ac_cv_libc_defines___progname+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13773 "configure"
+#line 13820 "configure"
 #include "confdefs.h"
 
 int
@@ -13782,16 +13829,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:13785: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13832: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13788: \$? = $ac_status" >&5
+  echo "$as_me:13835: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:13791: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13838: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13794: \$? = $ac_status" >&5
+  echo "$as_me:13841: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_libc_defines___progname="yes"
 else
@@ -13803,7 +13850,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:13806: result: $ac_cv_libc_defines___progname" >&5
+echo "$as_me:13853: result: $ac_cv_libc_defines___progname" >&5
 echo "${ECHO_T}$ac_cv_libc_defines___progname" >&6
 if test "x$ac_cv_libc_defines___progname" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13812,14 +13859,14 @@
 
 fi
 
-echo "$as_me:13815: checking whether $CC implements __FUNCTION__" >&5
+echo "$as_me:13862: checking whether $CC implements __FUNCTION__" >&5
 echo $ECHO_N "checking whether $CC implements __FUNCTION__... $ECHO_C" >&6
 if test "${ac_cv_cc_implements___FUNCTION__+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13822 "configure"
+#line 13869 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -13833,16 +13880,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:13836: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13883: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13839: \$? = $ac_status" >&5
+  echo "$as_me:13886: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:13842: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13889: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13845: \$? = $ac_status" >&5
+  echo "$as_me:13892: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_cc_implements___FUNCTION__="yes"
 else
@@ -13854,7 +13901,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:13857: result: $ac_cv_cc_implements___FUNCTION__" >&5
+echo "$as_me:13904: result: $ac_cv_cc_implements___FUNCTION__" >&5
 echo "${ECHO_T}$ac_cv_cc_implements___FUNCTION__" >&6
 if test "x$ac_cv_cc_implements___FUNCTION__" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13863,14 +13910,14 @@
 
 fi
 
-echo "$as_me:13866: checking whether $CC implements __func__" >&5
+echo "$as_me:13913: checking whether $CC implements __func__" >&5
 echo $ECHO_N "checking whether $CC implements __func__... $ECHO_C" >&6
 if test "${ac_cv_cc_implements___func__+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13873 "configure"
+#line 13920 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -13884,16 +13931,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:13887: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13934: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13890: \$? = $ac_status" >&5
+  echo "$as_me:13937: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:13893: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13940: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13896: \$? = $ac_status" >&5
+  echo "$as_me:13943: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_cc_implements___func__="yes"
 else
@@ -13905,7 +13952,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:13908: result: $ac_cv_cc_implements___func__" >&5
+echo "$as_me:13955: result: $ac_cv_cc_implements___func__" >&5
 echo "${ECHO_T}$ac_cv_cc_implements___func__" >&6
 if test "x$ac_cv_cc_implements___func__" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13914,14 +13961,14 @@
 
 fi
 
-echo "$as_me:13917: checking whether getopt has optreset support" >&5
+echo "$as_me:13964: checking whether getopt has optreset support" >&5
 echo $ECHO_N "checking whether getopt has optreset support... $ECHO_C" >&6
 if test "${ac_cv_have_getopt_optreset+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13924 "configure"
+#line 13971 "configure"
 #include "confdefs.h"
 
 #include <getopt.h>
@@ -13935,16 +13982,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:13938: \"$ac_link\"") >&5
+if { (eval echo "$as_me:13985: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13941: \$? = $ac_status" >&5
+  echo "$as_me:13988: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:13944: \"$ac_try\"") >&5
+  { (eval echo "$as_me:13991: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13947: \$? = $ac_status" >&5
+  echo "$as_me:13994: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_have_getopt_optreset="yes"
 else
@@ -13956,7 +14003,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:13959: result: $ac_cv_have_getopt_optreset" >&5
+echo "$as_me:14006: result: $ac_cv_have_getopt_optreset" >&5
 echo "${ECHO_T}$ac_cv_have_getopt_optreset" >&6
 if test "x$ac_cv_have_getopt_optreset" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -13965,14 +14012,14 @@
 
 fi
 
-echo "$as_me:13968: checking if libc defines sys_errlist" >&5
+echo "$as_me:14015: checking if libc defines sys_errlist" >&5
 echo $ECHO_N "checking if libc defines sys_errlist... $ECHO_C" >&6
 if test "${ac_cv_libc_defines_sys_errlist+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 13975 "configure"
+#line 14022 "configure"
 #include "confdefs.h"
 
 int
@@ -13984,16 +14031,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:13987: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14034: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:13990: \$? = $ac_status" >&5
+  echo "$as_me:14037: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:13993: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14040: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:13996: \$? = $ac_status" >&5
+  echo "$as_me:14043: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_libc_defines_sys_errlist="yes"
 else
@@ -14005,7 +14052,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:14008: result: $ac_cv_libc_defines_sys_errlist" >&5
+echo "$as_me:14055: result: $ac_cv_libc_defines_sys_errlist" >&5
 echo "${ECHO_T}$ac_cv_libc_defines_sys_errlist" >&6
 if test "x$ac_cv_libc_defines_sys_errlist" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -14014,14 +14061,14 @@
 
 fi
 
-echo "$as_me:14017: checking if libc defines sys_nerr" >&5
+echo "$as_me:14064: checking if libc defines sys_nerr" >&5
 echo $ECHO_N "checking if libc defines sys_nerr... $ECHO_C" >&6
 if test "${ac_cv_libc_defines_sys_nerr+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
 
 	cat >conftest.$ac_ext <<_ACEOF
-#line 14024 "configure"
+#line 14071 "configure"
 #include "confdefs.h"
 
 int
@@ -14033,16 +14080,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14036: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14083: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14039: \$? = $ac_status" >&5
+  echo "$as_me:14086: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14042: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14089: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14045: \$? = $ac_status" >&5
+  echo "$as_me:14092: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    ac_cv_libc_defines_sys_nerr="yes"
 else
@@ -14054,7 +14101,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 
 fi
-echo "$as_me:14057: result: $ac_cv_libc_defines_sys_nerr" >&5
+echo "$as_me:14104: result: $ac_cv_libc_defines_sys_nerr" >&5
 echo "${ECHO_T}$ac_cv_libc_defines_sys_nerr" >&6
 if test "x$ac_cv_libc_defines_sys_nerr" = "xyes" ; then
 	cat >>confdefs.h <<\EOF
@@ -14085,23 +14132,23 @@
 for ac_header in sectok.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:14088: checking for $ac_header" >&5
+echo "$as_me:14135: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 14094 "configure"
+#line 14141 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:14098: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:14145: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:14104: \$? = $ac_status" >&5
+  echo "$as_me:14151: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -14120,7 +14167,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:14123: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:14170: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -14131,12 +14178,12 @@
 done
 
 			if test "$ac_cv_header_sectok_h" != yes; then
-				{ { echo "$as_me:14134: error: Can't find sectok.h" >&5
+				{ { echo "$as_me:14181: error: Can't find sectok.h" >&5
 echo "$as_me: error: Can't find sectok.h" >&2;}
    { (exit 1); exit 1; }; }
 			fi
 
-echo "$as_me:14139: checking for sectok_open in -lsectok" >&5
+echo "$as_me:14186: checking for sectok_open in -lsectok" >&5
 echo $ECHO_N "checking for sectok_open in -lsectok... $ECHO_C" >&6
 if test "${ac_cv_lib_sectok_sectok_open+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14144,7 +14191,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lsectok  $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 14147 "configure"
+#line 14194 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14163,16 +14210,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14166: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14213: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14169: \$? = $ac_status" >&5
+  echo "$as_me:14216: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14172: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14219: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14175: \$? = $ac_status" >&5
+  echo "$as_me:14222: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_sectok_sectok_open=yes
 else
@@ -14183,7 +14230,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:14186: result: $ac_cv_lib_sectok_sectok_open" >&5
+echo "$as_me:14233: result: $ac_cv_lib_sectok_sectok_open" >&5
 echo "${ECHO_T}$ac_cv_lib_sectok_sectok_open" >&6
 if test $ac_cv_lib_sectok_sectok_open = yes; then
   cat >>confdefs.h <<EOF
@@ -14195,7 +14242,7 @@
 fi
 
 			if test "$ac_cv_lib_sectok_sectok_open" != yes; then
-				{ { echo "$as_me:14198: error: Can't find libsectok" >&5
+				{ { echo "$as_me:14245: error: Can't find libsectok" >&5
 echo "$as_me: error: Can't find libsectok" >&2;}
    { (exit 1); exit 1; }; }
 			fi
@@ -14225,7 +14272,7 @@
   OPENSC_CONFIG=$opensc_config_prefix/bin/opensc-config
   # Extract the first word of "opensc-config", so it can be a program name with args.
 set dummy opensc-config; ac_word=$2
-echo "$as_me:14228: checking for $ac_word" >&5
+echo "$as_me:14275: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_OPENSC_CONFIG+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14242,7 +14289,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_OPENSC_CONFIG="$ac_dir/$ac_word"
-   echo "$as_me:14245: found $ac_dir/$ac_word" >&5
+   echo "$as_me:14292: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -14254,10 +14301,10 @@
 OPENSC_CONFIG=$ac_cv_path_OPENSC_CONFIG
 
 if test -n "$OPENSC_CONFIG"; then
-  echo "$as_me:14257: result: $OPENSC_CONFIG" >&5
+  echo "$as_me:14304: result: $OPENSC_CONFIG" >&5
 echo "${ECHO_T}$OPENSC_CONFIG" >&6
 else
-  echo "$as_me:14260: result: no" >&5
+  echo "$as_me:14307: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -14291,7 +14338,7 @@
 #define DNS 1
 EOF
 
-			echo "$as_me:14294: checking for library containing getrrsetbyname" >&5
+			echo "$as_me:14341: checking for library containing getrrsetbyname" >&5
 echo $ECHO_N "checking for library containing getrrsetbyname... $ECHO_C" >&6
 if test "${ac_cv_search_getrrsetbyname+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14299,7 +14346,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_getrrsetbyname=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 14302 "configure"
+#line 14349 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14318,16 +14365,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14321: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14368: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14324: \$? = $ac_status" >&5
+  echo "$as_me:14371: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14327: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14374: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14330: \$? = $ac_status" >&5
+  echo "$as_me:14377: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_getrrsetbyname="none required"
 else
@@ -14339,7 +14386,7 @@
   for ac_lib in resolv; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 14342 "configure"
+#line 14389 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14358,16 +14405,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14361: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14408: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14364: \$? = $ac_status" >&5
+  echo "$as_me:14411: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14367: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14414: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14370: \$? = $ac_status" >&5
+  echo "$as_me:14417: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_getrrsetbyname="-l$ac_lib"
 break
@@ -14380,7 +14427,7 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:14383: result: $ac_cv_search_getrrsetbyname" >&5
+echo "$as_me:14430: result: $ac_cv_search_getrrsetbyname" >&5
 echo "${ECHO_T}$ac_cv_search_getrrsetbyname" >&6
 if test "$ac_cv_search_getrrsetbyname" != no; then
   test "$ac_cv_search_getrrsetbyname" = "none required" || LIBS="$ac_cv_search_getrrsetbyname $LIBS"
@@ -14391,7 +14438,7 @@
 else
 
 					# Needed by our getrrsetbyname()
-					echo "$as_me:14394: checking for library containing res_query" >&5
+					echo "$as_me:14441: checking for library containing res_query" >&5
 echo $ECHO_N "checking for library containing res_query... $ECHO_C" >&6
 if test "${ac_cv_search_res_query+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14399,7 +14446,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_res_query=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 14402 "configure"
+#line 14449 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14418,16 +14465,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14421: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14468: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14424: \$? = $ac_status" >&5
+  echo "$as_me:14471: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14427: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14474: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14430: \$? = $ac_status" >&5
+  echo "$as_me:14477: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_res_query="none required"
 else
@@ -14439,7 +14486,7 @@
   for ac_lib in resolv; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 14442 "configure"
+#line 14489 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14458,16 +14505,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14461: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14508: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14464: \$? = $ac_status" >&5
+  echo "$as_me:14511: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14467: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14514: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14470: \$? = $ac_status" >&5
+  echo "$as_me:14517: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_res_query="-l$ac_lib"
 break
@@ -14480,14 +14527,14 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:14483: result: $ac_cv_search_res_query" >&5
+echo "$as_me:14530: result: $ac_cv_search_res_query" >&5
 echo "${ECHO_T}$ac_cv_search_res_query" >&6
 if test "$ac_cv_search_res_query" != no; then
   test "$ac_cv_search_res_query" = "none required" || LIBS="$ac_cv_search_res_query $LIBS"
 
 fi
 
-					echo "$as_me:14490: checking for library containing dn_expand" >&5
+					echo "$as_me:14537: checking for library containing dn_expand" >&5
 echo $ECHO_N "checking for library containing dn_expand... $ECHO_C" >&6
 if test "${ac_cv_search_dn_expand+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14495,7 +14542,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_dn_expand=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 14498 "configure"
+#line 14545 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14514,16 +14561,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14517: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14564: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14520: \$? = $ac_status" >&5
+  echo "$as_me:14567: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14523: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14570: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14526: \$? = $ac_status" >&5
+  echo "$as_me:14573: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_dn_expand="none required"
 else
@@ -14535,7 +14582,7 @@
   for ac_lib in resolv; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 14538 "configure"
+#line 14585 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14554,16 +14601,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14557: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14604: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14560: \$? = $ac_status" >&5
+  echo "$as_me:14607: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14563: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14610: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14566: \$? = $ac_status" >&5
+  echo "$as_me:14613: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_dn_expand="-l$ac_lib"
 break
@@ -14576,7 +14623,7 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:14579: result: $ac_cv_search_dn_expand" >&5
+echo "$as_me:14626: result: $ac_cv_search_dn_expand" >&5
 echo "${ECHO_T}$ac_cv_search_dn_expand" >&6
 if test "$ac_cv_search_dn_expand" != no; then
   test "$ac_cv_search_dn_expand" = "none required" || LIBS="$ac_cv_search_dn_expand $LIBS"
@@ -14586,13 +14633,13 @@
 for ac_func in _getshort _getlong
 do
 as_ac_var=`echo "ac_cv_func_$ac_func" | $as_tr_sh`
-echo "$as_me:14589: checking for $ac_func" >&5
+echo "$as_me:14636: checking for $ac_func" >&5
 echo $ECHO_N "checking for $ac_func... $ECHO_C" >&6
 if eval "test \"\${$as_ac_var+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 14595 "configure"
+#line 14642 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func (); below.  */
@@ -14623,16 +14670,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14626: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14673: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14629: \$? = $ac_status" >&5
+  echo "$as_me:14676: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14632: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14679: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14635: \$? = $ac_status" >&5
+  echo "$as_me:14682: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   eval "$as_ac_var=yes"
 else
@@ -14642,7 +14689,7 @@
 fi
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 fi
-echo "$as_me:14645: result: `eval echo '${'$as_ac_var'}'`" >&5
+echo "$as_me:14692: result: `eval echo '${'$as_ac_var'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_var'}'`" >&6
 if test `eval echo '${'$as_ac_var'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -14652,13 +14699,13 @@
 fi
 done
 
-					echo "$as_me:14655: checking for HEADER.ad" >&5
+					echo "$as_me:14702: checking for HEADER.ad" >&5
 echo $ECHO_N "checking for HEADER.ad... $ECHO_C" >&6
 if test "${ac_cv_member_HEADER_ad+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 14661 "configure"
+#line 14708 "configure"
 #include "confdefs.h"
 #include <arpa/nameser.h>
 
@@ -14673,16 +14720,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:14676: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:14723: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14679: \$? = $ac_status" >&5
+  echo "$as_me:14726: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:14682: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14729: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14685: \$? = $ac_status" >&5
+  echo "$as_me:14732: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_member_HEADER_ad=yes
 else
@@ -14692,7 +14739,7 @@
 fi
 rm -f conftest.$ac_objext conftest.$ac_ext
 fi
-echo "$as_me:14695: result: $ac_cv_member_HEADER_ad" >&5
+echo "$as_me:14742: result: $ac_cv_member_HEADER_ad" >&5
 echo "${ECHO_T}$ac_cv_member_HEADER_ad" >&6
 if test $ac_cv_member_HEADER_ad = yes; then
   cat >>confdefs.h <<\EOF
@@ -14727,10 +14774,10 @@
 EOF
 
 			KRB5_MSG="yes"
-                        echo "$as_me:14730: checking whether we are using Heimdal" >&5
+                        echo "$as_me:14777: checking whether we are using Heimdal" >&5
 echo $ECHO_N "checking whether we are using Heimdal... $ECHO_C" >&6
                         cat >conftest.$ac_ext <<_ACEOF
-#line 14733 "configure"
+#line 14780 "configure"
 #include "confdefs.h"
  #include <krb5.h>
 int
@@ -14742,18 +14789,18 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:14745: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:14792: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:14748: \$? = $ac_status" >&5
+  echo "$as_me:14795: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:14751: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14798: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14754: \$? = $ac_status" >&5
+  echo "$as_me:14801: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:14756: result: yes" >&5
+   echo "$as_me:14803: result: yes" >&5
 echo "${ECHO_T}yes" >&6
                                          cat >>confdefs.h <<\EOF
 #define HEIMDAL 1
@@ -14764,7 +14811,7 @@
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:14767: result: no" >&5
+ echo "$as_me:14814: result: no" >&5
 echo "${ECHO_T}no" >&6
                                          K5LIBS="-lkrb5 -lk5crypto -lcom_err"
 
@@ -14776,7 +14823,7 @@
                         if test ! -z "$blibpath" ; then
                                 blibpath="$blibpath:${KRB5ROOT}/lib"
                         fi
-			echo "$as_me:14779: checking for library containing dn_expand" >&5
+			echo "$as_me:14826: checking for library containing dn_expand" >&5
 echo $ECHO_N "checking for library containing dn_expand... $ECHO_C" >&6
 if test "${ac_cv_search_dn_expand+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14784,7 +14831,7 @@
   ac_func_search_save_LIBS=$LIBS
 ac_cv_search_dn_expand=no
 cat >conftest.$ac_ext <<_ACEOF
-#line 14787 "configure"
+#line 14834 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14803,16 +14850,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14806: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14853: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14809: \$? = $ac_status" >&5
+  echo "$as_me:14856: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14812: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14859: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14815: \$? = $ac_status" >&5
+  echo "$as_me:14862: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_dn_expand="none required"
 else
@@ -14824,7 +14871,7 @@
   for ac_lib in resolv; do
     LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
     cat >conftest.$ac_ext <<_ACEOF
-#line 14827 "configure"
+#line 14874 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14843,16 +14890,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14846: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14893: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14849: \$? = $ac_status" >&5
+  echo "$as_me:14896: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14852: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14899: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14855: \$? = $ac_status" >&5
+  echo "$as_me:14902: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_search_dn_expand="-l$ac_lib"
 break
@@ -14865,14 +14912,14 @@
 fi
 LIBS=$ac_func_search_save_LIBS
 fi
-echo "$as_me:14868: result: $ac_cv_search_dn_expand" >&5
+echo "$as_me:14915: result: $ac_cv_search_dn_expand" >&5
 echo "${ECHO_T}$ac_cv_search_dn_expand" >&6
 if test "$ac_cv_search_dn_expand" != no; then
   test "$ac_cv_search_dn_expand" = "none required" || LIBS="$ac_cv_search_dn_expand $LIBS"
 
 fi
 
-			echo "$as_me:14875: checking for gss_init_sec_context in -lgssapi" >&5
+			echo "$as_me:14922: checking for gss_init_sec_context in -lgssapi" >&5
 echo $ECHO_N "checking for gss_init_sec_context in -lgssapi... $ECHO_C" >&6
 if test "${ac_cv_lib_gssapi_gss_init_sec_context+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14880,7 +14927,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgssapi $K5LIBS $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 14883 "configure"
+#line 14930 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14899,16 +14946,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14902: \"$ac_link\"") >&5
+if { (eval echo "$as_me:14949: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14905: \$? = $ac_status" >&5
+  echo "$as_me:14952: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14908: \"$ac_try\"") >&5
+  { (eval echo "$as_me:14955: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14911: \$? = $ac_status" >&5
+  echo "$as_me:14958: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_gssapi_gss_init_sec_context=yes
 else
@@ -14919,7 +14966,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:14922: result: $ac_cv_lib_gssapi_gss_init_sec_context" >&5
+echo "$as_me:14969: result: $ac_cv_lib_gssapi_gss_init_sec_context" >&5
 echo "${ECHO_T}$ac_cv_lib_gssapi_gss_init_sec_context" >&6
 if test $ac_cv_lib_gssapi_gss_init_sec_context = yes; then
    cat >>confdefs.h <<\EOF
@@ -14928,7 +14975,7 @@
 
 				  K5LIBS="-lgssapi $K5LIBS"
 else
-   echo "$as_me:14931: checking for gss_init_sec_context in -lgssapi_krb5" >&5
+   echo "$as_me:14978: checking for gss_init_sec_context in -lgssapi_krb5" >&5
 echo $ECHO_N "checking for gss_init_sec_context in -lgssapi_krb5... $ECHO_C" >&6
 if test "${ac_cv_lib_gssapi_krb5_gss_init_sec_context+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -14936,7 +14983,7 @@
   ac_check_lib_save_LIBS=$LIBS
 LIBS="-lgssapi_krb5 $K5LIBS $LIBS"
 cat >conftest.$ac_ext <<_ACEOF
-#line 14939 "configure"
+#line 14986 "configure"
 #include "confdefs.h"
 
 /* Override any gcc2 internal prototype to avoid an error.  */
@@ -14955,16 +15002,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:14958: \"$ac_link\"") >&5
+if { (eval echo "$as_me:15005: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:14961: \$? = $ac_status" >&5
+  echo "$as_me:15008: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:14964: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15011: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:14967: \$? = $ac_status" >&5
+  echo "$as_me:15014: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   ac_cv_lib_gssapi_krb5_gss_init_sec_context=yes
 else
@@ -14975,7 +15022,7 @@
 rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
 LIBS=$ac_check_lib_save_LIBS
 fi
-echo "$as_me:14978: result: $ac_cv_lib_gssapi_krb5_gss_init_sec_context" >&5
+echo "$as_me:15025: result: $ac_cv_lib_gssapi_krb5_gss_init_sec_context" >&5
 echo "${ECHO_T}$ac_cv_lib_gssapi_krb5_gss_init_sec_context" >&6
 if test $ac_cv_lib_gssapi_krb5_gss_init_sec_context = yes; then
    cat >>confdefs.h <<\EOF
@@ -14984,29 +15031,29 @@
 
 				  	  K5LIBS="-lgssapi_krb5 $K5LIBS"
 else
-  { echo "$as_me:14987: WARNING: Cannot find any suitable gss-api library - build may fail" >&5
+  { echo "$as_me:15034: WARNING: Cannot find any suitable gss-api library - build may fail" >&5
 echo "$as_me: WARNING: Cannot find any suitable gss-api library - build may fail" >&2;}
 fi
 
 fi
 
-			echo "$as_me:14993: checking for gssapi.h" >&5
+			echo "$as_me:15040: checking for gssapi.h" >&5
 echo $ECHO_N "checking for gssapi.h... $ECHO_C" >&6
 if test "${ac_cv_header_gssapi_h+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 14999 "configure"
+#line 15046 "configure"
 #include "confdefs.h"
 #include <gssapi.h>
 _ACEOF
-if { (eval echo "$as_me:15003: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:15050: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:15009: \$? = $ac_status" >&5
+  echo "$as_me:15056: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -15025,7 +15072,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:15028: result: $ac_cv_header_gssapi_h" >&5
+echo "$as_me:15075: result: $ac_cv_header_gssapi_h" >&5
 echo "${ECHO_T}$ac_cv_header_gssapi_h" >&6
 if test $ac_cv_header_gssapi_h = yes; then
   :
@@ -15036,23 +15083,23 @@
 for ac_header in gssapi.h
 do
 as_ac_Header=`echo "ac_cv_header_$ac_header" | $as_tr_sh`
-echo "$as_me:15039: checking for $ac_header" >&5
+echo "$as_me:15086: checking for $ac_header" >&5
 echo $ECHO_N "checking for $ac_header... $ECHO_C" >&6
 if eval "test \"\${$as_ac_Header+set}\" = set"; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 15045 "configure"
+#line 15092 "configure"
 #include "confdefs.h"
 #include <$ac_header>
 _ACEOF
-if { (eval echo "$as_me:15049: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:15096: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:15055: \$? = $ac_status" >&5
+  echo "$as_me:15102: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -15071,7 +15118,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:15074: result: `eval echo '${'$as_ac_Header'}'`" >&5
+echo "$as_me:15121: result: `eval echo '${'$as_ac_Header'}'`" >&5
 echo "${ECHO_T}`eval echo '${'$as_ac_Header'}'`" >&6
 if test `eval echo '${'$as_ac_Header'}'` = yes; then
   cat >>confdefs.h <<EOF
@@ -15079,7 +15126,7 @@
 EOF
 
 else
-  { echo "$as_me:15082: WARNING: Cannot find any suitable gss-api header - build may fail" >&5
+  { echo "$as_me:15129: WARNING: Cannot find any suitable gss-api header - build may fail" >&5
 echo "$as_me: WARNING: Cannot find any suitable gss-api header - build may fail" >&2;}
 
 fi
@@ -15089,23 +15136,23 @@
 
 			oldCPP="$CPPFLAGS"
 			CPPFLAGS="$CPPFLAGS -I${KRB5ROOT}/include/gssapi"
-			echo "$as_me:15092: checking for gssapi_krb5.h" >&5
+			echo "$as_me:15139: checking for gssapi_krb5.h" >&5
 echo $ECHO_N "checking for gssapi_krb5.h... $ECHO_C" >&6
 if test "${ac_cv_header_gssapi_krb5_h+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 15098 "configure"
+#line 15145 "configure"
 #include "confdefs.h"
 #include <gssapi_krb5.h>
 _ACEOF
-if { (eval echo "$as_me:15102: \"$ac_cpp conftest.$ac_ext\"") >&5
+if { (eval echo "$as_me:15149: \"$ac_cpp conftest.$ac_ext\"") >&5
   (eval $ac_cpp conftest.$ac_ext) 2>conftest.er1
   ac_status=$?
   egrep -v '^ *\+' conftest.er1 >conftest.err
   rm -f conftest.er1
   cat conftest.err >&5
-  echo "$as_me:15108: \$? = $ac_status" >&5
+  echo "$as_me:15155: \$? = $ac_status" >&5
   (exit $ac_status); } >/dev/null; then
   if test -s conftest.err; then
     ac_cpp_err=$ac_c_preproc_warn_flag
@@ -15124,7 +15171,7 @@
 fi
 rm -f conftest.err conftest.$ac_ext
 fi
-echo "$as_me:15127: result: $ac_cv_header_gssapi_krb5_h" >&5
+echo "$as_me:15174: result: $ac_cv_header_gssapi_krb5_h" >&5
 echo "${ECHO_T}$ac_cv_header_gssapi_krb5_h" >&6
 if test $ac_cv_header_gssapi_krb5_h = yes; then
   :
@@ -15169,7 +15216,7 @@
 		TestPath="${TestPath}${PATH_SEPARATOR}/usr/openwin/bin"
 		# Extract the first word of "xauth", so it can be a program name with args.
 set dummy xauth; ac_word=$2
-echo "$as_me:15172: checking for $ac_word" >&5
+echo "$as_me:15219: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_xauth_path+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -15186,7 +15233,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_xauth_path="$ac_dir/$ac_word"
-   echo "$as_me:15189: found $ac_dir/$ac_word" >&5
+   echo "$as_me:15236: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -15197,10 +15244,10 @@
 xauth_path=$ac_cv_path_xauth_path
 
 if test -n "$xauth_path"; then
-  echo "$as_me:15200: result: $xauth_path" >&5
+  echo "$as_me:15247: result: $xauth_path" >&5
 echo "${ECHO_T}$xauth_path" >&6
 else
-  echo "$as_me:15203: result: no" >&5
+  echo "$as_me:15250: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -15244,13 +15291,13 @@
 
 if test -z "$no_dev_ptmx" ; then
 	if test "x$disable_ptmx_check" != "xyes" ; then
-		echo "$as_me:15247: checking for \"/dev/ptmx\"" >&5
+		echo "$as_me:15294: checking for \"/dev/ptmx\"" >&5
 echo $ECHO_N "checking for \"/dev/ptmx\"... $ECHO_C" >&6
 if test "${ac_cv_file___dev_ptmx_+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   test "$cross_compiling" = yes &&
-  { { echo "$as_me:15253: error: cannot check for file existence when cross compiling" >&5
+  { { echo "$as_me:15300: error: cannot check for file existence when cross compiling" >&5
 echo "$as_me: error: cannot check for file existence when cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 if test -r ""/dev/ptmx""; then
@@ -15259,7 +15306,7 @@
   ac_cv_file___dev_ptmx_=no
 fi
 fi
-echo "$as_me:15262: result: $ac_cv_file___dev_ptmx_" >&5
+echo "$as_me:15309: result: $ac_cv_file___dev_ptmx_" >&5
 echo "${ECHO_T}$ac_cv_file___dev_ptmx_" >&6
 if test $ac_cv_file___dev_ptmx_ = yes; then
 
@@ -15273,13 +15320,13 @@
 
 	fi
 fi
-echo "$as_me:15276: checking for \"/dev/ptc\"" >&5
+echo "$as_me:15323: checking for \"/dev/ptc\"" >&5
 echo $ECHO_N "checking for \"/dev/ptc\"... $ECHO_C" >&6
 if test "${ac_cv_file___dev_ptc_+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   test "$cross_compiling" = yes &&
-  { { echo "$as_me:15282: error: cannot check for file existence when cross compiling" >&5
+  { { echo "$as_me:15329: error: cannot check for file existence when cross compiling" >&5
 echo "$as_me: error: cannot check for file existence when cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 if test -r ""/dev/ptc""; then
@@ -15288,7 +15335,7 @@
   ac_cv_file___dev_ptc_=no
 fi
 fi
-echo "$as_me:15291: result: $ac_cv_file___dev_ptc_" >&5
+echo "$as_me:15338: result: $ac_cv_file___dev_ptc_" >&5
 echo "${ECHO_T}$ac_cv_file___dev_ptc_" >&6
 if test $ac_cv_file___dev_ptc_ = yes; then
 
@@ -15311,7 +15358,7 @@
 			MANTYPE=$withval
 			;;
 		*)
-			{ { echo "$as_me:15314: error: invalid man type: $withval" >&5
+			{ { echo "$as_me:15361: error: invalid man type: $withval" >&5
 echo "$as_me: error: invalid man type: $withval" >&2;}
    { (exit 1); exit 1; }; }
 			;;
@@ -15324,7 +15371,7 @@
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
-echo "$as_me:15327: checking for $ac_word" >&5
+echo "$as_me:15374: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_NROFF+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -15341,7 +15388,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_NROFF="$ac_dir/$ac_word"
-   echo "$as_me:15344: found $ac_dir/$ac_word" >&5
+   echo "$as_me:15391: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -15352,10 +15399,10 @@
 NROFF=$ac_cv_path_NROFF
 
 if test -n "$NROFF"; then
-  echo "$as_me:15355: result: $NROFF" >&5
+  echo "$as_me:15402: result: $NROFF" >&5
 echo "${ECHO_T}$NROFF" >&6
 else
-  echo "$as_me:15358: result: no" >&5
+  echo "$as_me:15405: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -15412,10 +15459,10 @@
 fi;
 
 if test -z "$disable_shadow" ; then
-	echo "$as_me:15415: checking if the systems has expire shadow information" >&5
+	echo "$as_me:15462: checking if the systems has expire shadow information" >&5
 echo $ECHO_N "checking if the systems has expire shadow information... $ECHO_C" >&6
 	cat >conftest.$ac_ext <<_ACEOF
-#line 15418 "configure"
+#line 15465 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -15431,16 +15478,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:15434: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:15481: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:15437: \$? = $ac_status" >&5
+  echo "$as_me:15484: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:15440: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15487: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:15443: \$? = $ac_status" >&5
+  echo "$as_me:15490: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    sp_expire_available=yes
 else
@@ -15451,14 +15498,14 @@
 rm -f conftest.$ac_objext conftest.$ac_ext
 
 	if test "x$sp_expire_available" = "xyes" ; then
-		echo "$as_me:15454: result: yes" >&5
+		echo "$as_me:15501: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 		cat >>confdefs.h <<\EOF
 #define HAS_SHADOW_EXPIRE 1
 EOF
 
 	else
-		echo "$as_me:15461: result: no" >&5
+		echo "$as_me:15508: result: no" >&5
 echo "${ECHO_T}no" >&6
 	fi
 fi
@@ -15495,13 +15542,13 @@
 
 else
 
-echo "$as_me:15498: checking for \"/etc/default/login\"" >&5
+echo "$as_me:15545: checking for \"/etc/default/login\"" >&5
 echo $ECHO_N "checking for \"/etc/default/login\"... $ECHO_C" >&6
 if test "${ac_cv_file___etc_default_login_+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
 else
   test "$cross_compiling" = yes &&
-  { { echo "$as_me:15504: error: cannot check for file existence when cross compiling" >&5
+  { { echo "$as_me:15551: error: cannot check for file existence when cross compiling" >&5
 echo "$as_me: error: cannot check for file existence when cross compiling" >&2;}
    { (exit 1); exit 1; }; }
 if test -r ""/etc/default/login""; then
@@ -15510,7 +15557,7 @@
   ac_cv_file___etc_default_login_=no
 fi
 fi
-echo "$as_me:15513: result: $ac_cv_file___etc_default_login_" >&5
+echo "$as_me:15560: result: $ac_cv_file___etc_default_login_" >&5
 echo "${ECHO_T}$ac_cv_file___etc_default_login_" >&6
 if test $ac_cv_file___etc_default_login_ = yes; then
    external_path_file=/etc/default/login
@@ -15538,7 +15585,7 @@
   withval="$with_default_path"
 
 		if test "x$external_path_file" = "x/etc/login.conf" ; then
-			{ echo "$as_me:15541: WARNING:
+			{ echo "$as_me:15588: WARNING:
 --with-default-path=PATH has no effect on this system.
 Edit /etc/login.conf instead." >&5
 echo "$as_me: WARNING:
@@ -15546,7 +15593,7 @@
 Edit /etc/login.conf instead." >&2;}
 		elif test "x$withval" != "xno" ; then
 			if test ! -z "$external_path_file" ; then
-				{ echo "$as_me:15549: WARNING:
+				{ echo "$as_me:15596: WARNING:
 --with-default-path=PATH will only be used if PATH is not defined in
 $external_path_file ." >&5
 echo "$as_me: WARNING:
@@ -15559,11 +15606,11 @@
 
 else
    if test "x$external_path_file" = "x/etc/login.conf" ; then
-		{ echo "$as_me:15562: WARNING: Make sure the path to scp is in /etc/login.conf" >&5
+		{ echo "$as_me:15609: WARNING: Make sure the path to scp is in /etc/login.conf" >&5
 echo "$as_me: WARNING: Make sure the path to scp is in /etc/login.conf" >&2;}
 	else
 		if test ! -z "$external_path_file" ; then
-			{ echo "$as_me:15566: WARNING:
+			{ echo "$as_me:15613: WARNING:
 If PATH is defined in $external_path_file, ensure the path to scp is included,
 otherwise scp will not work." >&5
 echo "$as_me: WARNING:
@@ -15575,7 +15622,7 @@
 
 else
   cat >conftest.$ac_ext <<_ACEOF
-#line 15578 "configure"
+#line 15625 "configure"
 #include "confdefs.h"
 
 /* find out what STDPATH is */
@@ -15612,15 +15659,15 @@
 
 _ACEOF
 rm -f conftest$ac_exeext
-if { (eval echo "$as_me:15615: \"$ac_link\"") >&5
+if { (eval echo "$as_me:15662: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:15618: \$? = $ac_status" >&5
+  echo "$as_me:15665: \$? = $ac_status" >&5
   (exit $ac_status); } && { ac_try='./conftest$ac_exeext'
-  { (eval echo "$as_me:15620: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15667: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:15623: \$? = $ac_status" >&5
+  echo "$as_me:15670: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
    user_path=`cat conftest.stdpath`
 else
@@ -15644,7 +15691,7 @@
 			echo $user_path | grep "^$t_bindir"  > /dev/null 2>&1
 			if test $? -ne 0  ; then
 				user_path=$user_path:$t_bindir
-				echo "$as_me:15647: result: Adding $t_bindir to USER_PATH so scp will work" >&5
+				echo "$as_me:15694: result: Adding $t_bindir to USER_PATH so scp will work" >&5
 echo "${ECHO_T}Adding $t_bindir to USER_PATH so scp will work" >&6
 			fi
 		fi
@@ -15674,7 +15721,7 @@
 
 fi;
 
-echo "$as_me:15677: checking if we need to convert IPv4 in IPv6-mapped addresses" >&5
+echo "$as_me:15724: checking if we need to convert IPv4 in IPv6-mapped addresses" >&5
 echo $ECHO_N "checking if we need to convert IPv4 in IPv6-mapped addresses... $ECHO_C" >&6
 IPV4_IN6_HACK_MSG="no"
 
@@ -15683,7 +15730,7 @@
   withval="$with_4in6"
 
 		if test "x$withval" != "xno" ; then
-			echo "$as_me:15686: result: yes" >&5
+			echo "$as_me:15733: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 			cat >>confdefs.h <<\EOF
 #define IPV4_IN_IPV6 1
@@ -15691,14 +15738,14 @@
 
 			IPV4_IN6_HACK_MSG="yes"
 		else
-			echo "$as_me:15694: result: no" >&5
+			echo "$as_me:15741: result: no" >&5
 echo "${ECHO_T}no" >&6
 		fi
 
 else
 
 		if test "x$inet6_default_4in6" = "xyes"; then
-			echo "$as_me:15701: result: yes (default)" >&5
+			echo "$as_me:15748: result: yes (default)" >&5
 echo "${ECHO_T}yes (default)" >&6
 			cat >>confdefs.h <<\EOF
 #define IPV4_IN_IPV6 1
@@ -15706,7 +15753,7 @@
 
 			IPV4_IN6_HACK_MSG="yes"
 		else
-			echo "$as_me:15709: result: no (default)" >&5
+			echo "$as_me:15756: result: no (default)" >&5
 echo "${ECHO_T}no (default)" >&6
 		fi
 
@@ -15746,7 +15793,7 @@
 		if test "x$withval" != "xno" ; then
 			piddir=$withval
 			if test ! -d $piddir ; then
-			{ echo "$as_me:15749: WARNING: ** no $piddir directory on this system **" >&5
+			{ echo "$as_me:15796: WARNING: ** no $piddir directory on this system **" >&5
 echo "$as_me: WARNING: ** no $piddir directory on this system **" >&2;}
 			fi
 		fi
@@ -15869,10 +15916,10 @@
 
 fi;
 
-echo "$as_me:15872: checking if your system defines LASTLOG_FILE" >&5
+echo "$as_me:15919: checking if your system defines LASTLOG_FILE" >&5
 echo $ECHO_N "checking if your system defines LASTLOG_FILE... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 15875 "configure"
+#line 15922 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -15896,29 +15943,29 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:15899: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:15946: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:15902: \$? = $ac_status" >&5
+  echo "$as_me:15949: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:15905: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15952: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:15908: \$? = $ac_status" >&5
+  echo "$as_me:15955: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:15910: result: yes" >&5
+   echo "$as_me:15957: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-		echo "$as_me:15916: result: no" >&5
+		echo "$as_me:15963: result: no" >&5
 echo "${ECHO_T}no" >&6
-		echo "$as_me:15918: checking if your system defines _PATH_LASTLOG" >&5
+		echo "$as_me:15965: checking if your system defines _PATH_LASTLOG" >&5
 echo $ECHO_N "checking if your system defines _PATH_LASTLOG... $ECHO_C" >&6
 		cat >conftest.$ac_ext <<_ACEOF
-#line 15921 "configure"
+#line 15968 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -15939,24 +15986,24 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:15942: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:15989: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:15945: \$? = $ac_status" >&5
+  echo "$as_me:15992: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:15948: \"$ac_try\"") >&5
+  { (eval echo "$as_me:15995: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:15951: \$? = $ac_status" >&5
+  echo "$as_me:15998: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:15953: result: yes" >&5
+   echo "$as_me:16000: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 
-			echo "$as_me:15959: result: no" >&5
+			echo "$as_me:16006: result: no" >&5
 echo "${ECHO_T}no" >&6
 			system_lastlog_path=no
 
@@ -15974,7 +16021,7 @@
 				fi
 		done
 		if test -z "$conf_lastlog_location"; then
-			{ echo "$as_me:15977: WARNING: ** Cannot find lastlog **" >&5
+			{ echo "$as_me:16024: WARNING: ** Cannot find lastlog **" >&5
 echo "$as_me: WARNING: ** Cannot find lastlog **" >&2;}
 					fi
 	fi
@@ -15987,10 +16034,10 @@
 
 fi
 
-echo "$as_me:15990: checking if your system defines UTMP_FILE" >&5
+echo "$as_me:16037: checking if your system defines UTMP_FILE" >&5
 echo $ECHO_N "checking if your system defines UTMP_FILE... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 15993 "configure"
+#line 16040 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -16008,23 +16055,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:16011: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:16058: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:16014: \$? = $ac_status" >&5
+  echo "$as_me:16061: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:16017: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16064: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16020: \$? = $ac_status" >&5
+  echo "$as_me:16067: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:16022: result: yes" >&5
+   echo "$as_me:16069: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:16027: result: no" >&5
+ echo "$as_me:16074: result: no" >&5
 echo "${ECHO_T}no" >&6
 	  system_utmp_path=no
 
@@ -16052,10 +16099,10 @@
 
 fi
 
-echo "$as_me:16055: checking if your system defines WTMP_FILE" >&5
+echo "$as_me:16102: checking if your system defines WTMP_FILE" >&5
 echo $ECHO_N "checking if your system defines WTMP_FILE... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 16058 "configure"
+#line 16105 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -16073,23 +16120,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:16076: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:16123: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:16079: \$? = $ac_status" >&5
+  echo "$as_me:16126: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:16082: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16129: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16085: \$? = $ac_status" >&5
+  echo "$as_me:16132: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:16087: result: yes" >&5
+   echo "$as_me:16134: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:16092: result: no" >&5
+ echo "$as_me:16139: result: no" >&5
 echo "${ECHO_T}no" >&6
 	  system_wtmp_path=no
 
@@ -16117,10 +16164,10 @@
 
 fi
 
-echo "$as_me:16120: checking if your system defines UTMPX_FILE" >&5
+echo "$as_me:16167: checking if your system defines UTMPX_FILE" >&5
 echo $ECHO_N "checking if your system defines UTMPX_FILE... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 16123 "configure"
+#line 16170 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -16141,23 +16188,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:16144: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:16191: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:16147: \$? = $ac_status" >&5
+  echo "$as_me:16194: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:16150: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16197: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16153: \$? = $ac_status" >&5
+  echo "$as_me:16200: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:16155: result: yes" >&5
+   echo "$as_me:16202: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:16160: result: no" >&5
+ echo "$as_me:16207: result: no" >&5
 echo "${ECHO_T}no" >&6
 	  system_utmpx_path=no
 
@@ -16177,10 +16224,10 @@
 
 fi
 
-echo "$as_me:16180: checking if your system defines WTMPX_FILE" >&5
+echo "$as_me:16227: checking if your system defines WTMPX_FILE" >&5
 echo $ECHO_N "checking if your system defines WTMPX_FILE... $ECHO_C" >&6
 cat >conftest.$ac_ext <<_ACEOF
-#line 16183 "configure"
+#line 16230 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -16201,23 +16248,23 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext
-if { (eval echo "$as_me:16204: \"$ac_compile\"") >&5
+if { (eval echo "$as_me:16251: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:16207: \$? = $ac_status" >&5
+  echo "$as_me:16254: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest.$ac_objext'
-  { (eval echo "$as_me:16210: \"$ac_try\"") >&5
+  { (eval echo "$as_me:16257: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:16213: \$? = $ac_status" >&5
+  echo "$as_me:16260: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
-   echo "$as_me:16215: result: yes" >&5
+   echo "$as_me:16262: result: yes" >&5
 echo "${ECHO_T}yes" >&6
 else
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
- echo "$as_me:16220: result: no" >&5
+ echo "$as_me:16267: result: no" >&5
 echo "${ECHO_T}no" >&6
 	  system_wtmpx_path=no
 
@@ -16239,7 +16286,7 @@
 
 if test ! -z "$blibpath" ; then
 	LDFLAGS="$LDFLAGS $blibflags$blibpath"
-	{ echo "$as_me:16242: WARNING: Please check and edit blibpath in LDFLAGS in Makefile" >&5
+	{ echo "$as_me:16289: WARNING: Please check and edit blibpath in LDFLAGS in Makefile" >&5
 echo "$as_me: WARNING: Please check and edit blibpath in LDFLAGS in Makefile" >&2;}
 fi
 
@@ -16331,7 +16378,7 @@
 : ${CONFIG_STATUS=./config.status}
 ac_clean_files_save=$ac_clean_files
 ac_clean_files="$ac_clean_files $CONFIG_STATUS"
-{ echo "$as_me:16334: creating $CONFIG_STATUS" >&5
+{ echo "$as_me:16381: creating $CONFIG_STATUS" >&5
 echo "$as_me: creating $CONFIG_STATUS" >&6;}
 cat >$CONFIG_STATUS <<_ACEOF
 #! $SHELL
@@ -16504,7 +16551,7 @@
     echo "$ac_cs_version"; exit 0 ;;
   --he | --h)
     # Conflict between --help and --header
-    { { echo "$as_me:16507: error: ambiguous option: $1
+    { { echo "$as_me:16554: error: ambiguous option: $1
 Try \`$0 --help' for more information." >&5
 echo "$as_me: error: ambiguous option: $1
 Try \`$0 --help' for more information." >&2;}
@@ -16523,7 +16570,7 @@
     ac_need_defaults=false;;
 
   # This is an error.
-  -*) { { echo "$as_me:16526: error: unrecognized option: $1
+  -*) { { echo "$as_me:16573: error: unrecognized option: $1
 Try \`$0 --help' for more information." >&5
 echo "$as_me: error: unrecognized option: $1
 Try \`$0 --help' for more information." >&2;}
@@ -16563,7 +16610,7 @@
   "scard/Makefile" ) CONFIG_FILES="$CONFIG_FILES scard/Makefile" ;;
   "ssh_prng_cmds" ) CONFIG_FILES="$CONFIG_FILES ssh_prng_cmds" ;;
   "config.h" ) CONFIG_HEADERS="$CONFIG_HEADERS config.h" ;;
-  *) { { echo "$as_me:16566: error: invalid argument: $ac_config_target" >&5
+  *) { { echo "$as_me:16613: error: invalid argument: $ac_config_target" >&5
 echo "$as_me: error: invalid argument: $ac_config_target" >&2;}
    { (exit 1); exit 1; }; };;
   esac
@@ -16673,6 +16720,7 @@
 s,@TEST_MINUS_S_SH@,$TEST_MINUS_S_SH,;t t
 s,@SH@,$SH,;t t
 s,@LOGIN_PROGRAM_FALLBACK@,$LOGIN_PROGRAM_FALLBACK,;t t
+s,@PASSWD_PROGRAM_PATH@,$PASSWD_PROGRAM_PATH,;t t
 s,@LD@,$LD,;t t
 s,@LIBWRAP@,$LIBWRAP,;t t
 s,@LIBPAM@,$LIBPAM,;t t
@@ -16819,7 +16867,7 @@
   esac
 
   if test x"$ac_file" != x-; then
-    { echo "$as_me:16822: creating $ac_file" >&5
+    { echo "$as_me:16870: creating $ac_file" >&5
 echo "$as_me: creating $ac_file" >&6;}
     rm -f "$ac_file"
   fi
@@ -16837,7 +16885,7 @@
       -) echo $tmp/stdin ;;
       [\\/$]*)
          # Absolute (can't be DOS-style, as IFS=:)
-         test -f "$f" || { { echo "$as_me:16840: error: cannot find input file: $f" >&5
+         test -f "$f" || { { echo "$as_me:16888: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          echo $f;;
@@ -16850,7 +16898,7 @@
            echo $srcdir/$f
          else
            # /dev/null tree
-           { { echo "$as_me:16853: error: cannot find input file: $f" >&5
+           { { echo "$as_me:16901: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          fi;;
@@ -16911,7 +16959,7 @@
   * )   ac_file_in=$ac_file.in ;;
   esac
 
-  test x"$ac_file" != x- && { echo "$as_me:16914: creating $ac_file" >&5
+  test x"$ac_file" != x- && { echo "$as_me:16962: creating $ac_file" >&5
 echo "$as_me: creating $ac_file" >&6;}
 
   # First look for the input files in the build tree, otherwise in the
@@ -16922,7 +16970,7 @@
       -) echo $tmp/stdin ;;
       [\\/$]*)
          # Absolute (can't be DOS-style, as IFS=:)
-         test -f "$f" || { { echo "$as_me:16925: error: cannot find input file: $f" >&5
+         test -f "$f" || { { echo "$as_me:16973: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          echo $f;;
@@ -16935,7 +16983,7 @@
            echo $srcdir/$f
          else
            # /dev/null tree
-           { { echo "$as_me:16938: error: cannot find input file: $f" >&5
+           { { echo "$as_me:16986: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          fi;;
@@ -17052,7 +17100,7 @@
   rm -f $tmp/in
   if test x"$ac_file" != x-; then
     if cmp -s $ac_file $tmp/config.h 2>/dev/null; then
-      { echo "$as_me:17055: $ac_file is unchanged" >&5
+      { echo "$as_me:17103: $ac_file is unchanged" >&5
 echo "$as_me: $ac_file is unchanged" >&6;}
     else
       ac_dir=`$as_expr X"$ac_file" : 'X\(.*[^/]\)//*[^/][^/]*/*$' \| \
diff -ru openssh-3.7.1p2.orig/configure.ac openssh-3.7.1p2/configure.ac
--- openssh-3.7.1p2.orig/configure.ac	2003-09-23 19:24:21.000000000 +1000
+++ openssh-3.7.1p2/configure.ac	2003-11-12 13:06:03.000000000 +1100
@@ -42,6 +42,13 @@
 	fi
 fi
 
+AC_PATH_PROG(PASSWD_PROGRAM_PATH, passwd)
+if test ! -z "$PASSWD_PROGRAM_PATH" ; then
+	AC_DEFINE_UNQUOTED(PASSWD_PROGRAM_PATH, "$PASSWD_PROGRAM_PATH")
+else
+	AC_MSG_ERROR([*** passwd command not found - check config.log ***])
+fi
+
 if test -z "$LD" ; then
 	LD=$CC
 fi
@@ -897,7 +904,6 @@
 			AC_CHECK_FUNCS(pam_getenvlist)
 			AC_CHECK_FUNCS(pam_putenv)
 
-			disable_shadow=yes
 			PAM_MSG="yes"
 
 			AC_DEFINE(USE_PAM)
diff -ru openssh-3.7.1p2.orig/session.c openssh-3.7.1p2/session.c
--- openssh-3.7.1p2.orig/session.c	2003-09-23 18:59:08.000000000 +1000
+++ openssh-3.7.1p2/session.c	2003-11-12 13:06:03.000000000 +1100
@@ -94,6 +94,9 @@
 extern int startup_pipe;
 extern void destroy_sensitive_data(void);
 extern Buffer loginmsg;
+extern Buffer expiremsg;
+extern int password_change_required;
+
 
 /* original command from peer. */
 const char *original_command = NULL;
@@ -395,13 +398,12 @@
 	session_proctitle(s);
 
 #if defined(USE_PAM)
-	if (options.use_pam) {
+	if (options.use_pam)
 		do_pam_setcred(1);
-		if (is_pam_password_change_required())
-			packet_disconnect("Password change required but no "
-			    "TTY available");
-	}
 #endif /* USE_PAM */
+	if (password_change_required)
+		packet_disconnect("Password change required but no "
+		    "TTY available");
 
 	/* Fork the child. */
 	if ((pid = fork()) == 0) {
@@ -671,10 +673,10 @@
 void
 do_login(Session *s, const char *command)
 {
-	char *time_string;
 	socklen_t fromlen;
 	struct sockaddr_storage from;
 	struct passwd * pw = s->pw;
+	int password_changed = 0;
 	pid_t pid = getpid();
 
 	/*
@@ -698,25 +700,31 @@
 		    options.use_dns),
 		    (struct sockaddr *)&from, fromlen);
 
-#ifdef USE_PAM
 	/*
 	 * If password change is needed, do it now.
 	 * This needs to occur before the ~/.hushlogin check.
 	 */
-	if (options.use_pam && is_pam_password_change_required()) {
-		print_pam_messages();
-		do_pam_chauthtok();
+	buffer_append(&expiremsg, "\0", 1);
+	if (password_change_required) {
+		printf("%s\n", (char *)buffer_ptr(&expiremsg));
+		if (options.use_pam) {
+#ifdef USE_PAM
+			if (use_privsep)
+				do_tty_change_password(pw);
+#endif
+		} else {
+			fflush(stdout);
+			do_tty_change_password(pw);
+		}
+		password_changed = 1;	/* chauthtok will abort on failure */
 		/* XXX - signal [net] parent to enable forwardings */
 	}
-#endif
 
 	if (check_quietlogin(s, command))
 		return;
 
-#ifdef USE_PAM
-	if (options.use_pam && !is_pam_password_change_required())
-		print_pam_messages();
-#endif /* USE_PAM */
+	if (!password_changed)
+		printf("%s", (char *)buffer_ptr(&expiremsg));
 
 	/* display post-login message */
 	if (buffer_len(&loginmsg) > 0) {
@@ -725,19 +733,6 @@
 	}
 	buffer_free(&loginmsg);
 
-#ifndef NO_SSH_LASTLOG
-	if (options.print_lastlog && s->last_login_time != 0) {
-		time_string = ctime(&s->last_login_time);
-		if (strchr(time_string, '\n'))
-			*strchr(time_string, '\n') = 0;
-		if (strcmp(s->hostname, "") == 0)
-			printf("Last login: %s\r\n", time_string);
-		else
-			printf("Last login: %s from %s\r\n", time_string,
-			    s->hostname);
-	}
-#endif /* NO_SSH_LASTLOG */
-
 	do_motd();
 }
 
@@ -1621,12 +1616,6 @@
 		packet_disconnect("Protocol error: you already have a pty.");
 		return 0;
 	}
-	/* Get the time and hostname when the user last logged in. */
-	if (options.print_lastlog) {
-		s->hostname[0] = '\0';
-		s->last_login_time = get_last_login_time(s->pw->pw_uid,
-		    s->pw->pw_name, s->hostname, sizeof(s->hostname));
-	}
 
 	s->term = packet_get_string(&len);
 
diff -ru openssh-3.7.1p2.orig/session.h openssh-3.7.1p2/session.h
--- openssh-3.7.1p2.orig/session.h	2003-08-26 11:49:56.000000000 +1000
+++ openssh-3.7.1p2/session.h	2003-11-12 13:06:03.000000000 +1100
@@ -39,9 +39,6 @@
 	int	ptyfd, ttyfd, ptymaster;
 	u_int	row, col, xpixel, ypixel;
 	char	tty[TTYSZ];
-	/* last login */
-	char	hostname[MAXHOSTNAMELEN];
-	time_t	last_login_time;
 	/* X11 */
 	u_int	display_number;
 	char	*display;
diff -ru openssh-3.7.1p2.orig/sshd.c openssh-3.7.1p2/sshd.c
--- openssh-3.7.1p2.orig/sshd.c	2003-09-02 22:51:17.000000000 +1000
+++ openssh-3.7.1p2/sshd.c	2003-11-12 13:06:03.000000000 +1100
@@ -202,7 +202,8 @@
 struct monitor *pmonitor;
 
 /* message to be displayed after login */
-Buffer loginmsg;
+Buffer expiremsg;	/* "password will expire/has expired" messages */
+Buffer loginmsg;	/* message to be displayed after login */
 
 /* Prototypes for various functions defined later in this file. */
 void destroy_sensitive_data(void);
@@ -1472,6 +1473,10 @@
 		if ((authctxt = privsep_preauth()) != NULL)
 			goto authenticated;
 
+	/* prepare buffers to collect authentication/expiry messages */
+	buffer_init(&loginmsg);
+	buffer_init(&expiremsg);
+
 	/* perform the key exchange */
 	/* authenticate user and start session */
 	if (compat20) {
Only in openssh-3.7.1p2: stamp-h.in
diff -ru openssh-3.7.1p2.orig/version.h openssh-3.7.1p2/version.h
--- openssh-3.7.1p2.orig/version.h	2003-09-23 19:26:51.000000000 +1000
+++ openssh-3.7.1p2/version.h	2003-11-12 13:06:03.000000000 +1100
@@ -1,3 +1,3 @@
 /* $OpenBSD: version.h,v 1.39 2003/09/16 21:02:40 markus Exp $ */
 
-#define SSH_VERSION	"OpenSSH_3.7.1p2"
+#define SSH_VERSION	"OpenSSH_3.7.1p2-pwexp25"
